@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 #include <gnumeric-config.h>
 #include <gnumeric.h>
@@ -208,8 +207,8 @@ static GnmFuncHelp const help_base[] = {
         { GNM_FUNC_HELP_ARG, F_("n:integer") },
         { GNM_FUNC_HELP_ARG, F_("b:base (2 \xe2\x89\xa4 @{b} \xe2\x89\xa4 36)") },
         { GNM_FUNC_HELP_ARG, F_("length:minimum length of the resulting string") },
-        { GNM_FUNC_HELP_DESCRIPTION, F_("BASE converts @{n} to its string representation in base @{b}."
-					" Leading zeroes will be added to reach the minimum length given by @{length}.") },
+        { GNM_FUNC_HELP_DESCRIPTION, F_("BASE converts @{n} to its string representation in base @{b}. "
+					"Leading zeroes will be added to reach the minimum length given by @{length}.") },
 	{ GNM_FUNC_HELP_ODF, F_("This function is OpenFormula compatible.") },
         { GNM_FUNC_HELP_EXAMPLES, "=BASE(255,16,4)" },
         { GNM_FUNC_HELP_SEEALSO, "DECIMAL" },
@@ -649,20 +648,37 @@ static GnmFuncHelp const help_convert[] = {
 	{ GNM_FUNC_HELP_NOTE, F_("If @{from} and @{to} are different types, CONVERT returns #N/A!") },
         { GNM_FUNC_HELP_DESCRIPTION, F_("@{from} and @{to} can be any of the following:\n\n"
 					"Weight and mass:\n"
+					"\t'brton'\t\tImperial ton\n"
+					"\t'cwt'\t\t\tU.S. (short) hundredweight\n"
 					"\t'g'  \t\t\tGram\n"
+					"\t'grain'\t\tGrain\n"
+					"\t'hweight'\t\tImperial (long) hundredweight\n"
+					"\t'LTON'\t\tImperial ton\n"
 					"\t'sg' \t\t\tSlug\n"
+					"\t'shweight'\tU.S. (short) hundredweight\n"
 					"\t'lbm'\t\tPound\n"
+					"\t'lcwt'\t\tImperial  (long) hundredweight\n"
 					"\t'u'  \t\t\tU (atomic mass)\n"
-					"\t'ozm'\t\tOunce\n\n"
+					"\t'uk_cwt'\t\tImperial  (long) hundredweight\n"
+					"\t'uk_ton'\t\tImperial ton\n"
+					"\t'ozm'\t\tOunce\n"
+					"\t'stone'\t\tStone\n"
+					"\t'ton'\t\t\tTon\n\n"
 					"Distance:\n"
 					"\t'm'   \t\tMeter\n"
 					"\t'mi'  \t\tStatute mile\n"
+					"\t'survey_mi' \tU.S. survey mile\n"
 					"\t'Nmi' \t\tNautical mile\n"
 					"\t'in'  \t\t\tInch\n"
 					"\t'ft'  \t\t\tFoot\n"
 					"\t'yd'  \t\tYard\n"
+					"\t'ell' \t\t\tEnglish Ell\n"
 					"\t'ang' \t\tAngstrom\n"
+					"\t'ly' \t\t\tLight-Year\n"
+					"\t'pc' \t\t\tParsec\n"
+					"\t'parsec' \t\tParsec\n"
 					"\t'Pica'\t\tPica Points\n"
+					"\t'Picapt'\t\tPica Points\n"
 					"\t'picapt'\t\tPica Points\n"
 					"\t'pica'\t\tPica\n\n"
 					"Time:\n"
@@ -672,12 +688,16 @@ static GnmFuncHelp const help_convert[] = {
 					"\t'mn'  \t\tMinute\n"
 					"\t'sec' \t\tSecond\n\n"
 					"Pressure:\n"
-					"\t'Pa'  \t\tPascal\n"
+					"\t'Pa'  \t\t\tPascal\n"
+					"\t'psi' \t\t\tPSI\n"
 					"\t'atm' \t\tAtmosphere\n"
-					"\t'mmHg'\t\tmm of Mercury\n\n"
+					"\t'Pa'  \t\t\tPascal\n"
+					"\t'mmHg'\t\tmm of Mercury\n"
+					"\t'Torr'\t\t\tTorr\n\n"
 					"Force:\n"
 					"\t'N'   \t\t\tNewton\n"
 					"\t'dyn' \t\tDyne\n"
+					"\t'pond' \t\tPond\n"
 					"\t'lbf' \t\t\tPound force\n\n"
 					"Energy:\n"
 					"\t'J'    \t\t\tJoule\n"
@@ -691,6 +711,7 @@ static GnmFuncHelp const help_convert[] = {
 					"\t'BTU'  \t\tBTU\n\n"
 					"Power:\n"
 					"\t'HP'   \t\tHorsepower\n"
+					"\t'PS'   \t\tPferdestärke\n"
 					"\t'W'    \t\tWatt\n\n"
 					"Magnetism:\n"
 					"\t'T'    \t\tTesla\n"
@@ -698,16 +719,85 @@ static GnmFuncHelp const help_convert[] = {
 					"Temperature:\n"
 					"\t'C'    \t\tDegree Celsius\n"
 					"\t'F'    \t\tDegree Fahrenheit\n"
-					"\t'K'    \t\tDegree Kelvin\n\n"
-					"Liquid measure:\n"
+					"\t'K'    \t\tKelvin\n"
+					"\t'Rank' \t\tDegree Rankine\n"
+					"\t'Reau' \t\tDegree Réaumur\n\n"
+					"Volume (liquid measure):\n"
 					"\t'tsp'  \t\tTeaspoon\n"
+					"\t'tspm'  \t\tTeaspoon (modern, metric)\n"
 					"\t'tbs'  \t\tTablespoon\n"
 					"\t'oz'   \t\tFluid ounce\n"
 					"\t'cup'  \t\tCup\n"
 					"\t'pt'   \t\tPint\n"
+					"\t'us_pt'\t\tU.S. pint\n"
+					"\t'uk_pt'\t\tImperial pint (U.K.)\n"
 					"\t'qt'   \t\tQuart\n"
+					"\t'uk_qt'   \t\tImperial quart\n"
 					"\t'gal'  \t\tGallon\n"
-					"\t'l'    \t\t\tLiter\n\n"
+					"\t'uk_gal'  \t\tImperial gallon\n"
+					"\t'GRT'  \t\tRegistered ton\n"
+					"\t'regton' \t\tRegistered ton\n"
+					"\t'MTON' \t\tMeasurement ton (freight ton)\n"
+					"\t'l'    \t\t\tLiter\n"
+					"\t'L'    \t\tLiter\n"
+					"\t'lt'   \t\t\tLiter\n"
+					"\t'ang3' \t\tCubic Angstrom\n"
+					"\t'ang^3' \t\tCubic Angstrom\n"
+					"\t'barrel' \t\tU.S. oil barrel (bbl)\n"
+					"\t'bushel' \t\tU.S. bushel\n"
+					"\t'ft3' \t\t\tCubic feet\n"
+					"\t'ft^3' \t\tCubic feet\n"
+					"\t'in3' \t\tCubic inch\n"
+					"\t'in^3' \t\tCubic inch\n"
+					"\t'ly3' \t\t\tCubic light-year\n"
+					"\t'ly^3' \t\tCubic light-year\n"
+					"\t'm3' \t\tCubic meter\n"
+					"\t'm^3' \t\tCubic meter\n"
+					"\t'mi3' \t\tCubic mile\n"
+					"\t'mi^3' \t\tCubic mile\n"
+					"\t'yd3' \t\tCubic yard\n"
+					"\t'yd^3' \t\tCubic yard\n"
+					"\t'Nmi3' \t\tCubic nautical mile\n"
+					"\t'Nmi^3' \t\tCubic nautical mile\n"
+					"\t'Picapt3' \t\tCubic Pica\n"
+					"\t'Picapt^3' \tCubic Pica\n"
+					"\t'Pica3' \t\tCubic Pica\n"
+					"\t'Pica^3' \t\tCubic Pica\n\n"
+					"Area:\n"
+					"\t'uk_acre' \t\tInternational acre\n"
+					"\t'us_acre' \t\tU.S. survey/statute acre\n"
+					"\t'ang2' \t\tSquare angstrom\n"
+					"\t'ang^2' \t\tSquare angstrom\n"
+					"\t'ar' \t\t\tAre\n"
+					"\t'ha' \t\t\tHectare\n"
+					"\t'in2' \t\tSquare inches\n"
+					"\t'in^2' \t\tSquare inches\n"
+					"\t'ly2' \t\t\tSquare light-year\n"
+					"\t'ly^2' \t\tSquare light-year\n"
+					"\t'm2' \t\tSquare meter\n"
+					"\t'm^2' \t\tSquare meter\n"
+					"\t'Morgen' \t\tMorgen (North German Confederation)\n"
+					"\t'mi2' \t\tSquare miles\n"
+					"\t'mi^2' \t\tSquare miles\n"
+					"\t'Nmi2' \t\tSquare nautical miles\n"
+					"\t'Nmi^2' \t\tSquare nautical miles\n"
+					"\t'Picapt2' \t\tSquare Pica\n"
+					"\t'Picapt^2' \tSquare Pica\n"
+					"\t'Pica2' \t\tSquare Pica\n"
+					"\t'Pica^2' \t\tSquare Pica\n"
+					"\t'yd2' \t\tSquare yards\n"
+					"\t'yd^2' \t\tSquare yards\n\n"
+					"Bits and Bytes:\n"
+					"\t'bit' \t\t\tBit\n"
+					"\t'byte' \t\tByte\n\n"
+					"Speed:\n"
+					"\t'admkn' \t\tAdmiralty knot\n"
+					"\t'kn' \t\t\tknot\n"
+					"\t'm/h' \t\tMeters per hour\n"
+					"\t'm/hr' \t\tMeters per hour\n"
+					"\t'm/s' \t\tMeters per second\n"
+					"\t'm/sec' \t\tMeters per second\n"
+					"\t'mph' \t\tMiles per hour\n\n"
 					"For metric units any of the following prefixes can be used:\n"
 					"\t'Y'  \tyotta \t\t1E+24\n"
 					"\t'Z'  \tzetta \t\t1E+21\n"
@@ -716,24 +806,34 @@ static GnmFuncHelp const help_convert[] = {
 					"\t'T'  \ttera  \t\t1E+12\n"
 					"\t'G'  \tgiga  \t\t1E+09\n"
 					"\t'M'  \tmega  \t\t1E+06\n"
-					"\t'k'  \tkilo  \t\t1E+03\n"
+					"\t'k'  \tkilo  \t\t\t1E+03\n"
 					"\t'h'  \thecto \t\t1E+02\n"
 					"\t'e'  \tdeca (deka)\t1E+01\n"
 					"\t'd'  \tdeci  \t\t1E-01\n"
 					"\t'c'  \tcenti \t\t1E-02\n"
-					"\t'm'  \tmilli \t\t1E-03\n"
+					"\t'm'  \tmilli \t\t\t1E-03\n"
 					"\t'u'  \tmicro \t\t1E-06\n"
 					"\t'n'  \tnano  \t\t1E-09\n"
 					"\t'p'  \tpico  \t\t1E-12\n"
 					"\t'f'  \tfemto \t\t1E-15\n"
 					"\t'a'  \tatto  \t\t1E-18\n"
 					"\t'z'  \tzepto \t\t1E-21\n"
-					"\t'y'  \tyocto \t\t1E-24") },
+					"\t'y'  \tyocto \t\t1E-24\n\n"
+					"For bits and bytes any of the following prefixes can be also be used:\n"
+					"\t'Yi'  \tyobi \t\t2^80\n"
+					"\t'Zi'  \tzebi \t\t\t2^70\n"
+					"\t'Ei'  \texbi \t\t2^60\n"
+					"\t'Pi'  \tpebi \t\t2^50\n"
+					"\t'Ti'  \ttebi \t\t\t2^40\n"
+					"\t'Gi'  \tgibi \t\t\t2^30\n"
+					"\t'Mi'  \tmebi \t\t2^20\n"
+					"\t'ki'  \tkibi \t\t\t2^10") },
  	{ GNM_FUNC_HELP_EXCEL, F_("This function is Excel compatible (except \"picapt\").") },
  	{ GNM_FUNC_HELP_ODF, F_("This function is OpenFormula compatible.") },
 	{ GNM_FUNC_HELP_EXAMPLES, "=CONVERT(3,\"lbm\",\"g\")" },
         { GNM_FUNC_HELP_EXAMPLES, "=CONVERT(5.8,\"m\",\"in\")" },
         { GNM_FUNC_HELP_EXAMPLES, "=CONVERT(7.9,\"cal\",\"J\")" },
+        { GNM_FUNC_HELP_EXAMPLES, "=CONVERT(3,\"Yibyte\",\"bit\")" },
         { GNM_FUNC_HELP_END}
 };
 
@@ -759,12 +859,14 @@ get_constant_of_unit(const eng_convert_unit_t units[],
 		}
 
 	if (prefixes != NULL)
-	        for (i = 0; prefixes[i].str != NULL; i++)
-		        if (strncmp (unit_name, prefixes[i].str, 1) == 0) {
+	        for (i = 0; prefixes[i].str != NULL; i++) {
+			int prefix_length = strlen (prefixes[i].str);
+		        if (strncmp (unit_name, prefixes[i].str, prefix_length) == 0) {
 			        *prefix = prefixes[i].c;
-				unit_name++;
+				unit_name += prefix_length;
 				break;
 			}
+		}
 
 	for (i = 0; units[i].str != NULL; i++)
 	        if (strcmp (unit_name, units[i].str) == 0) {
@@ -802,22 +904,122 @@ convert (eng_convert_unit_t const units[],
 	return FALSE;
 }
 
+typedef enum {
+	temp_invalid = 0,
+	temp_K,
+	temp_C,
+	temp_F,
+	temp_Rank,
+	temp_Reau
+} temp_types;
+
+static temp_types
+convert_temp_unit (char const *unit) {
+	if (0 == strcmp (unit, "K"))
+		return temp_K;
+	else if (0 == strcmp (unit, "C"))
+		return temp_C;
+	else if (0 == strcmp (unit, "F"))
+		return temp_F;
+	else if (0 == strcmp (unit, "Reau"))
+		return temp_Reau;
+	else if (0 == strcmp (unit, "Rank"))
+		return temp_Rank;
+	return temp_invalid;
+}
+
+static gboolean
+convert_temp (char const *from_unit, char const *to_unit, gnm_float n, GnmValue **v, GnmEvalPos const *ep)
+{
+	/* Temperature constants */
+	const gnm_float C_K_offset = GNM_const (273.15);
+
+	temp_types from_unit_type = convert_temp_unit (from_unit);
+	temp_types to_unit_type = convert_temp_unit (to_unit);
+
+	gnm_float nO = n;
+
+	if ((from_unit_type == temp_invalid) || (to_unit_type == temp_invalid))
+		return FALSE;
+
+	/* Convert from from_unit to K */
+	switch (from_unit_type) {
+	case temp_C:
+		n += C_K_offset;
+		break;
+	case temp_F:
+		n = (n - 32) * 5 / 9 + C_K_offset;
+		break;
+	case temp_Rank:
+		n = n * 5/9;
+		break;
+	case temp_Reau:
+		n = n * 5/4 + C_K_offset;
+		break;
+	default:
+		break;
+	}
+
+	/* temperatures below 0K do not exist */
+	if (n < 0.) {
+		*v = value_new_error_NUM (ep);
+		return TRUE;
+	}
+
+	if (from_unit_type == to_unit_type) {
+		*v = value_new_float (nO);
+		return TRUE;
+	}
+
+	/* Convert from K to to_unit */
+	switch (to_unit_type) {
+	case temp_C:
+		n -= C_K_offset;
+		break;
+	case temp_F:
+		n = (n - C_K_offset) * 9/5 + 32;
+		break;
+	case temp_Rank:
+		n = n * 9/5;
+		break;
+	case temp_Reau:
+		n = (n - C_K_offset) * 4/5;
+		break;
+	default:
+		break;
+	}
+
+	*v = value_new_float (n);
+
+	return TRUE;
+}
+
 static GnmValue *
 gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 {
         /* Weight and mass constants */
-#define one_g_to_sg     0.00006852205001
-#define one_g_to_lbm    0.002204622915
-#define one_g_to_u      6.02217e+23
-#define one_g_to_ozm    0.035273972
+#define one_g_to_cwt    (one_g_to_lbm/100)  /* exact relative definition */
+#define one_g_to_grain  (one_g_to_lbm*7000) /* exact relative definition */
+#define one_g_to_uk_cwt (one_g_to_lbm/112)  /* exact relative definition */
+#define one_g_to_uk_ton (one_g_to_lbm/2240) /* exact relative definition */
+#define one_g_to_stone  (one_g_to_lbm/14)   /* exact relative definition */
+#define one_g_to_ton    (one_g_to_lbm/2000) /* exact relative definition */
+#define one_g_to_sg     GNM_const (0.00006852205001)
+#define one_g_to_lbm    (1/GNM_const (453.59237)) /* exact definition */
+#define one_g_to_u      GNM_const (6.02217e+23)
+#define one_g_to_ozm    (one_g_to_lbm*16)   /* exact relative definition */
 
 	/* Distance constants */
 #define one_m_to_mi     (one_m_to_yd / 1760)
+#define one_m_to_survey_mi (1 / GNM_const (1609.347218694))
 #define one_m_to_Nmi    (1 / GNM_const (1852.0))
 #define one_m_to_in     (10000 / GNM_const (254.0))
 #define one_m_to_ft     (one_m_to_in / 12)
 #define one_m_to_yd     (one_m_to_ft / 3)
+#define one_m_to_ell    (one_m_to_in / 45)
 #define one_m_to_ang    GNM_const (1e10)
+#define one_m_to_ly     (1 / GNM_const (9.4607304725808E15))
+#define one_m_to_pc     (GNM_const (1e-16)/GNM_const (3.0856776))
 #define one_m_to_pica   236.2204724409449
 #define one_m_to_Pica   one_m_to_pica * 12
 
@@ -830,13 +1032,18 @@ gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	/* Pressure constants */
 #define one_Pa_to_atm   0.9869233e-5
 #define one_Pa_to_mmHg  0.00750061708
+#define one_Pa_to_psi   0.000145037738
+#define one_Pa_to_Torr  (GNM_const (760)/GNM_const (101325))
 
 	/* Force constants */
 #define one_N_to_dyn    100000
 #define one_N_to_lbf    0.224808924
+#define one_N_to_pond   0.00010197
+
 
 	/* Power constants */
 #define one_HP_to_W     745.701
+#define one_PS_to_W     735.49875
 
 	/* Energy constants */
 #define one_J_to_e      9999995.193
@@ -851,17 +1058,57 @@ gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	/* Magnetism constants */
 #define one_T_to_ga     10000
 
-	/* Temperature constants */
-	const gnm_float C_K_offset = GNM_const (273.15);
-
 	/* Liquid measure constants */
+#define one_l_to_uk_gal (GNM_const (1.0) / GNM_const (4.54609))
+#define one_tsp_to_tspm (one_tsp_to_l/GNM_const (0.005))
 #define one_tsp_to_tbs  (GNM_const (1.0) / 3)
 #define one_tsp_to_oz   (GNM_const (1.0) / 6)
 #define one_tsp_to_cup  (GNM_const (1.0) / 48)
 #define one_tsp_to_pt   (GNM_const (1.0) / 96)
+#define one_tsp_to_uk_pt (one_tsp_to_l * one_l_to_uk_gal * 8)
 #define one_tsp_to_qt   (GNM_const (1.0) / 192)
+#define one_tsp_to_uk_qt (one_tsp_to_l * one_l_to_uk_gal * 2)
 #define one_tsp_to_gal  (GNM_const (1.0) / 768)
-#define one_tsp_to_l    0.004929994
+#define one_tsp_to_uk_gal (one_tsp_to_l * one_l_to_uk_gal)
+#define one_tsp_to_l    GNM_const (0.004928921593749999)
+#define one_tsp_to_ang3 (one_tsp_to_l * GNM_const (1E-27))
+#define one_tsp_to_barrel (one_tsp_to_gal / 42)
+#define one_tsp_to_bushel (one_tsp_to_gal / GNM_const (9.3092))
+#define one_tsp_to_grt  (one_tsp_to_cubic_ft / 100)
+#define one_tsp_to_mton  (one_tsp_to_cubic_ft / 40)
+#define one_tsp_to_cubic_m  (one_tsp_to_l / 1000)
+#define one_tsp_to_cubic_ft (one_tsp_to_cubic_m * one_m_to_ft * one_m_to_ft * one_m_to_ft)
+#define one_tsp_to_cubic_in (one_tsp_to_cubic_m * one_m_to_in * one_m_to_in * one_m_to_in)
+#define one_tsp_to_cubic_ly (one_tsp_to_cubic_m * one_m_to_ly * one_m_to_ly * one_m_to_ly)
+#define one_tsp_to_cubic_mi (one_tsp_to_cubic_m * one_m_to_mi * one_m_to_mi * one_m_to_mi)
+#define one_tsp_to_cubic_yd (one_tsp_to_cubic_m * one_m_to_yd * one_m_to_yd * one_m_to_yd)
+#define one_tsp_to_cubic_Nmi (one_tsp_to_cubic_m * one_m_to_Nmi * one_m_to_Nmi * one_m_to_Nmi)
+#define one_tsp_to_cubic_Pica (one_tsp_to_cubic_m * one_m_to_Pica * one_m_to_Pica * one_m_to_Pica)
+
+	/* Bits and Bytes */
+#define one_byte_to_bit 8
+
+	/* Area constants */
+#define one_m2_to_uk_acre     (1/GNM_const (4046.8564224))
+#define one_m2_to_us_acre     (1/(4046 + GNM_const (13525426.)/15499969))
+#define one_m2_to_ang2        (one_m_to_ang * one_m_to_ang)
+#define one_m2_to_ar          GNM_const (0.01)
+#define one_m2_to_ha          (one_m2_to_ar / hecto)
+#define one_m2_to_ft2         (one_m_to_ft * one_m_to_ft)
+#define one_m2_to_in2         (one_m_to_in * one_m_to_in)
+#define one_m2_to_ly2         (one_m_to_ly * one_m_to_ly)
+#define one_m2_to_mi2         (one_m_to_mi * one_m_to_mi)
+#define one_m2_to_Nmi2        (one_m_to_Nmi * one_m_to_Nmi)
+#define one_m2_to_yd2         (one_m_to_yd * one_m_to_yd)
+#define one_m2_to_Pica2       (one_m_to_Pica * one_m_to_Pica)
+#define one_m2_to_Morgen      (one_m2_to_ha * 4)
+
+	/* Speed constants */
+#define one_mh_to_kn          one_m_to_Nmi
+#define one_mh_to_admkn       (1/GNM_const (1853.184))
+#define one_mh_to_msec        (GNM_const (1.0)/(60*60))
+#define one_mh_to_mph          one_m_to_mi
+
 
 	/* Prefixes */
 #define yotta  GNM_const (1e+24)
@@ -885,24 +1132,51 @@ gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 #define zepto  GNM_const (1e-21)
 #define yocto  GNM_const (1e-24)
 
+	/* Binary Prefixes */
+#define yobi  (zebi * kibi)
+#define zebi  (exbi * kibi)
+#define exbi  (pebi * kibi)
+#define pebi  (tebi * kibi)
+#define tebi  (gibi * kibi)
+#define gibi  (mebi * kibi)
+#define mebi  (kibi * kibi)
+#define kibi  GNM_const (1024.0)
+
 	static const eng_convert_unit_t weight_units[] = {
 	        { "g",    1.0 },
+		{ "brton",one_g_to_uk_ton },
+		{ "cwt",  one_g_to_cwt },
+		{ "grain",one_g_to_grain },
+		{ "hweight",one_g_to_uk_cwt },
+		{ "LTON",one_g_to_uk_ton },
 		{ "sg",   one_g_to_sg },
+		{ "shweight",one_g_to_cwt },
 		{ "lbm",  one_g_to_lbm },
+		{ "lcwt", one_g_to_uk_cwt },
 		{ "u",    one_g_to_u },
+		{ "uk_cwt",one_g_to_uk_cwt },
+		{ "uk_ton",one_g_to_uk_ton },
 		{ "ozm",  one_g_to_ozm },
+		{ "stone",one_g_to_stone },
+		{ "ton",  one_g_to_ton },
 		{ NULL,   0.0 }
 	};
 
 	static const eng_convert_unit_t distance_units[] = {
 	        { "m",    1.0 },
 		{ "mi",   one_m_to_mi },
+		{ "survey_mi", one_m_to_survey_mi},
 		{ "Nmi",  one_m_to_Nmi },
 		{ "in",   one_m_to_in },
 		{ "ft",   one_m_to_ft },
 		{ "yd",   one_m_to_yd },
+		{ "ell",  one_m_to_ell },
 		{ "ang",  one_m_to_ang },
+		{ "pc",   one_m_to_pc },
+		{ "parsec", one_m_to_pc },
+		{ "ly",   one_m_to_ly },
 		{ "Pica", one_m_to_Pica },
+		{ "Picapt", one_m_to_Pica },
 		{ "picapt", one_m_to_Pica },
 		{ "pica", one_m_to_pica },
 		{ NULL,   0.0 }
@@ -919,14 +1193,17 @@ gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 	static const eng_convert_unit_t pressure_units[] = {
 	        { "Pa",   1.0 },
+		{ "psi",  one_Pa_to_psi },
 		{ "atm",  one_Pa_to_atm },
 		{ "mmHg", one_Pa_to_mmHg },
+		{ "Torr", one_Pa_to_Torr },
 		{ NULL,   0.0 }
 	};
 
 	static const eng_convert_unit_t force_units[] = {
 	        { "N",    1.0 },
 		{ "dyn",  one_N_to_dyn },
+		{ "pond", one_N_to_pond },
 		{ "lbf",  one_N_to_lbf },
 		{ NULL,   0.0 }
 	};
@@ -946,6 +1223,7 @@ gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 	static const eng_convert_unit_t power_units[] = {
 	        { "HP",   1.0 },
+		{ "PS",   one_HP_to_W/one_PS_to_W },
 		{ "W",    one_HP_to_W },
 		{ NULL,   0.0 }
 	};
@@ -958,13 +1236,91 @@ gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 
 	static const eng_convert_unit_t liquid_units[] = {
 	        { "tsp",  1.0 },
+		{ "tspm", one_tsp_to_tspm },
 		{ "tbs",  one_tsp_to_tbs },
 		{ "oz",   one_tsp_to_oz },
 		{ "cup",  one_tsp_to_cup },
 		{ "pt",   one_tsp_to_pt },
 		{ "qt",   one_tsp_to_qt },
+		{ "uk_qt", one_tsp_to_uk_qt },
 		{ "gal",  one_tsp_to_gal },
+		{ "uk_gal", one_tsp_to_uk_gal },
+		{ "us_pt",one_tsp_to_pt },
+		{ "uk_pt",one_tsp_to_uk_pt },
 		{ "l",    one_tsp_to_l },
+		{ "L",    one_tsp_to_l },
+		{ "lt",   one_tsp_to_l },
+		{ "ang3", one_tsp_to_ang3 },
+		{ "ang^3", one_tsp_to_ang3 },
+		{ "bushel", one_tsp_to_bushel },
+		{ "barrel", one_tsp_to_barrel },
+		{ "GRT", one_tsp_to_grt },
+		{ "regton", one_tsp_to_grt },
+		{ "MTON", one_tsp_to_mton },
+		{ "ft3", one_tsp_to_cubic_ft},
+		{ "ft^3", one_tsp_to_cubic_ft},
+		{ "in3", one_tsp_to_cubic_in},
+		{ "in^3", one_tsp_to_cubic_in},
+		{ "ly3", one_tsp_to_cubic_ly},
+		{ "ly^3", one_tsp_to_cubic_ly},
+		{ "m3", one_tsp_to_cubic_m},
+		{ "m^3", one_tsp_to_cubic_m},
+		{ "mi3", one_tsp_to_cubic_mi},
+		{ "mi^3", one_tsp_to_cubic_mi},
+		{ "yd3", one_tsp_to_cubic_yd},
+		{ "yd^3", one_tsp_to_cubic_yd},
+		{ "Nmi3", one_tsp_to_cubic_Nmi},
+		{ "Nmi^3", one_tsp_to_cubic_Nmi},
+		{ "Pica3", one_tsp_to_cubic_Pica},
+		{ "Pica^3", one_tsp_to_cubic_Pica},
+		{ "Picapt3", one_tsp_to_cubic_Pica},
+		{ "Picapt^3", one_tsp_to_cubic_Pica},
+		{ NULL,   0.0 }
+	};
+
+	static const eng_convert_unit_t information_units[] = {
+	        { "byte",    1.0 },
+		{ "bit",  one_byte_to_bit},
+		{ NULL,   0.0 }
+	};
+
+	static const eng_convert_unit_t speed_units[] = {
+		{ "m/h", 1.0 },
+		{ "m/hr", 1.0 },
+		{ "admkn", one_mh_to_admkn },
+		{ "kn", one_mh_to_kn },
+		{ "m/s", one_mh_to_msec },
+		{ "m/sec", one_mh_to_msec },
+		{ "mph", one_mh_to_mph },
+		{ NULL,   0.0 }
+	};
+
+	static const eng_convert_unit_t area_units[] = {
+		{ "m2", 1.0 },
+		{ "m^2", 1.0 },
+		{ "uk_acre", one_m2_to_uk_acre },
+		{ "us_acre", one_m2_to_us_acre },
+		{ "ang2", one_m2_to_ang2 },
+		{ "ang^2", one_m2_to_ang2 },
+		{ "ar", one_m2_to_ar },
+		{ "ha", one_m2_to_ha },
+		{ "in2", one_m2_to_in2 },
+		{ "in^2", one_m2_to_in2 },
+		{ "ft2", one_m2_to_ft2 },
+		{ "ft^2", one_m2_to_ft2 },
+		{ "ly2", one_m2_to_ly2 },
+		{ "ly^2", one_m2_to_ly2 },
+		{ "mi2", one_m2_to_mi2 },
+		{ "mi^2", one_m2_to_mi2 },
+		{ "Nmi2", one_m2_to_Nmi2 },
+		{ "Nmi^2", one_m2_to_Nmi2 },
+		{ "yd2", one_m2_to_yd2 },
+		{ "yd^2", one_m2_to_yd2 },
+		{ "Picapt2", one_m2_to_Pica2 },
+		{ "Picapt^2", one_m2_to_Pica2 },
+		{ "Pica2", one_m2_to_Pica2 },
+		{ "Pica^2", one_m2_to_Pica2 },
+		{ "Morgen", one_m2_to_Morgen },
 		{ NULL,   0.0 }
 	};
 
@@ -991,6 +1347,17 @@ gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	        { "y", yocto },
 		{ NULL,0.0 }
 	};
+	static const eng_convert_unit_t binary_prefixes[] = {
+	        { "Yi", yobi },
+	        { "Zi", zebi },
+	        { "Ei", exbi },
+	        { "Pi", pebi },
+	        { "Ti", tebi },
+	        { "Gi", gibi },
+	        { "Mi", mebi },
+	        { "ki", kibi },
+		{ NULL,0.0 }
+	};
 
 	gnm_float n;
 	char const *from_unit, *to_unit;
@@ -1000,20 +1367,8 @@ gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	from_unit = value_peek_string (argv[1]);
 	to_unit = value_peek_string (argv[2]);
 
-	if (strcmp (from_unit, "C") == 0 && strcmp (to_unit, "F") == 0)
-	        return value_new_float (n * 9 / 5 + 32);
-	else if (strcmp (from_unit, "F") == 0 && strcmp (to_unit, "C") == 0)
-	        return value_new_float ((n - 32) * 5 / 9);
-	else if (strcmp (from_unit, "F") == 0 && strcmp (to_unit, "F") == 0)
-	        return value_new_float (n);
-	else if (strcmp (from_unit, "F") == 0 && strcmp (to_unit, "K") == 0)
-	        return value_new_float ((n - 32) * 5 / 9 + C_K_offset);
-	else if (strcmp (from_unit, "K") == 0 && strcmp (to_unit, "F") == 0)
-	        return value_new_float ((n - C_K_offset) * 9 / 5 + 32);
-	else if (strcmp (from_unit, "C") == 0 && strcmp (to_unit, "K") == 0)
-	        return value_new_float (n + C_K_offset);
-	else if (strcmp (from_unit, "K") == 0 && strcmp (to_unit, "C") == 0)
-	        return value_new_float (n - C_K_offset);
+	if (convert_temp (from_unit, to_unit, n, &v, ei->pos))
+	        return v;
 
 	if (convert (weight_units, prefixes, from_unit, to_unit, n, &v,
 		     ei->pos))
@@ -1042,7 +1397,16 @@ gnumeric_convert (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 	if (convert (liquid_units, prefixes, from_unit, to_unit, n, &v,
 		     ei->pos))
 	        return v;
-	if (convert (magnetism_units, prefixes, from_unit, to_unit, n, &v,
+	if (convert (information_units, prefixes, from_unit, to_unit, n, &v,
+		     ei->pos))
+	        return v;
+	if (convert (information_units, binary_prefixes, from_unit, to_unit, n, &v,
+		     ei->pos))
+	        return v;
+	if (convert (speed_units, prefixes, from_unit, to_unit, n, &v,
+		     ei->pos))
+	        return v;
+	if (convert (area_units, prefixes, from_unit, to_unit, n, &v,
 		     ei->pos))
 	        return v;
 
