@@ -35,9 +35,7 @@
 #include <gtk/gtk.h>
 
 #define GNM_APP(o)		(G_TYPE_CHECK_INSTANCE_CAST((o), GNM_APP_TYPE, GnmApp))
-#define GNM_APP_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k),	 GNM_APP_TYPE, GnmAppClass))
-#define IS_GNM_APP(o)		(G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_APP_TYPE))
-#define IS_GNM_APP_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE((k),	 GNM_APP_TYPE))
+#define GNM_IS_APP(o)		(G_TYPE_CHECK_INSTANCE_TYPE((o), GNM_APP_TYPE))
 
 enum {
 	APPLICATION_PROP_0,
@@ -113,7 +111,7 @@ gnm_app_get_app (void)
 void
 gnm_app_workbook_list_add (Workbook *wb)
 {
-	g_return_if_fail (IS_WORKBOOK (wb));
+	g_return_if_fail (GNM_IS_WORKBOOK (wb));
 	g_return_if_fail (app != NULL);
 
 	app->workbook_list = g_list_prepend (app->workbook_list, wb);
@@ -188,11 +186,11 @@ gnm_app_clipboard_clear (gboolean drop_selection)
 		app->clipboard_copied_contents = NULL;
 	}
 	if (app->clipboard_sheet_view != NULL) {
-		sv_unant (app->clipboard_sheet_view);
+		gnm_sheet_view_unant (app->clipboard_sheet_view);
 
 		g_signal_emit (G_OBJECT (app), signals[CLIPBOARD_MODIFIED], 0);
 
-		sv_weak_unref (&(app->clipboard_sheet_view));
+		gnm_sheet_view_weak_unref (&(app->clipboard_sheet_view));
 
 		/* Release the selection */
 		if (drop_selection)
@@ -216,7 +214,7 @@ gnm_app_clipboard_unant (void)
 	g_return_if_fail (app != NULL);
 
 	if (app->clipboard_sheet_view != NULL)
-		sv_unant (app->clipboard_sheet_view);
+		gnm_sheet_view_unant (app->clipboard_sheet_view);
 }
 
 /**
@@ -246,7 +244,7 @@ gnm_app_clipboard_cut_copy (WorkbookControl *wbc, gboolean is_cut,
 {
 	Sheet *sheet;
 
-	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (GNM_IS_SHEET_VIEW (sv));
 	g_return_if_fail (area != NULL);
 	g_return_if_fail (app != NULL);
 
@@ -254,14 +252,14 @@ gnm_app_clipboard_cut_copy (WorkbookControl *wbc, gboolean is_cut,
 	sheet = sv_sheet (sv);
 	g_free (app->clipboard_cut_range);
 	app->clipboard_cut_range = gnm_range_dup (area);
-	sv_weak_ref (sv, &(app->clipboard_sheet_view));
+	gnm_sheet_view_weak_ref (sv, &(app->clipboard_sheet_view));
 
 	if (!is_cut)
 		app->clipboard_copied_contents =
 			clipboard_copy_range (sheet, area);
 	if (animate_cursor) {
 		GList *l = g_list_append (NULL, (gpointer)area);
-		sv_ant (sv, l);
+		gnm_sheet_view_ant (sv, l);
 		g_list_free (l);
 	}
 
@@ -286,14 +284,14 @@ void
 gnm_app_clipboard_cut_copy_obj (WorkbookControl *wbc, gboolean is_cut,
 				SheetView *sv, GSList *objects)
 {
-	g_return_if_fail (IS_SHEET_VIEW (sv));
+	g_return_if_fail (GNM_IS_SHEET_VIEW (sv));
 	g_return_if_fail (objects != NULL);
 	g_return_if_fail (app != NULL);
 
 	gnm_app_clipboard_clear (FALSE);
 	g_free (app->clipboard_cut_range);
 	app->clipboard_cut_range = NULL;
-	sv_weak_ref (sv, &(app->clipboard_sheet_view));
+	gnm_sheet_view_weak_ref (sv, &(app->clipboard_sheet_view));
 	app->clipboard_copied_contents
 		= clipboard_copy_obj (sv_sheet (sv), objects);
 	if (is_cut) {
@@ -605,7 +603,7 @@ compare_mru (GtkRecentInfo *a, GtkRecentInfo *b)
  *
  * creating it if necessary.
  *
- * Return value: (element-type char) (transfer full): the list, which must be
+ * Return value: (element-type utf8) (transfer full): the list, which must be
  * freed along with the strings in it.
  **/
 GSList *
@@ -764,7 +762,7 @@ gnm_app_class_init (GObjectClass *gobject_klass)
 		G_STRUCT_OFFSET (GnmAppClass, workbook_added),
 		NULL, NULL,
 		g_cclosure_marshal_VOID__OBJECT,
-		G_TYPE_NONE, 1, WORKBOOK_TYPE);
+		G_TYPE_NONE, 1, GNM_WORKBOOK_TYPE);
 	signals[WORKBOOK_REMOVED] = g_signal_new ("workbook_removed",
 		GNM_APP_TYPE,
 		G_SIGNAL_RUN_LAST,
@@ -911,6 +909,14 @@ gnm_action_get_type (void)
 static GnmAppExtraUI *
 gnm_app_extra_ui_ref (GnmAppExtraUI *ui)
 {
+	// Nothing
+	return ui;
+}
+
+static GnmAppExtraUI *
+gnm_app_extra_ui_unref (GnmAppExtraUI *ui)
+{
+	// Nothing
 	return ui;
 }
 
@@ -922,7 +928,7 @@ gnm_app_extra_ui_get_type (void)
 	if (t == 0) {
 		t = g_boxed_type_register_static ("GnmAppExtraUI",
 			 (GBoxedCopyFunc)gnm_app_extra_ui_ref,
-			 (GBoxedFreeFunc)gnm_app_extra_ui_ref);
+			 (GBoxedFreeFunc)gnm_app_extra_ui_unref);
 	}
 	return t;
 }
