@@ -86,9 +86,7 @@ gnm_cell_copy_get_type (void)
 static GnmPasteTarget *
 gnm_paste_target_copy (GnmPasteTarget *pt)
 {
-	GnmPasteTarget *res = g_new (GnmPasteTarget, 1);
-	memcpy (res, pt, sizeof (GnmPasteTarget));
-	return res;
+	return g_memdup (pt, sizeof (*pt));
 }
 
 GType
@@ -104,6 +102,15 @@ gnm_paste_target_get_type (void)
 	return t;
 }
 
+GnmPasteTarget *
+gnm_paste_target_new (Sheet *sheet, GnmRange *r, GnmPasteFlags flags)
+{
+	GnmPasteTarget *res = g_new (GnmPasteTarget, 1);
+	paste_target_init (res, sheet, r, flags);
+	return res;
+}
+
+
 static gboolean
 cell_has_expr_or_number_or_blank (GnmCell const * cell)
 {
@@ -246,10 +253,10 @@ struct paste_cell_data {
  * paste_cell:
  * @target_col:  Column to put the cell into
  * @target_row:  Row to put the cell into.
- * @src:         A #GnmCelCopy with the content to paste
+ * @src:         A #GnmCellCopy with the content to paste
  * @paste_flags: Bit mask that describes the paste options.
  *
- *  Pastes a cell in the spreadsheet.
+ * Pastes a cell in the spreadsheet.
  */
 static void
 paste_cell (int target_col, int target_row,
@@ -283,7 +290,7 @@ paste_cell (int target_col, int target_row,
 						 value_dup (src->val), TRUE);
 			if (NULL != relo)
 				gnm_expr_top_unref (relo);
-		} else {
+		} else if (src->val) {
 			GnmValue *newval = NULL;
 			GnmValue const *oldval = src->val;
 
@@ -403,14 +410,14 @@ range_flip_v (GnmRange *range, Sheet const *sheet, int const *data)
  * clipboard_paste_region:
  * @cr: The GnmCellRegion to paste.
  * @pt: Where to paste the values.
- * @cc: The context for error handling.
+ * @cc: (nullable): The context for error handling.
  *
  * Pastes the supplied GnmCellRegion (@cr) into the supplied
  * GnmPasteTarget (@pt).  This operation is not undoable.  It does not auto grow
  * the destination if the target is a singleton.  This is a simple interface to
  * paste a region.
  *
- * returns : TRUE if there was a problem.
+ * Returns: %TRUE if there was a problem.
  **/
 gboolean
 clipboard_paste_region (GnmCellRegion const *cr,
@@ -425,6 +432,7 @@ clipboard_paste_region (GnmCellRegion const *cr,
 	gboolean has_contents, adjust_merges = TRUE;
 	struct paste_cell_data dat;
 	GnmRange const *merge_src;
+	gboolean no_flipping, do_col_widths, do_row_heights;
 
 	g_return_val_if_fail (pt != NULL, TRUE);
 	g_return_val_if_fail (cr != NULL, TRUE);
@@ -447,8 +455,6 @@ clipboard_paste_region (GnmCellRegion const *cr,
 	src_cols = cr->cols;
 	src_rows = cr->rows;
 
-
-
 	/* If the source is a single cell or a single merge */
 	/* Treat a target of a single merge specially, don't split the merge */
 	if ((src_cols == 1 && src_rows == 1) ||
@@ -476,9 +482,11 @@ clipboard_paste_region (GnmCellRegion const *cr,
 	}
 
 	if (cr->not_as_contents && (pt->paste_flags & PASTE_CONTENTS)) {
-		go_cmd_context_error_invalid (cc,
-					_("Unable to paste"),
-					_("Contents can only be pasted by value or by link."));
+		if (cc)
+			go_cmd_context_error_invalid
+				(cc,
+				 _("Unable to paste"),
+				 _("Contents can only be pasted by value or by link."));
 		return TRUE;
 	}
 
@@ -489,7 +497,8 @@ clipboard_paste_region (GnmCellRegion const *cr,
 			_("destination does not have an even multiple of source columns (%d vs %d)\n\n"
 			  "Try selecting a single cell or an area of the same shape and size."),
 			dst_cols, src_cols);
-		go_cmd_context_error_invalid (cc, _("Unable to paste"), msg);
+		if (cc)
+			go_cmd_context_error_invalid (cc, _("Unable to paste"), msg);
 		g_free (msg);
 		return TRUE;
 	}
@@ -500,16 +509,19 @@ clipboard_paste_region (GnmCellRegion const *cr,
 			_("destination does not have an even multiple of source rows (%d vs %d)\n\n"
 			  "Try selecting a single cell or an area of the same shape and size."),
 			dst_rows, src_rows);
-		go_cmd_context_error_invalid (cc, _("Unable to paste"), msg);
+		if (cc)
+			go_cmd_context_error_invalid (cc, _("Unable to paste"), msg);
 		g_free (msg);
 		return TRUE;
 	}
 
 	if ((pt->range.start.col + dst_cols) > gnm_sheet_get_max_cols (pt->sheet) ||
 	    (pt->range.start.row + dst_rows) > gnm_sheet_get_max_rows (pt->sheet)) {
-		go_cmd_context_error_invalid (cc,
-					_("Unable to paste"),
-					_("result passes the sheet boundary"));
+		if (cc)
+			go_cmd_context_error_invalid
+				(cc,
+				 _("Unable to paste"),
+				 _("result passes the sheet boundary"));
 		return TRUE;
 	}
 
@@ -619,6 +631,35 @@ clipboard_paste_region (GnmCellRegion const *cr,
 					paste_object (pt, ptr->data, left, top);
 		}
 
+	no_flipping = (pt->paste_flags & (PASTE_FLIP_H | PASTE_FLIP_V | PASTE_TRANSPOSE)) == 0;
+	do_col_widths =
+		no_flipping &&
+		((pt->paste_flags & PASTE_COLUMN_WIDTHS) ||
+		 ((pt->paste_flags & PASTE_COLUMN_WIDTHS_AUTO) &&
+		  cr->origin_sheet &&
+		  src_rows == gnm_sheet_get_max_rows (cr->origin_sheet)));
+	if (do_col_widths) {
+		int i;
+		for (i = 0; i < repeat_horizontal; i++) {
+			int first = pt->range.start.col + i * src_cols;
+			colrow_set_states (pt->sheet, TRUE, first, cr->col_state);
+		}
+	}
+
+	do_row_heights =
+		no_flipping &&
+		((pt->paste_flags & PASTE_ROW_HEIGHTS) ||
+		 ((pt->paste_flags & PASTE_ROW_HEIGHTS_AUTO) &&
+		  cr->origin_sheet &&
+		  src_cols == gnm_sheet_get_max_cols (cr->origin_sheet)));
+	if (do_row_heights) {
+		int i;
+		for (i = 0; i < repeat_vertical; i++) {
+			int first = pt->range.start.row + i * src_rows;
+			colrow_set_states (pt->sheet, FALSE, first, cr->row_state);
+		}
+	}
+
 	if (!(pt->paste_flags & PASTE_NO_RECALC)) {
 		if (has_contents) {
 			sheet_region_queue_recalc (pt->sheet, r);
@@ -628,8 +669,6 @@ clipboard_paste_region (GnmCellRegion const *cr,
 
 		sheet_range_calc_spans (pt->sheet, r,
 					(pt->paste_flags & PASTE_FORMATS) ? GNM_SPANCALC_RE_RENDER : GNM_SPANCALC_RENDER);
-		if (pt->paste_flags & PASTE_UPDATE_ROW_HEIGHT)
-			rows_height_update (pt->sheet, &pt->range, FALSE);
 		sheet_redraw_all (pt->sheet, FALSE);
 	}
 
@@ -699,10 +738,9 @@ clipboard_copy_range (Sheet *sheet, GnmRange const *r)
 	cr->row_state = colrow_get_states (sheet,
 		FALSE, r->start.row, r->end.row);
 
-	sheet_foreach_cell_in_range ( sheet, CELL_ITER_IGNORE_NONEXISTENT,
-		r->start.col, r->start.row,
-		r->end.col, r->end.row,
-		(CellIterFunc) cb_clipboard_prepend_cell, cr);
+	sheet_foreach_cell_in_range ( sheet, CELL_ITER_IGNORE_NONEXISTENT, r,
+				      (CellIterFunc) cb_clipboard_prepend_cell,
+				      cr);
 	objects = sheet_objects_get (sheet, r, G_TYPE_NONE);
 	g_slist_foreach (objects, (GFunc)cb_dup_objects, cr);
 	g_slist_free (objects);
@@ -732,7 +770,8 @@ cb_clipboard_copy_range_undo (GnmCellRegion *cr, GnmSheetRange *sr,
 				    sr->sheet,
 				    &sr->range,
 				    PASTE_CONTENTS | PASTE_FORMATS |
-				    PASTE_OBJECTS | PASTE_COMMENTS),
+				    PASTE_OBJECTS | PASTE_COMMENTS |
+				    PASTE_COLUMN_WIDTHS | PASTE_ROW_HEIGHTS),
 		 cc);
 }
 
@@ -834,16 +873,17 @@ clipboard_copy_obj (Sheet *sheet, GSList *objects)
 }
 
 GnmPasteTarget*
-paste_target_init (GnmPasteTarget *pt, Sheet *sheet, GnmRange const *r, int flags)
+paste_target_init (GnmPasteTarget *pt, Sheet *sheet,
+		   GnmRange const *r, GnmPasteFlags flags)
 {
-	pt->sheet = sheet;
+	pt->sheet = sheet; // No ref
 	pt->range = *r;
 	pt->paste_flags = flags;
 	return pt;
 }
 
 /**
- * gnm_cell_region_new :
+ * gnm_cell_region_new:
  * @origin_sheet: optionally NULL.
  *
  * A convenience routine to create CellRegions and init the flags nicely.
@@ -869,11 +909,12 @@ gnm_cell_region_new (Sheet *origin_sheet)
 	return cr;
 }
 
-void
+GnmCellRegion *
 cellregion_ref (GnmCellRegion *cr)
 {
-	g_return_if_fail (cr != NULL);
+	g_return_val_if_fail (cr != NULL, NULL);
 	cr->ref_count++;
+	return cr;
 }
 
 void
@@ -957,7 +998,7 @@ cb_invalidate_cellcopy (GnmCellCopy *cc, gconstpointer ignore,
 }
 
 /**
- * cellregion_invalidate_sheet :
+ * cellregion_invalidate_sheet:
  * @cr: #GnmCellRegion
  * @sheet: #Sheet
  *
@@ -1170,6 +1211,9 @@ gnm_cell_copy_new (GnmCellRegion *cr, int col_offset, int row_offset)
 	return res;
 }
 
+/**
+ * clipboard_init: (skip)
+ */
 void
 clipboard_init (void)
 {
@@ -1190,6 +1234,9 @@ cb_cell_copy_pool_leak (gpointer data, G_GNUC_UNUSED gpointer user)
 }
 #endif
 
+/**
+ * clipboard_shutdown: (skip)
+ */
 void
 clipboard_shutdown (void)
 {
