@@ -268,7 +268,7 @@ find_column_of_field (GnmEvalPos const *ep,
 }
 
 void
-free_criteria (GnmCriteria *criteria)
+gnm_criteria_unref (GnmCriteria *criteria)
 {
 	if (!criteria || criteria->ref_count-- > 1)
 		return;
@@ -293,7 +293,7 @@ gnm_criteria_get_type (void)
 	if (t == 0) {
 		t = g_boxed_type_register_static ("GnmCriteria",
 			 (GBoxedCopyFunc)gnm_criteria_ref,
-			 (GBoxedFreeFunc)free_criteria);
+			 (GBoxedFreeFunc)gnm_criteria_unref);
 	}
 	return t;
 }
@@ -312,7 +312,7 @@ free_criterias (GSList *criterias)
         while (criterias != NULL) {
 		GnmDBCriteria *criteria = criterias->data;
 		g_slist_free_full (criteria->conditions,
-				      (GFreeFunc)free_criteria);
+				      (GFreeFunc)gnm_criteria_unref);
 		g_free (criteria);
 		criterias = criterias->next;
 	}
@@ -587,9 +587,15 @@ filter_row:
  * @fun: (scope call): function to evaluate on filtered data
  * @err: error value in case @fun fails.
  * @ep: evaluation position
- * @flags:
+ * @flags: #CollectFlags flags describing the collection and interpretation
+ * of values from @data.
+ *
+ * This implements a Gnumeric sheet database function of the "*IFS" type
+ * This function collects the arguments and uses @fun to do
+ * the actual computation.
+ *
+ * Returns: (transfer full): Function result or error value.
  */
-
 GnmValue *
 gnm_ifs_func (GPtrArray *data, GPtrArray *crits, GnmValue const *vals,
 	      float_range_function_t fun, GnmStdError err,
