@@ -16,8 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
@@ -52,7 +51,7 @@ enum {
 	SOURCE_COLUMN,
 	PIXMAP_COLUMN,
 	IS_EDITABLE_COLUMN,
-	NUM_COLMNS
+	NUM_COLUMNS
 };
 
 typedef struct {
@@ -413,7 +412,7 @@ setup_widgets (ConsolidateState *state, GtkBuilder *gui)
 						(gui,
 						 "source_treeview"));
 	state->source_areas = GTK_TREE_MODEL(gtk_list_store_new
-						 (NUM_COLMNS,
+						 (NUM_COLUMNS,
 						  G_TYPE_STRING,
 						  GDK_TYPE_PIXBUF,
 						  G_TYPE_INT));
