@@ -20,8 +20,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
@@ -93,7 +92,7 @@ enum {
 	ITEM_PASTABLE,
 	ITEM_PASTE_IMAGE,
 	ITEM_VISIBLE,
-	NUM_COLMNS
+	NUM_COLUMNS
 };
 
 typedef enum {
@@ -1074,7 +1073,7 @@ name_guru_init (NameGuruState *state, WBCGtk *wbcg, gboolean is_paste_dialog)
 					   state->wbcg,
 					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
 	state->model	 = gtk_tree_store_new
-		(NUM_COLMNS,
+		(NUM_COLUMNS,
 		 G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING,
 		 G_TYPE_INT, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN,
 		 GDK_TYPE_PIXBUF, GDK_TYPE_PIXBUF,
