@@ -46,7 +46,7 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
-#define F2(func,s) dgettext ((func)->textdomain->str, (s))
+#define F2(func,s) dgettext ((func)->tdomain->str, (s))
 
 #define FUNCTION_SELECT_KEY "function-selector-dialog"
 #define FUNCTION_SELECT_HELP_KEY "function-selector-dialog-help-mode"
@@ -96,7 +96,7 @@ enum {
 	CAT_NAME,
 	CATEGORY,
 	CAT_SEPARATOR,
-	NUM_COLMNS
+	NUM_CAT_COLUMNS
 };
 enum {
 	FUN_NAME,
@@ -641,7 +641,8 @@ cb_link_event (GtkTextTag *link, G_GNUC_UNUSED GObject *trigger,
 }
 
 static char *
-make_expr_example (Sheet *sheet, const char *text, gboolean localized)
+make_expr_example (Sheet *sheet, const char *text,
+		   gboolean localized, gboolean consider_format)
 {
 	GnmLocale *oldlocale = NULL;
 	GnmExprTop const *texpr;
@@ -649,6 +650,22 @@ make_expr_example (Sheet *sheet, const char *text, gboolean localized)
 	GnmParsePos pp;
 	GnmEvalPos ep;
 	GnmConventions const *convs = gnm_conventions_default;
+	char *tmp_text = NULL;
+	GOFormat const *fmt = NULL;
+
+	if (consider_format &&
+	    g_ascii_strncasecmp (text, "TEXT(", 5) == 0 &&
+	    text[strlen(text) - 1] == ')') {
+		char *p;
+		tmp_text = g_strdup (text + 5);
+		p = tmp_text + strlen (tmp_text) - 1;
+		while (p >= tmp_text && p[0] != '"') p--;
+		p[0] = 0;
+		while (p >= tmp_text && p[0] != '"') p--;
+		fmt = go_format_new_from_XL (p + 1);
+		while (p >= tmp_text && p[0] != ',') p--;
+		*p = 0;
+	}
 
 	eval_pos_init_sheet (&ep, sheet);
 	parse_pos_init_evalpos (&pp, &ep);
@@ -666,12 +683,13 @@ make_expr_example (Sheet *sheet, const char *text, gboolean localized)
 		char *etxt = gnm_expr_top_as_string (texpr, &pp, convs);
 		GnmValue *val = gnm_expr_top_eval
 			(texpr, &ep, GNM_EXPR_EVAL_PERMIT_NON_SCALAR);
-		GOFormat const *format = gnm_auto_style_format_suggest (texpr, &ep);
-		char *vtxt = format_value (format, val, -1,
-					   workbook_date_conv
-					   (sheet->workbook));
+		char *vtxt;
+
+		if (!fmt)
+			fmt = gnm_auto_style_format_suggest (texpr, &ep);
+		vtxt = format_value (fmt, val, -1,
+				     workbook_date_conv (sheet->workbook));
 
-		go_format_unref (format);
 		gnm_expr_top_unref (texpr);
 		value_release (val);
 
@@ -684,6 +702,9 @@ make_expr_example (Sheet *sheet, const char *text, gboolean localized)
 		res = g_strdup ("");
 	}
 
+	g_free (tmp_text);
+	go_format_unref (fmt);
+
 	return res;
 }
 
@@ -698,7 +719,7 @@ make_expr_example (Sheet *sheet, const char *text, gboolean localized)
 			if (at != NULL) { ADD_BOLD_TEXT(t, at - t); t = at + 1; } else {ADD_TEXT (t); break;}}}
 #define FINISH_ARGS if (seen_args && !args_finished) {\
 	gint min, max; \
-	function_def_count_args (func, &min, &max);\
+	gnm_func_count_args (func, &min, &max);\
 		if (max == G_MAXINT) {	\
 			ADD_BOLD_TEXT(UNICODE_ELLIPSIS, strlen(UNICODE_ELLIPSIS)); \
 			ADD_LTEXT("\n",1);				\
@@ -722,6 +743,8 @@ describe_new_style (GtkTextBuffer *description,
 	gboolean args_finished = FALSE;
 	gboolean seen_examples = FALSE;
 	gboolean seen_extref = FALSE;
+	gboolean is_TEXT =
+		g_ascii_strcasecmp (gnm_func_get_name (func, FALSE), "TEXT") == 0;
 
 	gtk_text_buffer_get_end_iter (description, &ti);
 
@@ -786,7 +809,10 @@ describe_new_style (GtkTextBuffer *description,
 			}
 
 			if (text[0] == '=') {
-				char *example = make_expr_example (sheet, text + 1, was_translated);
+				char *example =
+					make_expr_example (sheet, text + 1,
+							   was_translated,
+							   !is_TEXT);
 				ADD_TEXT (example);
 				g_free (example);
 			} else {
@@ -1200,7 +1226,7 @@ dialog_function_select_init (FunctionSelectState *state)
 	state->cb = GTK_COMBO_BOX
 		(go_gtk_builder_get_widget (state->gui, "category-box"));
 	state->model = gtk_list_store_new
-		(NUM_COLMNS, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_BOOLEAN);
+		(NUM_CAT_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_BOOLEAN);
 
 	gtk_combo_box_set_model (state->cb, GTK_TREE_MODEL (state->model));
 	g_object_unref (state->model);
