@@ -19,8 +19,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
@@ -66,7 +65,7 @@ typedef struct {
 enum {
 	DATA_RANGE,
 	FIELD_LOCATION,
-	NUM_COLMNS
+	NUM_COLUMNS
 };
 
 static void
@@ -292,7 +291,7 @@ cb_merge_merge_clicked (G_GNUC_UNUSED GtkWidget *ignore,
 
 	}
 
-	if (!cmd_merge_data (WORKBOOK_CONTROL (state->wbcg), state->sheet,
+	if (!cmd_merge_data (GNM_WBC (state->wbcg), state->sheet,
 			     v_zone, field_list, data_list))
 		gtk_widget_destroy (state->dialog);
 }
@@ -320,7 +319,7 @@ dialog_merge (WBCGtk *wbcg)
 
 	g_return_if_fail (wbcg != NULL);
 
-	if (gnumeric_dialog_raise_if_exists (wbcg, MERGE_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, MERGE_KEY))
 		return;
 	gui = gnm_gtk_builder_load ("merge.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
@@ -329,7 +328,7 @@ dialog_merge (WBCGtk *wbcg)
 	state = g_new0 (MergeState, 1);
 	state->gui = gui;
 	state->wbcg = wbcg;
-	state->sheet = wb_control_cur_sheet (WORKBOOK_CONTROL (state->wbcg));
+	state->sheet = wb_control_cur_sheet (GNM_WBC (state->wbcg));
 	state->dialog     = go_gtk_builder_get_widget (gui, "Merge");
 	state->warning_dialog = NULL;
 
@@ -347,14 +346,14 @@ dialog_merge (WBCGtk *wbcg)
 	grid = GTK_GRID (go_gtk_builder_get_widget (gui, "main-grid"));
 	state->zone = gnm_expr_entry_new (wbcg, TRUE);
 	gnm_expr_entry_set_flags (state->zone, GNM_EE_SINGLE_RANGE, GNM_EE_MASK);
-	gnumeric_editable_enters (GTK_WINDOW (state->dialog),
+	gnm_editable_enters (GTK_WINDOW (state->dialog),
 				  GTK_WIDGET (state->zone));
 	gtk_label_set_mnemonic_widget (GTK_LABEL (go_gtk_builder_get_widget (gui, "var1-label")),
 				       GTK_WIDGET (state->zone));
 	gtk_widget_set_hexpand (GTK_WIDGET (state->zone), TRUE);
 	gtk_grid_attach (grid, GTK_WIDGET (state->zone), 1, 0, 2, 1);
 	r = selection_first_range (
-		wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg)), NULL, NULL);
+		wb_control_cur_sheet_view (GNM_WBC (wbcg)), NULL, NULL);
 	if (r != NULL)
 		gnm_expr_entry_load_from_range (state->zone,
 			state->sheet, r);
@@ -370,7 +369,7 @@ dialog_merge (WBCGtk *wbcg)
 	gtk_grid_attach (grid, GTK_WIDGET (state->field), 1, 5, 1, 1);
 
 	scrolled = go_gtk_builder_get_widget (state->gui, "scrolled");
-	state->model = gtk_list_store_new (NUM_COLMNS, G_TYPE_STRING, G_TYPE_STRING);
+	state->model = gtk_list_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING);
 	state->list = GTK_TREE_VIEW (gtk_tree_view_new_with_model
 					   (GTK_TREE_MODEL (state->model)));
 	selection = gtk_tree_view_get_selection (state->list);
@@ -429,11 +428,11 @@ dialog_merge (WBCGtk *wbcg)
 					   state->wbcg,
 					   GNM_DIALOG_DESTROY_CURRENT_SHEET_REMOVED);
 
-	gnumeric_init_help_button (
+	gnm_init_help_button (
 		go_gtk_builder_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_DATA_MERGE);
 
-	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
+	gnm_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
 			       MERGE_KEY);
 
 	/* a candidate for merging into attach guru */
