@@ -597,11 +597,11 @@ gnm_go_data_vector_load_len (GODataVector *dat)
 			vec->as_col = (vec->val->v_array.y > vec->val->v_array.x);
 			break;
 		}
-		case VALUE_ERROR :
+		case VALUE_ERROR:
 			new_len = 0;
 			break;
 
-		default :
+		default:
 			new_len = 1;
 			vec->as_col = TRUE;
 		}
@@ -724,9 +724,10 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 				                                (CellIterFunc)cb_assign_val,
 				                                &closure);
 			else
-				sheet_foreach_cell_in_range (start_sheet, CELL_ITER_IGNORE_FILTERED,
-					r.start.col, r.start.row, r.end.col, r.end.row,
-					(CellIterFunc)cb_assign_val, &closure);
+				sheet_foreach_cell_in_range
+					(start_sheet, CELL_ITER_IGNORE_FILTERED,
+					 &r,
+					 (CellIterFunc)cb_assign_val, &closure);
 			dat->len = closure.last + 1; /* clip */
 			minimum = closure.minimum;
 			maximum = closure.maximum;
@@ -774,9 +775,10 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 								                (CellIterFunc)cb_assign_val,
 								                &closure);
 					else
-						sheet_foreach_cell_in_range (start_sheet, CELL_ITER_IGNORE_FILTERED,
-							r.start.col, r.start.row, r.end.col, r.end.row,
-							(CellIterFunc)cb_assign_val, &closure);
+						sheet_foreach_cell_in_range (start_sheet,
+									     CELL_ITER_IGNORE_FILTERED,
+									     &r,
+									     (CellIterFunc)cb_assign_val, &closure);
 					last = dat->len = closure.last + 1; /* clip */
 					if (minimum > closure.minimum)
 					    minimum = closure.minimum;
@@ -807,7 +809,7 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 		break;
 	}
 
-	case VALUE_STRING :
+	case VALUE_STRING:
 		v = format_match_number (value_peek_string (vec->val),
 					 NULL,
 					 closure.date_conv);
@@ -818,11 +820,11 @@ gnm_go_data_vector_load_values (GODataVector *dat)
 		}
 		/* fall through to errors */
 
-	case VALUE_EMPTY :
-	case VALUE_ERROR :
+	case VALUE_EMPTY:
+	case VALUE_ERROR:
 		minimum = maximum = vals[0] = go_nan;
 		break;
-	default :
+	default:
 		minimum = maximum = vals[0] = value_get_as_float (vec->val);
 		break;
 	}
@@ -937,9 +939,10 @@ gnm_go_data_vector_get_str (GODataVector *dat, unsigned i)
 						r.end.col = start_sheet->cols.max_used;
 
 					if (r.start.col <= r.end.col && r.start.row <= r.end.row)
-						sheet_foreach_cell_in_range (start_sheet, CELL_ITER_IGNORE_FILTERED,
-							r.start.col, r.start.row, r.end.col, r.end.row,
-							(CellIterFunc)cb_assign_string, &closure);
+						sheet_foreach_cell_in_range (start_sheet,
+									     CELL_ITER_IGNORE_FILTERED,
+									     &r,
+									     (CellIterFunc)cb_assign_string, &closure);
 				}
 			}
 		}
@@ -966,9 +969,10 @@ gnm_go_data_vector_get_str (GODataVector *dat, unsigned i)
 				r.end.col = start_sheet->cols.max_used;
 
 			if (r.start.col <= r.end.col && r.start.row <= r.end.row)
-				sheet_foreach_cell_in_range (start_sheet, CELL_ITER_IGNORE_FILTERED,
-					r.start.col, r.start.row, r.end.col, r.end.row,
-					(CellIterFunc)cb_assign_string, &closure);
+				sheet_foreach_cell_in_range (start_sheet,
+							     CELL_ITER_IGNORE_FILTERED,
+							     &r,
+							     (CellIterFunc)cb_assign_string, &closure);
 		}
 		if (vec->strs && vec->strs->len > i)
 			ret = g_ptr_array_index (vec->strs, i);
@@ -1038,9 +1042,10 @@ gnm_go_data_vector_get_markup (GODataVector *dat, unsigned i)
 
 			/* In case the sheet is empty */
 			if (r.start.col <= r.end.col && r.start.row <= r.end.row) {
-				sheet_foreach_cell_in_range (start_sheet, CELL_ITER_ALL,
-					r.start.col, r.start.row, r.end.col, r.end.row,
-					(CellIterFunc)cb_assign_markup, vec->markup);
+				sheet_foreach_cell_in_range (start_sheet,
+							     CELL_ITER_ALL,
+							     &r,
+							     (CellIterFunc)cb_assign_markup, vec->markup);
 			}
 			break;
 
@@ -1064,9 +1069,10 @@ gnm_go_data_vector_get_markup (GODataVector *dat, unsigned i)
 						r.end.col = start_sheet->cols.max_used;
 
 					if (r.start.col <= r.end.col && r.start.row <= r.end.row)
-						sheet_foreach_cell_in_range (start_sheet, CELL_ITER_ALL,
-							r.start.col, r.start.row, r.end.col, r.end.row,
-							(CellIterFunc)cb_assign_markup, vec->markup);
+						sheet_foreach_cell_in_range (start_sheet,
+									     CELL_ITER_ALL,
+									     &r,
+									     (CellIterFunc)cb_assign_markup, vec->markup);
 				}
 			}
 			break;
@@ -1210,12 +1216,12 @@ gnm_go_data_matrix_load_size (GODataMatrix *dat)
 			}
 			break;
 
-		case VALUE_ARRAY :
+		case VALUE_ARRAY:
 			dat->size.rows = mat->val->v_array.y;
 			dat->size.columns = mat->val->v_array.x;
 			break;
 
-		default :
+		default:
 			dat->size.rows = 1;
 			dat->size.columns = 1;
 		}
@@ -1333,7 +1339,7 @@ gnm_go_data_matrix_load_values (GODataMatrix *dat)
 			closure.first_col = closure.last_col = -1;
 			closure.row = closure.col = 0;
 			closure.columns = dat->size.columns;
-			sheet_foreach_cell_in_range (start_sheet, CELL_ITER_ALL,
+			sheet_foreach_cell_in_region (start_sheet, CELL_ITER_ALL,
 				r.start.col, r.start.row,
 				r.start.col + dat->size.columns - 1,
 				r.start.row + dat->size.rows - 1,
@@ -1347,7 +1353,7 @@ gnm_go_data_matrix_load_values (GODataMatrix *dat)
 			minimum = maximum = vals[0] = go_nan;
 		break;
 
-	case VALUE_ARRAY :
+	case VALUE_ARRAY:
 		maximum = - G_MAXDOUBLE;
 		minimum = G_MAXDOUBLE;
 		for (col = 0; col < size.columns; col ++)
@@ -1378,7 +1384,7 @@ gnm_go_data_matrix_load_values (GODataMatrix *dat)
 			minimum = maximum = go_nan;
 		break;
 
-	case VALUE_STRING :
+	case VALUE_STRING:
 		v = format_match_number (value_peek_string (mat->val),
 					 NULL,
 					 closure.date_conv);
@@ -1390,11 +1396,11 @@ gnm_go_data_matrix_load_values (GODataMatrix *dat)
 		}
 		/* fall through to errors */
 
-	case VALUE_EMPTY :
-	case VALUE_ERROR :
+	case VALUE_EMPTY:
+	case VALUE_ERROR:
 		minimum = maximum = vals[0] = go_nan;
 		break;
-	default :
+	default:
 		vals[0] = value_get_as_float (mat->val);
 		minimum = maximum = go_nan;
 		break;
