@@ -761,23 +761,23 @@ item_cursor_do_action (GnmItemCursor *ic, ActionType action)
 
 	switch (action) {
 	case ACTION_COPY_CELLS:
-		if (!sv_selection_copy (sv, wbc))
+		if (!gnm_sheet_view_selection_copy (sv, wbc))
 			break;
 		cmd_paste (wbc,
 			   paste_target_init (&pt, sheet, &ic->pos,
-					      PASTE_ALL_TYPES));
+					      PASTE_ALL_CELL));
 		break;
 
 	case ACTION_MOVE_CELLS:
-		if (!sv_selection_cut (sv, wbc))
+		if (!gnm_sheet_view_selection_cut (sv, wbc))
 			break;
 		cmd_paste (wbc,
 			   paste_target_init (&pt, sheet, &ic->pos,
-					      PASTE_ALL_TYPES));
+					      PASTE_ALL_CELL));
 		break;
 
 	case ACTION_COPY_FORMATS:
-		if (!sv_selection_copy (sv, wbc))
+		if (!gnm_sheet_view_selection_copy (sv, wbc))
 			break;
 		cmd_paste (wbc,
 			   paste_target_init (&pt, sheet, &ic->pos,
@@ -785,7 +785,7 @@ item_cursor_do_action (GnmItemCursor *ic, ActionType action)
 		break;
 
 	case ACTION_COPY_VALUES:
-		if (!sv_selection_copy (sv, wbc))
+		if (!gnm_sheet_view_selection_copy (sv, wbc))
 			break;
 		cmd_paste (wbc,
 			   paste_target_init (&pt, sheet, &ic->pos,
@@ -799,7 +799,7 @@ item_cursor_do_action (GnmItemCursor *ic, ActionType action)
 		g_warning ("Operation not yet implemented.");
 		break;
 
-	default :
+	default:
 		g_warning ("Invalid Operation %d.", action);
 	}
 
@@ -1443,7 +1443,7 @@ item_cursor_set_property (GObject *obj, guint param_id,
 	case ITEM_CURSOR_PROP_STYLE:
 		ic->style = g_value_get_int (value);
 		break;
-	case ITEM_CURSOR_PROP_BUTTON :
+	case ITEM_CURSOR_PROP_BUTTON:
 		ic->drag_button = g_value_get_int (value);
 		break;
 	case ITEM_CURSOR_PROP_COLOR:
