@@ -31,7 +31,6 @@
 #include "parse-util.h"
 #include "mstyle.h"
 #include "style-conditions.h"
-#include "gnm-style-impl.h"	/* cheesy */
 #include "position.h"		/* to eval conditions */
 #include "style-border.h"
 #include "style-color.h"
@@ -283,6 +282,7 @@ item_grid_draw_merged_range (cairo_t *cr, GnmItemGrid *ig,
 	Sheet const *sheet  = sv->sheet;
 	GnmCell const *cell = sheet_cell_get (sheet, range->start.col, range->start.row);
 	int const dir = sheet->text_is_rtl ? -1 : 1;
+	GnmStyleConditions *conds;
 
 	/* load style from corner which may not be visible */
 	GnmStyle const *style = sheet_style_get (sheet, range->start.col, range->start.row);
@@ -311,12 +311,13 @@ item_grid_draw_merged_range (cairo_t *cr, GnmItemGrid *ig,
 	if (l == r || t == b)
 		return;
 
-	if (style->conditions) {
+	conds = gnm_style_get_conditions (style);
+	if (conds) {
 		GnmEvalPos ep;
 		int res;
 		eval_pos_init (&ep, (Sheet *)sheet, range->start.col, range->start.row);
-		if ((res = gnm_style_conditions_eval (style->conditions, &ep)) >= 0)
-			style = g_ptr_array_index (style->cond_styles, res);
+		if ((res = gnm_style_conditions_eval (conds, &ep)) >= 0)
+			style = gnm_style_get_cond_style (style, res);
 	}
 
 	/* Check for background THEN selection */
@@ -990,7 +991,7 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 					      (already_selected && (event->button.state & GDK_CONTROL_MASK)) ?
 					      GNM_SELECTION_MODE_REMOVE :
 					      GNM_SELECTION_MODE_ADD);
-			sv_make_cell_visible (sv, pos.col, pos.row, FALSE);
+			gnm_sheet_view_make_cell_visible (sv, pos.col, pos.row, FALSE);
 		} else sv_selection_extend_to (sv, pos.col, pos.row);
 		sheet_update (sheet);
 	}
@@ -1027,7 +1028,7 @@ item_grid_button_pressed (GocItem *item, int button, double x_, double y_)
 
 	case 3: scg_context_menu (scg, event, FALSE, FALSE);
 		break;
-	default :
+	default:
 		break;
 	}
 
@@ -1116,10 +1117,10 @@ item_grid_motion (GocItem *item, double x_, double y_)
 		ig->last_x = x;
 		ig->last_y = y;
 		return TRUE;
-	case GNM_ITEM_GRID_SELECTING_CELL_RANGE :
+	case GNM_ITEM_GRID_SELECTING_CELL_RANGE:
 		slide_handler = &cb_extend_cell_range;
 		break;
-	case GNM_ITEM_GRID_SELECTING_FORMULA_RANGE :
+	case GNM_ITEM_GRID_SELECTING_FORMULA_RANGE:
 		slide_handler = &cb_extend_expr_range;
 		break;
 	default:
@@ -1151,13 +1152,13 @@ item_grid_button_released (GocItem *item, int button, G_GNUC_UNUSED double x_, G
 	case GNM_ITEM_GRID_NO_SELECTION:
 		return TRUE;
 
-	case GNM_ITEM_GRID_SELECTING_FORMULA_RANGE :
+	case GNM_ITEM_GRID_SELECTING_FORMULA_RANGE:
 /*  Removal of this code (2 lines)                                                */
 /*  should fix http://bugzilla.gnome.org/show_bug.cgi?id=63485                    */
 /*			sheet_make_cell_visible (sheet,                           */
 /*				sheet->edit_pos.col, sheet->edit_pos.row, FALSE); */
 		/* Fall through */
-	case GNM_ITEM_GRID_SELECTING_CELL_RANGE :
+	case GNM_ITEM_GRID_SELECTING_CELL_RANGE:
 		sv_selection_simplify (scg_view (scg));
 		wb_view_selection_desc (
 			wb_control_view (scg_wbc (scg)), TRUE, NULL);
@@ -1236,11 +1237,11 @@ item_grid_set_property (GObject *obj, guint param_id,
 	GnmRange const *r;
 
 	switch (param_id) {
-	case GNM_ITEM_GRID_PROP_SHEET_CONTROL_GUI :
+	case GNM_ITEM_GRID_PROP_SHEET_CONTROL_GUI:
 		ig->scg = g_value_get_object (value);
 		break;
 
-	case GNM_ITEM_GRID_PROP_BOUND :
+	case GNM_ITEM_GRID_PROP_BOUND:
 		r = g_value_get_pointer (value);
 		g_return_if_fail (r != NULL);
 		ig->bound =  *r;
