@@ -46,14 +46,13 @@
 #include <string.h>
 #include <locale.h>
 
-static gboolean split_funcdocs = FALSE;
+#ifdef HAVE_FPU_CONTROL_H
+#include <fpu_control.h>
+#endif
+
 static gboolean immediate_exit_flag = FALSE;
 static gboolean gnumeric_no_splash = FALSE;
 static gboolean gnumeric_no_warnings = FALSE;
-static gchar  *func_def_file = NULL;
-static gchar  *func_state_file = NULL;
-static gchar  *ext_refs_file = NULL;
-static gchar  *samples_file = NULL;
 static gchar  *geometry = NULL;
 static gchar **startup_files;
 
@@ -73,36 +72,6 @@ static const GOptionEntry gnumeric_options [] = {
 
 	/*********************************
 	 * Hidden Actions */
-	{
-		"dump-func-defs", 0,
-		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME, &func_def_file,
-		N_("Dumps the function definitions"),
-		N_("FILE")
-	},
-	{
-		"dump-func-state", 0,
-		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME, &func_state_file,
-		N_("Dumps the function definitions"),
-		N_("FILE")
-	},
-	{
-		"ext-refs-file", 0,
-		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME, &ext_refs_file,
-		N_("Dumps web page for function help"),
-		N_("FILE")
-	},
-	{
-		"samples-file", 0,
-		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME, &samples_file,
-		N_("Dumps list of samples in function help"),
-		N_("FILE")
-	},
-	{
-		"split-func", 0,
-		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &split_funcdocs,
-		N_("Generate new help and po files"),
-		NULL
-	},
 	{
 		"quit", 0,
 		G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &immediate_exit_flag,
@@ -138,17 +107,8 @@ static void
 gnumeric_arg_parse (int argc, char **argv)
 {
 	GOptionContext *ocontext;
-	int i;
-	gboolean funcdump = FALSE;
 	GError *error = NULL;
 
-	/* no need to init gtk when dumping function info */
-	for (i = 0 ; argv[i] ; i++)
-		if (0 == strncmp ("--dump-func", argv[i], 11)) {
-			funcdump = TRUE;
-			break;
-		}
-
 	ocontext = g_option_context_new (_("[FILE ...]"));
 	g_option_context_add_main_entries (ocontext, gnumeric_options, GETTEXT_PACKAGE);
 	g_option_context_add_group	  (ocontext, gnm_get_option_group ());
@@ -159,8 +119,7 @@ gnumeric_arg_parse (int argc, char **argv)
 	g_option_context_set_delocalize   (ocontext, FALSE);
 #endif
 
-	if (!funcdump)
-		g_option_context_add_group (ocontext, gtk_get_option_group (TRUE));
+	g_option_context_add_group (ocontext, gtk_get_option_group (TRUE));
 	g_option_context_parse (ocontext, &argc, &argv, &error);
 
 	if (ocontext)
@@ -173,9 +132,7 @@ gnumeric_arg_parse (int argc, char **argv)
 		exit (1);
 	}
 
-	if (!funcdump) {
-		gtk_init (&argc, &argv);
-	}
+	gtk_init (&argc, &argv);
 }
 
 /*
@@ -200,26 +157,6 @@ cb_kill_wbcg (WBCGtk *wbcg)
 	return FALSE;
 }
 
-static gboolean
-pathetic_qt_workaround (void)
-{
-	/*
-	 * When using with the Qt theme, the qt library will be initialized
-	 * somewhere around the time the first widget is created or maybe
-	 * realized.  That code literally does
-	 *
-	 *        setlocale( LC_NUMERIC, "C" );	// make sprintf()/scanf() work
-	 *
-	 * I am not kidding.  It seems like we can fix this by re-setting the
-	 * proper locale when the gui comes up.
-	 *
-	 * See bug 512752, for example.
-	 */
-	setlocale (LC_ALL, "");
-	return FALSE;
-}
-
-
 static void
 cb_workbook_removed (void)
 {
@@ -228,11 +165,31 @@ cb_workbook_removed (void)
 	}
 }
 
+static void
+cpu_sanity_check (void)
+{
+#if (defined(i386) || defined(__i386__) || defined(__i386) || defined(__x86_64__) || defined(__x86_64)) && HAVE_FPU_CONTROL_H
+	fpu_control_t state;
+	const fpu_control_t mask = _FPU_EXTENDED | _FPU_DOUBLE | _FPU_SINGLE;
+
+	_FPU_GETCW (state);
+	if ((state & mask) != _FPU_EXTENDED) {
+		// Evidently currentlly happinging when Windows runs Linux
+		// binaries.  See bug 794515.
+		g_warning ("Sanity check failed!  The cpu is not in \"extended\" mode as it should be.  Attempting to fix, but expect trouble.");
+		state = (state & ~mask) | _FPU_EXTENDED;
+		_FPU_SETCW (state);
+	}
+#else
+	// Hope for the best
+#endif
+}
+
+
 int
 main (int argc, char const **argv)
 {
 	gboolean opened_workbook = FALSE;
-	gboolean with_gui;
 	GOIOContext *ioc;
 	WorkbookView *wbv;
 	GSList *wbcgs_to_kill = NULL;
@@ -245,6 +202,8 @@ main (int argc, char const **argv)
 	/* No code before here, we need to init threads */
 	argv = gnm_pre_parse_init (argc, argv);
 
+	cpu_sanity_check ();
+
 	/*
 	 * Attempt to disable Ubuntu's funky, non-working scroll
 	 * bars.  This needs to be done before gtk starts loading
@@ -277,57 +236,31 @@ main (int argc, char const **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	bind_textdomain_codeset (GETTEXT_PACKAGE "-functions", "UTF-8");
 
-	with_gui = !func_def_file && !func_state_file && !split_funcdocs;
-
-	if (with_gui) {
-		gnm_session_init (argv[0]);
-	}
+	gnm_session_init (argv[0]);
 
 	gnm_init ();
 
-	/* These are useful for the build process only.  */
-	if (func_state_file)
-		return gnm_dump_func_defs (func_state_file, 0);
-	if (func_def_file)
-		return gnm_dump_func_defs (func_def_file, 1);
-	if (split_funcdocs)
-		return gnm_dump_func_defs (NULL, 2);
-	if (ext_refs_file)
-		return gnm_dump_func_defs (ext_refs_file, 4);
-	if (samples_file)
-		return gnm_dump_func_defs (samples_file, 5);
+	cc = gnm_cmd_context_stderr_new ();
+	go_component_set_default_command_context (cc);
+	g_object_unref (cc);
 
-	if (with_gui) {
-		go_component_set_default_command_context (cc = gnm_cmd_context_stderr_new ());
-		g_object_unref (cc);
-		cc = g_object_new (GNM_TYPE_IO_CONTEXT_GTK,
-				   "show-splash", !gnumeric_no_splash,
-				   "show-warnings", !gnumeric_no_warnings,
-				   NULL);
-		ioc = GO_IO_CONTEXT (g_object_ref (cc));
-		handle_paint_events ();
-		pathetic_qt_workaround ();
-	} else {
-		/* TODO: Make this inconsistency go away */
-		cc = gnm_cmd_context_stderr_new ();
-		ioc = go_io_context_new (cc);
-		go_component_set_default_command_context (cc);
-	}
+	cc = g_object_new (GNM_TYPE_IO_CONTEXT_GTK,
+			   "show-splash", !gnumeric_no_splash,
+			   "show-warnings", !gnumeric_no_warnings,
+			   NULL);
+	ioc = GO_IO_CONTEXT (g_object_ref (cc));
+	handle_paint_events ();
 
 	/* Keep in sync with .desktop file */
 	g_set_application_name (_("Gnumeric Spreadsheet"));
 	gnm_plugins_init (GO_CMD_CONTEXT (ioc));
 
 	if (startup_files) {
-		int i;
+		int i, N;
 
-		for (i = 0; startup_files [i]; i++)
-			;
-
-		go_io_context_set_num_files (ioc, i);
-		for (i = 0;
-		     startup_files [i] && !initial_workbook_open_complete;
-		     i++) {
+		N = g_strv_length (startup_files);
+		go_io_context_set_num_files (ioc, N);
+		for (i = 0; i < N && !initial_workbook_open_complete; i++) {
 			char *uri = go_shell_arg_to_uri (startup_files[i]);
 
 			if (uri == NULL) {
@@ -397,7 +330,6 @@ main (int argc, char const **argv)
 		gnm_io_context_gtk_discharge_splash (GNM_IO_CONTEXT_GTK (ioc));
 		g_object_unref (ioc);
 
-		g_idle_add ((GSourceFunc)pathetic_qt_workaround, NULL);
 		gtk_main ();
 	} else {
 		g_object_unref (ioc);
@@ -424,7 +356,7 @@ main (int argc, char const **argv)
 	 * This helps finding leaks.  We might want it in developent
 	 * only.
 	 */
-	if (with_gui && gnm_debug_flag ("close-displays")) {
+	if (gnm_debug_flag ("close-displays")) {
 		GSList *displays;
 
 		gdk_flush();
