@@ -22,7 +22,6 @@
 #include "value.h"
 #include "style-border.h"
 #include "style-conditions.h"
-#include "gnm-style-impl.h"
 #include "pattern.h"
 #include "cellspan.h"
 #include "ranges.h"
@@ -217,6 +216,7 @@ print_merged_range_gtk (cairo_t *context,
 	int last;
 	GnmCell  const *cell = sheet_cell_get (sheet, range->start.col, range->start.row);
 	int const dir = sheet->text_is_rtl ? -1 : 1;
+	GnmStyleConditions *conds;
 
 	/* load style from corner which may not be visible */
 	GnmStyle const *style = sheet_style_get (sheet, range->start.col, range->start.row);
@@ -240,12 +240,13 @@ print_merged_range_gtk (cairo_t *context,
 	if (l == r || t == b)
 		return;
 
-	if (style->conditions) {
+	conds = gnm_style_get_conditions (style);
+	if (style) {
 		GnmEvalPos ep;
 		int res;
 		eval_pos_init (&ep, (Sheet *)sheet, range->start.col, range->start.row);
-		if ((res = gnm_style_conditions_eval (style->conditions, &ep)) >= 0)
-			style = g_ptr_array_index (style->cond_styles, res);
+		if ((res = gnm_style_conditions_eval (conds, &ep)) >= 0)
+			style = gnm_style_get_cond_style (style, res);
 	}
 
 	if (gnm_pattern_background_set (style, context, FALSE, NULL))
@@ -302,6 +303,7 @@ gnm_gtk_print_cell_range (cairo_t *context,
 	GnmStyle const **styles;
 	GnmBorder const **borders, **prev_vert;
 	GnmBorder const *none;
+	gpointer *sr_array_data;
 
 	int n, col, row;
 	double x, y, offset;
@@ -353,8 +355,9 @@ gnm_gtk_print_cell_range (cairo_t *context,
 	 * Note that this means that in some cases array [-1] is legal.
 	 */
 	n = end_col - start_col + 3; /* 1 before, 1 after, 1 fencepost */
+	sr_array_data = g_new (gpointer, n * 8);
 	style_row_init (&prev_vert, &sr, &next_sr, start_col, end_col,
-			g_alloca (n * 8 * sizeof (gpointer)), hide_grid);
+			sr_array_data, hide_grid);
 
 	/* load up the styles for the first row */
 	next_sr.row = sr.row = row = start_row;
@@ -610,6 +613,7 @@ gnm_gtk_print_cell_range (cairo_t *context,
 	g_slist_free (merged_used);	   /* merges with bottom in view */
 	g_slist_free (merged_active_seen); /* merges with bottom the view */
 	g_slist_free (merged_unused);	   /* merges in hidden rows */
+	g_free (sr_array_data);
 	g_return_if_fail (merged_active == NULL);
 }
 
