@@ -34,6 +34,15 @@
 #undef RANGE_DEBUG
 #define UNICODE_ELLIPSIS "\xe2\x80\xa6"
 
+/**
+ * range_init_full_sheet:
+ * @r: #GnmRange
+ * @sheet: #Sheet
+ *
+ * Updates @r to fill @sheet in its entirety.
+ *
+ * Returns: (transfer none): @r
+ */
 GnmRange *
 range_init_full_sheet (GnmRange *r, Sheet const *sheet)
 {
@@ -44,6 +53,17 @@ range_init_full_sheet (GnmRange *r, Sheet const *sheet)
 	return r;
 }
 
+/**
+ * range_init_cols:
+ * @r: #GnmRange
+ * @sheet: #Sheet
+ * @start_col: Starting column
+ * @end_col: Ending column
+ *
+ * Updates @r to span full columns @start_col through @end_col completely.
+ *
+ * Returns: (transfer none): @r
+ */
 GnmRange *
 range_init_cols (GnmRange *r, Sheet const *sheet, int start_col, int end_col)
 {
@@ -54,16 +74,17 @@ range_init_cols (GnmRange *r, Sheet const *sheet, int start_col, int end_col)
 	return r;
 }
 
-GnmRange *
-range_init_invalid (GnmRange *r)
-{
-	r->start.col = -1;
-	r->start.row = -1;
-	r->end.col = -2;
-	r->end.row = -2;
-	return r;
-}
-
+/**
+ * range_init_rows:
+ * @r: #GnmRange
+ * @sheet: #Sheet
+ * @start_row: Starting row
+ * @end_row: Ending row
+ *
+ * Updates @r to span full rows @start_row through @end_row completely.
+ *
+ * Returns: (transfer none): @r
+ */
 GnmRange *
 range_init_rows (GnmRange *r, Sheet const *sheet, int start_row, int end_row)
 {
@@ -74,6 +95,33 @@ range_init_rows (GnmRange *r, Sheet const *sheet, int start_row, int end_row)
 	return r;
 }
 
+/**
+ * range_init_invalid: (skip)
+ * @r: #GnmRange
+ *
+ * Updates @r to a meaningless range
+ *
+ * Returns: (transfer none): @r
+ */
+GnmRange *
+range_init_invalid (GnmRange *r)
+{
+	r->start.col = -1;
+	r->start.row = -1;
+	r->end.col = -2;
+	r->end.row = -2;
+	return r;
+}
+
+/**
+ * range_init_rangeref:
+ * @r: #GnmRange
+ * @rr: #GnmRangeRef
+ *
+ * Updates @r to be the same as the range part of @rr.
+ *
+ * Returns: (transfer none): @r
+ */
 GnmRange *
 range_init_rangeref (GnmRange *range, GnmRangeRef const *rr)
 {
@@ -87,6 +135,15 @@ range_init_rangeref (GnmRange *range, GnmRangeRef const *rr)
 }
 
 
+/**
+ * range_init_value:
+ * @r: A #GnmRange to change
+ * @v: A #GnmValue containing a cell range
+ *
+ * Updates @r to be the same as the cell range of @v.
+ *
+ * Returns: (transfer none) (nullable): @r
+ */
 GnmRange *
 range_init_value (GnmRange *range, GnmValue const *v)
 {
@@ -96,6 +153,15 @@ range_init_value (GnmRange *range, GnmValue const *v)
 	return range_init_rangeref (range, &v->v_range.cell);
 }
 
+/**
+ * range_init_cellpos:
+ * @r: A #GnmRange to change
+ * @pos: A #GnmCellPos
+ *
+ * Updates @r to be the singleton range of @pos
+ *
+ * Returns: (transfer none): @r
+ */
 GnmRange *
 range_init_cellpos (GnmRange *r, GnmCellPos const *pos)
 {
@@ -104,6 +170,18 @@ range_init_cellpos (GnmRange *r, GnmCellPos const *pos)
 
 	return r;
 }
+
+/**
+ * range_init_cellpos_size:
+ * @r: A #GnmRange to change
+ * @start: A #GnmCellPos for the upper left corner of the desired range
+ * @cols: number of columns
+ * @rows: number of rows
+ *
+ * Updates @r to start at @start and spanning @cols columns and @rows rows.
+ *
+ * Returns: (transfer none): @r
+ */
 GnmRange *
 range_init_cellpos_size (GnmRange *r,
 			 GnmCellPos const *start, int cols, int rows)
@@ -115,6 +193,19 @@ range_init_cellpos_size (GnmRange *r,
 	return r;
 }
 
+/**
+ * range_init:
+ * @r: A #GnmRange to change
+ * @start_col: Column
+ * @start_row: Row
+ * @end_col: Column
+ * @end_row: Row
+ *
+ * Updates @r to start at (@start_col,@start_row) and end
+ * at (@end_col,@end_row).
+ *
+ * Returns: (transfer none): @r
+ */
 GnmRange *
 range_init (GnmRange *r, int start_col, int start_row,
 	    int end_col, int end_row)
@@ -130,14 +221,15 @@ range_init (GnmRange *r, int start_col, int start_row,
 }
 
 /**
- * range_parse :
+ * range_parse:
  * @r: #GnmRange
- * @text:
+ * @text: text to parse
+ * @ss: #GnmSheetSize describing the size of the sheet in which @r lives.
  *
  * Parse a simple range (no abs/rel refs, no sheet refs)
- * Store the result in @res.
+ * Store the result in @r.
  *
- * Returns TRUE on success.
+ * Returns: %TRUE on success.
  **/
 gboolean
 range_parse (GnmRange *r, char const *text, GnmSheetSize const *ss)
@@ -160,7 +252,7 @@ range_parse (GnmRange *r, char const *text, GnmSheetSize const *ss)
 
 /**
  * range_list_destroy:
- * @ranges: (element-type GnmValue) (transfer full):  a list of value ranges
+ * @ranges: (element-type GnmValue) (transfer full): a list of value ranges
  * to destroy.
  *
  * Destroys a list of ranges returned from parse_cell_range_list
@@ -179,19 +271,25 @@ range_list_destroy (GSList *ranges)
 }
 
 
+/**
+ * range_as_string:
+ * @r: A #GnmRange
+ *
+ * Returns: (transfer none): a string repesentation of @src
+ **/
 char const *
-range_as_string (GnmRange const *src)
+range_as_string (GnmRange const *r)
 {
 	static char buffer[(6 + 4 * sizeof (long)) * 2 + 1];
 
-	g_return_val_if_fail (src != NULL, "");
+	g_return_val_if_fail (r != NULL, "");
 
 	sprintf (buffer, "%s%s",
-		 col_name (src->start.col), row_name (src->start.row));
+		 col_name (r->start.col), row_name (r->start.row));
 
-	if (src->start.col != src->end.col || src->start.row != src->end.row)
+	if (r->start.col != r->end.col || r->start.row != r->end.row)
 		sprintf (buffer + strlen(buffer), ":%s%s",
-			 col_name (src->end.col), row_name (src->end.row));
+			 col_name (r->end.col), row_name (r->end.row));
 
 	return buffer;
 }
@@ -440,8 +538,8 @@ gnm_range_dup (GnmRange const *a)
 
 /**
  * range_fragment:
- * @a: GnmRange a
- * @b: GnmRange b
+ * @a: #GnmRange a
+ * @b: #GnmRange b
  *
  * Fragments the ranges into totaly non-overlapping regions,
  *
@@ -479,13 +577,15 @@ range_fragment (GnmRange const *a, GnmRange const *b)
  *
  * NB. totally commutative
  *
- * Return value: True if the ranges intersect, false otherwise
+ * Return value: %TRUE if the ranges intersect, %FALSE otherwise
  **/
 gboolean
 range_intersection (GnmRange *r, GnmRange const *a, GnmRange const *b)
 {
-	if (!range_overlap (a, b))
+	if (!range_overlap (a, b)) {
+		*r = *a; // Something
 		return FALSE;
+	}
 
 	r->start.col = MAX (a->start.col, b->start.col);
 	r->start.row = MAX (a->start.row, b->start.row);
@@ -560,6 +660,12 @@ range_union (GnmRange const *a, GnmRange const *b)
 	return ans;
 }
 
+/**
+ * range_is_singleton:
+ * @r: the range.
+ *
+ * Returns: %TRUE if @r is a single-cell range.
+ */
 gboolean
 range_is_singleton (GnmRange const *r)
 {
@@ -567,15 +673,15 @@ range_is_singleton (GnmRange const *r)
 }
 
 /**
- * range_is_full :
+ * range_is_full:
  * @r: the range.
  * @sheet: the sheet in which @r lives
- * @horiz: TRUE to check for a horizontal full ref (_cols_ [0..MAX))
+ * @horiz: %TRUE to check for a horizontal full ref (_cols_ [0..MAX))
  *
  * This determines whether @r completely spans a sheet
  * in the dimension specified by @horiz.
  *
- * Return value: TRUE if it is infinite else FALSE
+ * Return value: %TRUE if it is infinite else %FALSE.
  **/
 gboolean
 range_is_full (GnmRange const *r, Sheet const *sheet, gboolean horiz)
@@ -589,7 +695,7 @@ range_is_full (GnmRange const *r, Sheet const *sheet, gboolean horiz)
 }
 
 /**
- * range_clip_to_finite :
+ * range_clip_to_finite:
  * @range:
  * @sheet: the sheet in which @range lives
  *
@@ -667,7 +773,7 @@ range_translate (GnmRange *range, Sheet const *sheet, int col_offset, int row_of
 }
 
 /**
- * range_ensure_sanity :
+ * range_ensure_sanity:
  * @range: the range to check
  * @sheet: the sheet in which @range lives
  *
@@ -685,7 +791,7 @@ range_ensure_sanity (GnmRange *range, Sheet const *sheet)
 }
 
 /**
- * range_is_sane :
+ * range_is_sane:
  * @range: the range to check
  *
  * Generate warnings if the range is out of bounds or inverted.
@@ -710,7 +816,7 @@ range_is_sane (GnmRange const *range)
  * @sheet: the sheet in which @range lives
  * @origin: The box to transpose inside
  *
- *   Effectively mirrors the ranges in 'boundary' around a
+ * Effectively mirrors the ranges in 'boundary' around a
  * leading diagonal projected from offset.
  *
  * Return value: whether we clipped the range.
@@ -829,11 +935,13 @@ gnm_sheet_range_dup (GnmSheetRange const *sr)
 }
 
 /**
- * gnm_sheet_range_from_value :
- * @r:
- * @v:
+ * gnm_sheet_range_from_value:
+ * @r: #GnmSheetRange to change
+ * @v: #GnmValue containing a cell range.
  *
- * Convert @v into a GnmSheetRange and return in @r
+ * Convert @v into a GnmSheetRange.
+ *
+ * Returns: %TRUE
  **/
 gboolean
 gnm_sheet_range_from_value (GnmSheetRange *r, GnmValue const *v)
@@ -1042,8 +1150,7 @@ undo_range_list_name (Sheet const *sheet, GSList const *ranges)
  * Parses a list of ranges, relative to the @sheet and returns a list with the
  * results.
  *
- * Returns: (element-type GnmValue) (transfer full): a GSList containing
- * Values of type VALUE_CELLRANGE, or NULL on failure
+ * Returns: (element-type GnmValue) (transfer full): a #GSList of #GnmValue.
  **/
 GSList *
 global_range_list_parse (Sheet *sheet, char const *str)
