@@ -33,7 +33,6 @@
 #include "style-font.h"
 #include "style-border.h"
 #include "style-conditions.h"
-#include "gnm-style-impl.h"
 #include "sheet.h"
 #include "sheet-merge.h"
 #include "gnm-format.h"
@@ -245,6 +244,7 @@ gnm_rendered_value_new (GnmCell const *cell,
 	PangoDirection dir;
 	char const *text;
 	gboolean debug = debug_rv ();
+	GnmStyleConditions *conds;
 
 	g_return_val_if_fail (cell != NULL, NULL);
 
@@ -271,14 +271,15 @@ gnm_rendered_value_new (GnmCell const *cell,
 
 	mstyle = gnm_cell_get_style (cell);
 
-	if (mstyle->conditions) {
+	conds = gnm_style_get_conditions (mstyle);
+	if (conds) {
 		GnmEvalPos ep;
 		int res;
 		eval_pos_init_cell (&ep, cell);
 
-		res = gnm_style_conditions_eval (mstyle->conditions, &ep);
+		res = gnm_style_conditions_eval (conds, &ep);
 		if (res >= 0)
-			mstyle = g_ptr_array_index (mstyle->cond_styles, res);
+			mstyle = gnm_style_get_cond_style (mstyle, res);
 	}
 
 	rotation = gnm_style_get_rotation (mstyle);
@@ -535,6 +536,10 @@ gnm_rendered_value_new (GnmCell const *cell,
 		break;
 
 	case GNM_HALIGN_DISTRIBUTED:
+		pango_layout_set_justify (layout, TRUE);
+		pango_layout_set_alignment (layout, PANGO_ALIGN_CENTER);
+		break;
+
 	case GNM_HALIGN_CENTER:
 	case GNM_HALIGN_CENTER_ACROSS_SELECTION:
 		pango_layout_set_alignment (layout, PANGO_ALIGN_CENTER);
@@ -567,65 +572,6 @@ gnm_rendered_value_destroy (GnmRenderedValue *rv)
 		CHUNK_FREE (rendered_value_pool, rv);
 }
 
-/**
- * gnm_rendered_value_recontext: (skip)
- * @rv: #GnmRenderedValue
- * @context: the new Pango context.
- *
- * Returns:
- **/
-GnmRenderedValue *
-gnm_rendered_value_recontext (GnmRenderedValue *rv, PangoContext *context)
-{
-	GnmRenderedValue *res;
-	PangoLayout *layout, *olayout;
-
-	if (rv->rotation) {
-		GnmRenderedRotatedValue *rres =
-			CHUNK_ALLOC (GnmRenderedRotatedValue, rendered_rotated_value_pool);
-		res = (GnmRenderedValue *)rres;
-
-		*rres = *(GnmRenderedRotatedValue *)rv;
-		rres->lines = g_memdup (rres->lines,
-					rres->linecount * sizeof (struct GnmRenderedRotatedValueInfo));
-	} else {
-		res = CHUNK_ALLOC (GnmRenderedValue, rendered_value_pool);
-		*res = *rv;
-	}
-
-	res->layout = layout = pango_layout_new (context);
-	olayout = rv->layout;
-
-	pango_layout_set_text (layout, pango_layout_get_text (olayout), -1);
-	pango_layout_set_alignment (layout, pango_layout_get_alignment (olayout));
-	pango_layout_set_attributes (layout, pango_layout_get_attributes (olayout));
-	pango_layout_set_single_paragraph_mode (layout, pango_layout_get_single_paragraph_mode (olayout));
-	pango_layout_set_justify (layout, pango_layout_get_justify (olayout));
-	pango_layout_set_width (layout, pango_layout_get_width (olayout));
-	pango_layout_set_spacing (layout, pango_layout_get_spacing (olayout));
-	pango_layout_set_wrap (layout, pango_layout_get_wrap (olayout));
-	pango_layout_set_indent (layout, pango_layout_get_indent (olayout));
-	pango_layout_set_auto_dir (layout, pango_layout_get_auto_dir (olayout));
-	pango_layout_set_ellipsize (layout, pango_layout_get_ellipsize (olayout));
-	pango_layout_set_font_description (layout, pango_layout_get_font_description (olayout));
-	/* ignore tabs */
-
-	/*
-	 * We really want to keep the line breaks, but currently pango
-	 * does not support that.
-	 */
-	if (pango_layout_get_line_count (olayout) == 1) {
-		if (pango_layout_get_line_count (layout) > 1) {
-			res->wrap_text = FALSE;
-			pango_layout_set_width (layout, -1);
-		}
-	}
-
-	gnm_rendered_value_remeasure (res);
-	return res;
-}
-
-
 /* Return the value as a single string without format infomation.
  */
 char const *
@@ -734,6 +680,9 @@ gnm_rvc_remove (GnmRenderedValueCollection *rvc, GnmCell const *cell)
 
 /* ------------------------------------------------------------------------- */
 
+/**
+ * gnm_rendered_value_init: (skip)
+ */
 void
 gnm_rendered_value_init (void)
 {
@@ -759,6 +708,9 @@ cb_rendered_value_pool_leak (gpointer data, G_GNUC_UNUSED gpointer user)
 }
 #endif
 
+/**
+ * gnm_rendered_value_shutdown: (skip)
+ */
 void
 gnm_rendered_value_shutdown (void)
 {
