@@ -65,7 +65,7 @@ gnm_filter_op_needs_value (GnmFilterOp op)
 
 
 /**
- * gnm_filter_condition_new_single :
+ * gnm_filter_condition_new_single:
  * @op: #GnmFilterOp
  * @v: #GnmValue
  *
@@ -87,7 +87,7 @@ gnm_filter_condition_new_single (GnmFilterOp op, GnmValue *v)
 }
 
 /**
- * gnm_filter_condition_new_double :
+ * gnm_filter_condition_new_double:
  * @op0: #GnmFilterOp
  * @v0: #GnmValue
  * @join_with_and:
@@ -274,7 +274,7 @@ filter_expr_eval (GnmFilterOp op, GnmValue const *src, GORegexp const *regexp,
 	case GNM_FILTER_OP_GT	: return cmp == IS_GREATER;
 	case GNM_FILTER_OP_LTE	: if (cmp == IS_EQUAL) return TRUE; /* fall */
 	case GNM_FILTER_OP_LT	: return cmp == IS_LESS;
-	default :
+	default:
 		g_warning ("Huh?");
 		return FALSE;
 	}
@@ -441,7 +441,7 @@ gnm_filter_combo_index (GnmFilterCombo *fcombo)
 
 
 /**
- * gnm_filter_combo_apply :
+ * gnm_filter_combo_apply:
  * @fcombo: #GnmFilterCombo
  * @target_sheet: @Sheet
  *
@@ -483,7 +483,7 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 		if (cond->op[1] != GNM_FILTER_UNUSED)
 			filter_expr_init (&data, 1, cond, filter);
 
-		sheet_foreach_cell_in_range (filter->sheet,
+		sheet_foreach_cell_in_region (filter->sheet,
 			iter_flags,
 			col, start_row, col, end_row,
 			(CellIterFunc) cb_filter_expr, &data);
@@ -492,12 +492,12 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 		if (cond->op[1] != GNM_FILTER_UNUSED)
 			filter_expr_release (&data, 1);
 	} else if (cond->op[0] == GNM_FILTER_OP_BLANKS)
-		sheet_foreach_cell_in_range (filter->sheet,
+		sheet_foreach_cell_in_region (filter->sheet,
 			CELL_ITER_IGNORE_HIDDEN,
 			col, start_row, col, end_row,
 			(CellIterFunc) cb_filter_blanks, target_sheet);
 	else if (cond->op[0] == GNM_FILTER_OP_NON_BLANKS)
-		sheet_foreach_cell_in_range (filter->sheet,
+		sheet_foreach_cell_in_region (filter->sheet,
 			CELL_ITER_IGNORE_HIDDEN,
 			col, start_row, col, end_row,
 			(CellIterFunc) cb_filter_non_blanks, target_sheet);
@@ -511,12 +511,12 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 				if (data.count < 1)
 					data.count = 1;
 				data.vals   = g_new (GnmValue const *, data.count);
-				sheet_foreach_cell_in_range (filter->sheet,
+				sheet_foreach_cell_in_region (filter->sheet,
 							     CELL_ITER_IGNORE_HIDDEN | CELL_ITER_IGNORE_BLANK,
 							     col, start_row, col, end_row,
 							     (CellIterFunc) cb_filter_find_items, &data);
 				data.target_sheet = target_sheet;
-				sheet_foreach_cell_in_range (filter->sheet,
+				sheet_foreach_cell_in_region (filter->sheet,
 							     CELL_ITER_IGNORE_HIDDEN,
 							     col, start_row, col, end_row,
 							     (CellIterFunc) cb_hide_unwanted_items, &data);
@@ -527,7 +527,7 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 
 				data.find_max = (cond->op[0] & 0x1) ? FALSE : TRUE;
 				data.initialized = FALSE;
-				sheet_foreach_cell_in_range (filter->sheet,
+				sheet_foreach_cell_in_region (filter->sheet,
 							     CELL_ITER_IGNORE_HIDDEN | CELL_ITER_IGNORE_BLANK,
 							     col, start_row, col, end_row,
 							     (CellIterFunc) cb_filter_find_percentage, &data);
@@ -535,7 +535,7 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 				data.high -= offset;
 				data.low  += offset;
 				data.target_sheet = target_sheet;
-				sheet_foreach_cell_in_range (filter->sheet,
+				sheet_foreach_cell_in_region (filter->sheet,
 							     CELL_ITER_IGNORE_HIDDEN,
 							     col, start_row, col, end_row,
 							     (CellIterFunc) cb_hide_unwanted_percentage, &data);
@@ -547,12 +547,12 @@ gnm_filter_combo_apply (GnmFilterCombo *fcombo, Sheet *target_sheet)
 			data.count  = cond->count;
 			data.vals   = g_new (GnmValue const *, data.count);
 
-			sheet_foreach_cell_in_range (filter->sheet,
+			sheet_foreach_cell_in_region (filter->sheet,
 				CELL_ITER_IGNORE_HIDDEN | CELL_ITER_IGNORE_BLANK,
 				col, start_row, col, end_row,
 				(CellIterFunc) cb_filter_find_items, &data);
 			data.target_sheet = target_sheet;
-			sheet_foreach_cell_in_range (filter->sheet,
+			sheet_foreach_cell_in_region (filter->sheet,
 				CELL_ITER_IGNORE_HIDDEN,
 				col, start_row, col, end_row,
 				(CellIterFunc) cb_hide_unwanted_items, &data);
@@ -676,7 +676,7 @@ gnm_filter_attach (GnmFilter *filter, Sheet *sheet)
 
 
 /**
- * gnm_filter_new :
+ * gnm_filter_new:
  * @sheet:
  * @r:
  *
@@ -703,7 +703,7 @@ gnm_filter_new (Sheet *sheet, GnmRange const *r)
 }
 
 /**
- * gnm_filter_dup :
+ * gnm_filter_dup:
  * @src: #GnmFilter
  * @sheet: #Sheet
  *
@@ -802,7 +802,7 @@ gnm_filter_remove (GnmFilter *filter)
 }
 
 /**
- * gnm_filter_get_condition :
+ * gnm_filter_get_condition:
  * @filter:
  * @i:
  *
@@ -857,7 +857,7 @@ gnm_filter_update_active (GnmFilter *filter)
 
 
 /**
- * gnm_filter_set_condition :
+ * gnm_filter_set_condition:
  * @filter:
  * @i:
  * @cond: #GnmFilterCondition
@@ -906,7 +906,7 @@ gnm_filter_set_condition (GnmFilter *filter, unsigned i,
 }
 
 /**
- * gnm_filter_overlaps_range :
+ * gnm_filter_overlaps_range:
  * @filter: #GnmFilter
  * @r: #GnmRange
  *
@@ -924,7 +924,7 @@ gnm_filter_overlaps_range (GnmFilter const *filter, GnmRange const *r)
 /*************************************************************************/
 
 /**
- * gnm_sheet_filter_at_pos :
+ * gnm_sheet_filter_at_pos:
  * @sheet: #Sheet
  *
  * Returns : #GnmRange
@@ -1047,7 +1047,7 @@ gnm_filter_set_range (GnmFilter *filter, GnmRange *r)
 }
 
 /**
- * gnm_sheet_filter_insdel_colrow :
+ * gnm_sheet_filter_insdel_colrow:
  * @sheet:
  * @is_cols:
  * @is_insert:
