@@ -23,7 +23,6 @@
 
 #include <gnumeric-config.h>
 #include "sheet-style.h"
-#include "gnm-style-impl.h"
 #include "ranges.h"
 #include "sheet.h"
 #include "expr.h"
@@ -213,8 +212,7 @@ sheet_style_find (Sheet const *sheet, GnmStyle *s)
 		 * gnm_style_unlink as that would call sheet_style_unlink
 		 * and thus remove "res" from the hash.
 		 */
-		s->link_count = 0;
-		s->linked_sheet = NULL;
+		gnm_style_abandon_link (s);
 		gnm_style_unref (s);
 
 		return res;
@@ -737,10 +735,8 @@ sheet_style_resize (Sheet *sheet, int cols, int rows)
 		GnmRange const *r = &sr->range;
 		GnmStyle *style = sr->style;
 		GnmRange newr;
-		if (range_intersection (&newr, r, &new_full)) {
-			gnm_style_ref (style);
-			sheet_style_apply_range (sheet, &newr, style);
-		}
+		if (range_intersection (&newr, r, &new_full))
+			sheet_style_apply_range2 (sheet, &newr, style);
 	}
 
 	style_list_free	(styles);
@@ -1491,11 +1487,11 @@ sheet_style_default (Sheet const *sheet)
 /**
  * sheet_style_get:
  * @sheet: #Sheet
- * @col:
- * @row:
+ * @col: column number
+ * @row: row number
  *
- * Find the fully qualified style applicable to the specified cellpos.
- * Does _not_ add a reference.
+ * Returns: (transfer none): find the fully qualified style applicable to
+ * the specified cell position
  **/
 GnmStyle const *
 sheet_style_get (Sheet const *sheet, int col, int row)
@@ -1542,20 +1538,27 @@ sheet_style_get (Sheet const *sheet, int col, int row)
 #define border_null(b)	((b) == none || (b) == NULL)
 
 static void
-style_row (GnmStyle *style, int start_col, int end_col, GnmStyleRow *sr, gboolean accept_conditions)
+style_row (GnmStyle const *style, int start_col, int end_col,
+	   GnmStyleRow *sr, gboolean accept_conditions)
 {
 	GnmBorder const *top, *bottom, *none = gnm_style_border_none ();
 	GnmBorder const *left, *right, *v;
 	int const end = MIN (end_col, sr->end_col);
 	int i = MAX (start_col, sr->start_col);
+	GnmStyleConditions *conds;
 
-	if (accept_conditions && style->conditions) {
+	conds = accept_conditions
+		? gnm_style_get_conditions (style)
+		: NULL;
+	if (conds) {
 		GnmEvalPos ep;
 		int res;
 
 		for (eval_pos_init (&ep, (Sheet *)sr->sheet, i, sr->row); ep.eval.col <= end ; ep.eval.col++) {
-			res = gnm_style_conditions_eval (style->conditions, &ep);
-			style_row (res >= 0 ? g_ptr_array_index (style->cond_styles, res) : style,
+			res = gnm_style_conditions_eval (conds, &ep);
+			style_row (res >= 0
+				   ? gnm_style_get_cond_style (style, res)
+				   : style,
 				   ep.eval.col, ep.eval.col, sr, FALSE);
 		}
 		return;
@@ -1746,10 +1749,10 @@ style_row_init (GnmBorder const * * *prev_vert,
 }
 
 /**
- * sheet_style_apply_range:
- * @sheet:
- * @range:
- * @pstyle:
+ * sheet_style_apply_range: (skip)
+ * @sheet: #Sheet
+ * @range: #GnmRange to apply over
+ * @pstyle: (transfer full): A partial style to apply
  *
  * Apply a partial style to a region.
  * The routine absorbs a reference to the partial style.
@@ -1779,6 +1782,22 @@ sheet_style_apply_range (Sheet *sheet, GnmRange const *range, GnmStyle *pstyle)
 	rstyle_dtor (&rs);
 }
 
+/**
+ * sheet_style_apply_range2: (skip)
+ * @sheet: #Sheet
+ * @range: #GnmRange to apply over
+ * @pstyle: A partial style to apply
+ *
+ * Apply a partial style to a region.
+ */
+void
+sheet_style_apply_range2 (Sheet *sheet, GnmRange const *range, GnmStyle *pstyle)
+{
+	gnm_style_ref (pstyle);
+	sheet_style_apply_range (sheet, range, pstyle);
+}
+
+
 static void
 apply_border (Sheet *sheet, GnmRange const *r,
 	      GnmStyleBorderLocation side,
@@ -2004,6 +2023,7 @@ sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
 {
 	int n, col, row, start_col, end_col;
 	GnmStyleRow sr;
+	gpointer *sr_array_data;
 	GnmStyleBorderLocation i;
 	gboolean known[GNM_STYLE_BORDER_EDGE_MAX];
 	GnmBorder const *none = gnm_style_border_none ();
@@ -2050,15 +2070,15 @@ sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
 
 	/* allocate then alias the arrays for easy access */
 	n = end_col - start_col + 2;
-	sr.vertical	 = (GnmBorder const **)g_alloca (n *
-			    (3 * sizeof (GnmBorder const *) +
-			     sizeof (GnmStyle const *)));
-	sr.top	      = sr.vertical + n;
-	sr.bottom     = sr.top + n;
-	sr.styles     = ((GnmStyle const **) (sr.bottom + n));
-	sr.vertical  -= start_col; sr.top     -= start_col;
-	sr.bottom    -= start_col; sr.styles  -= start_col;
-	sr.start_col  = start_col; sr.end_col  = end_col;
+	g_assert (sizeof (GnmBorder *) == sizeof (gpointer));
+	g_assert (sizeof (GnmStyle *) == sizeof (gpointer));
+	sr_array_data = g_new (gpointer, n * 4);
+	sr.vertical = (GnmBorder const **)(sr_array_data - start_col);
+	sr.top      = (GnmBorder const **)(sr_array_data + n - start_col);
+	sr.bottom   = (GnmBorder const **)(sr_array_data + 2 * n - start_col);
+	sr.styles   = (GnmStyle const **) (sr_array_data + 3 * n - start_col);
+	sr.start_col  = start_col;
+	sr.end_col  = end_col;
 	sr.hide_grid  = sheet->hide_grid;
 
 	/* pretend the previous bottom had no borders */
@@ -2109,6 +2129,7 @@ sheet_style_find_conflicts (Sheet const *sheet, GnmRange const *r,
 	border_mask_vec (known, borders, sr.top, r->start.col, r->end.col,
 			 GNM_STYLE_BORDER_BOTTOM);
 
+	g_free (sr_array_data);
 	return user.conflicts;
 }
 
