@@ -4,7 +4,7 @@
  * Author:
  *   Morten Welinder <terra@gnome.org>
  *
- * Copyright (C) 2012 Morten Welinder (terra@gnome.org)
+ * Copyright (C) 2012-2018 Morten Welinder (terra@gnome.org)
  */
 
 #include <gnumeric-config.h>
@@ -31,7 +31,7 @@
 #include "hlink.h"
 #include "input-msg.h"
 #include "expr-name.h"
-#include "workbook-priv.h"
+#include "sheet-diff.h"
 #include <gsf/gsf-libxml.h>
 #include <gsf/gsf-output-stdio.h>
 #include <gsf/gsf-input.h>
@@ -80,145 +80,30 @@ static const GOptionEntry ssdiff_options [] = {
 
 /* -------------------------------------------------------------------------- */
 
-typedef struct GnmDiffState_ GnmDiffState;
-
-typedef struct {
-	// Start comparison of two workbooks.
-	gboolean (*diff_start) (GnmDiffState *state);
-
-	// Finish comparison started with above.
-	void (*diff_end) (GnmDiffState *state);
-
-	// Clean up allocations
-	void (*dtor) (GnmDiffState *state);
-
-	/* ------------------------------ */
-
-	// Start looking at a sheet.  Either sheet might be NULL.
-	void (*sheet_start) (GnmDiffState *state,
-			     Sheet const *os, Sheet const *ns);
-
-	// Finish sheet started with above.
-	void (*sheet_end) (GnmDiffState *state);
-
-	// The order of sheets has changed.
-	void (*sheet_order_changed) (GnmDiffState *state);
-
-	// An integer attribute of the sheet has changed.
-	void (*sheet_attr_int_changed) (GnmDiffState *state, const char *name,
-					int o, int n);
-
-	/* ------------------------------ */
-
-	// Column or Row information changed
-	void (*colrow_changed) (GnmDiffState *state,
-				ColRowInfo const *oc, ColRowInfo const *nc,
-				gboolean is_cols, int i);
-
-	/* ------------------------------ */
-
-	// A cell was changed/added/removed.
-	void (*cell_changed) (GnmDiffState *state,
-			      GnmCell const *oc, GnmCell const *nc);
-
-	/* ------------------------------ */
-
-	// The style of an area was changed.
-	void (*style_changed) (GnmDiffState *state, GnmRange const *r,
-			       GnmStyle const *os, GnmStyle const *ns);
-
-	/* ------------------------------ */
-
-	// A defined name was changed
-	void (*name_changed) (GnmDiffState *state,
-			      GnmNamedExpr const *on, GnmNamedExpr const *nn);
-} GnmDiffActions;
-
 typedef struct {
 	char *url;
 	GsfInput *input;
 	Workbook *wb;
 	WorkbookView *wbv;
-}  GnmDiffStateFile;
+} GnmDiffStateFile;
 
-struct GnmDiffState_ {
+typedef struct {
 	GOIOContext *ioc;
 	GnmDiffStateFile old, new;
 
-	const GnmDiffActions *actions;
-
-	gboolean diff_found;
-
 	GsfOutput *output;
 
-	// Valid when comparing sheets
-	Sheet *old_sheet, *new_sheet;
-	GnmRange common_range;
-
 	// The following for xml mode.
 	GsfXMLOut *xml;
 	const char *xml_section;
 	GnmConventions *xml_convs;
 
 	// The following for highlight mode.
+	Sheet *highlight_sheet;
 	GnmDiffStateFile highlight;
 	GOFileSaver const *highlight_fs;
 	GnmStyle *highlight_style;
-};
-
-static gboolean
-null_diff_start (G_GNUC_UNUSED GnmDiffState *state)
-{
-	return FALSE;
-}
-
-static void
-null_diff_end (G_GNUC_UNUSED GnmDiffState *state)
-{
-}
-
-static void
-null_dtor (G_GNUC_UNUSED GnmDiffState *state)
-{
-}
-
-static void
-null_sheet_start (G_GNUC_UNUSED GnmDiffState *state,
-		  G_GNUC_UNUSED Sheet const *os,
-		  G_GNUC_UNUSED Sheet const *ns)
-{
-}
-
-static void
-null_sheet_end (G_GNUC_UNUSED GnmDiffState *state)
-{
-}
-
-static void
-null_sheet_order_changed (G_GNUC_UNUSED GnmDiffState *state)
-{
-}
-
-static void
-null_sheet_attr_int_changed (G_GNUC_UNUSED GnmDiffState *state,
-			     G_GNUC_UNUSED const char *name,
-			     G_GNUC_UNUSED int o,
-			     G_GNUC_UNUSED int n)
-{
-}
-
-static void
-null_colrow_changed (G_GNUC_UNUSED GnmDiffState *state,
-		     G_GNUC_UNUSED ColRowInfo const *oc, G_GNUC_UNUSED ColRowInfo const *nc,
-		     G_GNUC_UNUSED gboolean is_cols, G_GNUC_UNUSED int i)
-{
-}
-
-static void
-null_name_changed (G_GNUC_UNUSED GnmDiffState *state,
-		   G_GNUC_UNUSED GnmNamedExpr const *on, G_GNUC_UNUSED GnmNamedExpr const *nn)
-{
-}
+} DiffState;
 
 /* -------------------------------------------------------------------------- */
 
@@ -278,8 +163,9 @@ def_cell_name (GnmCell const *oc)
 }
 
 static void
-def_sheet_start (GnmDiffState *state, Sheet const *os, Sheet const *ns)
+def_sheet_start (gpointer user, Sheet const *os, Sheet const *ns)
 {
+	DiffState *state = user;
 	if (os && ns)
 		gsf_output_printf (state->output, _("Differences for sheet %s:\n"), os->name_quoted);
 	else if (os)
@@ -291,23 +177,26 @@ def_sheet_start (GnmDiffState *state, Sheet const *os, Sheet const *ns)
 }
 
 static void
-def_sheet_order_changed (GnmDiffState *state)
+def_sheet_order_changed (gpointer user)
 {
+	DiffState *state = user;
 	gsf_output_printf (state->output, _("Sheet order changed.\n"));
 }
 
 static void
-def_sheet_attr_int_changed (GnmDiffState *state, const char *name,
+def_sheet_attr_int_changed (gpointer user, const char *name,
 			    G_GNUC_UNUSED int o, G_GNUC_UNUSED int n)
 {
+	DiffState *state = user;
 	gsf_output_printf (state->output, _("Sheet attribute %s changed.\n"),
 			   name);
 }
 
 static void
-def_colrow_changed (GnmDiffState *state, ColRowInfo const *oc, ColRowInfo const *nc,
+def_colrow_changed (gpointer user, ColRowInfo const *oc, ColRowInfo const *nc,
 		    gboolean is_cols, int i)
 {
+	DiffState *state = user;
 	if (is_cols)
 		gsf_output_printf (state->output, _("Column %s changed.\n"),
 				   col_name (i));
@@ -317,8 +206,9 @@ def_colrow_changed (GnmDiffState *state, ColRowInfo const *oc, ColRowInfo const
 }
 
 static void
-def_cell_changed (GnmDiffState *state, GnmCell const *oc, GnmCell const *nc)
+def_cell_changed (gpointer user, GnmCell const *oc, GnmCell const *nc)
 {
+	DiffState *state = user;
 	if (oc && nc)
 		gsf_output_printf (state->output, _("Cell %s changed.\n"), def_cell_name (oc));
 	else if (oc)
@@ -330,18 +220,20 @@ def_cell_changed (GnmDiffState *state, GnmCell const *oc, GnmCell const *nc)
 }
 
 static void
-def_style_changed (GnmDiffState *state, GnmRange const *r,
+def_style_changed (gpointer user, GnmRange const *r,
 		   G_GNUC_UNUSED GnmStyle const *os,
 		   G_GNUC_UNUSED GnmStyle const *ns)
 {
+	DiffState *state = user;
 	gsf_output_printf (state->output, _("Style of %s was changed.\n"),
 			   range_as_string (r));
 }
 
 static void
-def_name_changed (GnmDiffState *state,
+def_name_changed (gpointer user,
 		  GnmNamedExpr const *on, GnmNamedExpr const *nn)
 {
+	DiffState *state = user;
 	if (on && nn)
 		gsf_output_printf (state->output, _("Name %s changed.\n"), expr_name_name (on));
 	else if (on)
@@ -353,24 +245,21 @@ def_name_changed (GnmDiffState *state,
 }
 
 static const GnmDiffActions default_actions = {
-	null_diff_start,
-	null_diff_end,
-	null_dtor,
-	def_sheet_start,
-	null_sheet_end,
-	def_sheet_order_changed,
-	def_sheet_attr_int_changed,
-	def_colrow_changed,
-	def_cell_changed,
-	def_style_changed,
-	def_name_changed,
+	.sheet_start = def_sheet_start,
+	.sheet_order_changed = def_sheet_order_changed,
+	.sheet_attr_int_changed = def_sheet_attr_int_changed,
+	.colrow_changed = def_colrow_changed,
+	.cell_changed = def_cell_changed,
+	.style_changed = def_style_changed,
+	.name_changed = def_name_changed,
 };
 
 /* -------------------------------------------------------------------------- */
 
 static gboolean
-xml_diff_start (GnmDiffState *state)
+xml_diff_start (gpointer user)
 {
+	DiffState *state = user;
 	char *attr;
 
 	state->xml = gsf_xml_out_new (state->output);
@@ -386,14 +275,16 @@ xml_diff_start (GnmDiffState *state)
 }
 
 static void
-xml_diff_end (GnmDiffState *state)
+xml_diff_end (gpointer user)
 {
+	DiffState *state = user;
 	gsf_xml_out_end_element (state->xml); /* </Diff> */
 }
 
 static void
-xml_dtor (GnmDiffState *state)
+xml_dtor (gpointer user)
 {
+	DiffState *state = user;
 	g_clear_object (&state->xml);
 
 	if (state->xml_convs) {
@@ -403,7 +294,7 @@ xml_dtor (GnmDiffState *state)
 }
 
 static void
-xml_close_section (GnmDiffState *state)
+xml_close_section (DiffState *state)
 {
 	if (state->xml_section) {
 		gsf_xml_out_end_element (state->xml);
@@ -412,7 +303,7 @@ xml_close_section (GnmDiffState *state)
 }
 
 static void
-xml_open_section (GnmDiffState *state, const char *section)
+xml_open_section (DiffState *state, const char *section)
 {
 	if (state->xml_section && g_str_equal (section, state->xml_section))
 		return;
@@ -423,8 +314,9 @@ xml_open_section (GnmDiffState *state, const char *section)
 }
 
 static void
-xml_sheet_start (GnmDiffState *state, Sheet const *os, Sheet const *ns)
+xml_sheet_start (gpointer user, Sheet const *os, Sheet const *ns)
 {
+	DiffState *state = user;
 	Sheet const *sheet = os ? os : ns;
 
 	// We might have an open section for global names
@@ -439,16 +331,18 @@ xml_sheet_start (GnmDiffState *state, Sheet const *os, Sheet const *ns)
 }
 
 static void
-xml_sheet_end (GnmDiffState *state)
+xml_sheet_end (gpointer user)
 {
+	DiffState *state = user;
 	xml_close_section (state);
 	gsf_xml_out_end_element (state->xml); /* </Sheet> */
 }
 
 static void
-xml_sheet_attr_int_changed (GnmDiffState *state, const char *name,
+xml_sheet_attr_int_changed (gpointer user, const char *name,
 			    int o, int n)
 {
+	DiffState *state = user;
 	char *elem;
 
 	elem = g_strconcat (DIFF, name, NULL);
@@ -460,7 +354,7 @@ xml_sheet_attr_int_changed (GnmDiffState *state, const char *name,
 }
 
 static void
-xml_output_texpr (GnmDiffState *state, GnmExprTop const *texpr, GnmParsePos const *pos,
+xml_output_texpr (DiffState *state, GnmExprTop const *texpr, GnmParsePos const *pos,
 		  const char *tag)
 {
 	GnmConventionsOut out;
@@ -478,7 +372,7 @@ xml_output_texpr (GnmDiffState *state, GnmExprTop const *texpr, GnmParsePos cons
 }
 
 static void
-xml_output_cell (GnmDiffState *state, GnmCell const *cell,
+xml_output_cell (DiffState *state, GnmCell const *cell,
 		 const char *tag, const char *valtag, const char *fmttag)
 {
 	if (!cell)
@@ -501,9 +395,10 @@ xml_output_cell (GnmDiffState *state, GnmCell const *cell,
 }
 
 static void
-xml_colrow_changed (GnmDiffState *state, ColRowInfo const *oc, ColRowInfo const *nc,
+xml_colrow_changed (gpointer user, ColRowInfo const *oc, ColRowInfo const *nc,
 		    gboolean is_cols, int i)
 {
+	DiffState *state = user;
 	xml_open_section (state, is_cols ? DIFF "Cols" : DIFF "Rows");
 
 	gsf_xml_out_start_element (state->xml, is_cols ? DIFF "ColInfo" : DIFF "RowInfo");
@@ -534,8 +429,9 @@ xml_colrow_changed (GnmDiffState *state, ColRowInfo const *oc, ColRowInfo const
 }
 
 static void
-xml_cell_changed (GnmDiffState *state, GnmCell const *oc, GnmCell const *nc)
+xml_cell_changed (gpointer user, GnmCell const *oc, GnmCell const *nc)
 {
+	DiffState *state = user;
 	const GnmCellPos *pos;
 
 	xml_open_section (state, DIFF "Cells");
@@ -609,9 +505,10 @@ cb_validation_use_dropdown (GnmValidation const *v)
 }
 
 static void
-xml_style_changed (GnmDiffState *state, GnmRange const *r,
+xml_style_changed (gpointer user, GnmRange const *r,
 		   GnmStyle const *os, GnmStyle const *ns)
 {
+	DiffState *state = user;
 	unsigned int conflicts;
 	GnmStyleElement e;
 
@@ -831,9 +728,10 @@ xml_style_changed (GnmDiffState *state, GnmRange const *r,
 #undef DO_STRINGS
 
 static void
-xml_name_changed (GnmDiffState *state,
+xml_name_changed (gpointer user,
 		  GnmNamedExpr const *on, GnmNamedExpr const *nn)
 {
+	DiffState *state = user;
 	xml_open_section (state, DIFF "Names");
 
 	gsf_xml_out_start_element (state->xml, DIFF "Name");
@@ -846,24 +744,24 @@ xml_name_changed (GnmDiffState *state,
 }
 
 static const GnmDiffActions xml_actions = {
-	xml_diff_start,
-	xml_diff_end,
-	xml_dtor,
-	xml_sheet_start,
-	xml_sheet_end,
-	null_sheet_order_changed,
-	xml_sheet_attr_int_changed,
-	xml_colrow_changed,
-	xml_cell_changed,
-	xml_style_changed,
-	xml_name_changed,
+	.diff_start = xml_diff_start,
+	.diff_end = xml_diff_end,
+	.dtor = xml_dtor,
+	.sheet_start = xml_sheet_start,
+	.sheet_end = xml_sheet_end,
+	.sheet_attr_int_changed = xml_sheet_attr_int_changed,
+	.colrow_changed = xml_colrow_changed,
+	.cell_changed = xml_cell_changed,
+	.style_changed = xml_style_changed,
+	.name_changed = xml_name_changed,
 };
 
 /* -------------------------------------------------------------------------- */
 
 static gboolean
-highlight_diff_start (GnmDiffState *state)
+highlight_diff_start (gpointer user)
 {
+	DiffState *state = user;
 	const char *dst = state->new.url;
 
 	state->highlight_fs = go_file_saver_for_file_name (ssdiff_output);
@@ -891,15 +789,18 @@ highlight_diff_start (GnmDiffState *state)
 }
 
 static void
-highlight_diff_end (GnmDiffState *state)
+highlight_diff_end (gpointer user)
 {
-	wbv_save_to_output (state->highlight.wbv, state->highlight_fs,
-			    state->output, state->ioc);
+	DiffState *state = user;
+	workbook_view_save_to_output (state->highlight.wbv,
+				      state->highlight_fs,
+				      state->output, state->ioc);
 }
 
 static void
-highlight_dtor (GnmDiffState *state)
+highlight_dtor (gpointer user)
 {
+	DiffState *state = user;
 	clear_file_state (&state->highlight);
 	if (state->highlight_style) {
 		gnm_style_unref (state->highlight_style);
@@ -908,392 +809,77 @@ highlight_dtor (GnmDiffState *state)
 }
 
 static void
-highlight_apply (GnmDiffState *state, const GnmRange *r)
+highlight_sheet_start (gpointer user,
+		       G_GNUC_UNUSED Sheet const *os, Sheet const *ns)
 {
-	// We want the highlight sheet corresponding to new_sheet.
-	Sheet *sheet = workbook_sheet_by_index (state->highlight.wb,
-						state->new_sheet->index_in_wb);
-	g_return_if_fail (IS_SHEET (sheet));
+	DiffState *state = user;
 
-	gnm_style_ref (state->highlight_style);
-	sheet_style_apply_range (sheet, r, state->highlight_style);
+	// We want the highlight sheet corresponding to new_sheet.
+	state->highlight_sheet = ns
+		? workbook_sheet_by_index (state->highlight.wb, ns->index_in_wb)
+		: NULL;
 }
 
 static void
-highlight_cell_changed (GnmDiffState *state,
+highlight_sheet_end (gpointer user)
+{
+	DiffState *state = user;
+	state->highlight_sheet = NULL;
+}
+
+static void
+highlight_apply (DiffState *state, const GnmRange *r)
+{
+	Sheet *sheet = state->highlight_sheet;
+
+	g_return_if_fail (IS_SHEET (sheet));
+
+	sheet_style_apply_range2 (sheet, r, state->highlight_style);
+}
+
+static void
+highlight_cell_changed (gpointer user,
 			GnmCell const *oc, GnmCell const *nc)
 {
+	DiffState *state = user;
 	GnmRange r;
 	highlight_apply (state, range_init_cellpos (&r, &(nc ? nc : oc)->pos));
 }
 
 static void
-highlight_style_changed (GnmDiffState *state, GnmRange const *r,
+highlight_style_changed (gpointer user, GnmRange const *r,
 			 G_GNUC_UNUSED GnmStyle const *os,
 			 G_GNUC_UNUSED GnmStyle const *ns)
 {
+	DiffState *state = user;
 	highlight_apply (state, r);
 }
 
 
 static const GnmDiffActions highlight_actions = {
-	highlight_diff_start,
-	highlight_diff_end,
-	highlight_dtor,
-	null_sheet_start,
-	null_sheet_end,
-	null_sheet_order_changed,
-	null_sheet_attr_int_changed,
-	null_colrow_changed,
-	highlight_cell_changed,
-	highlight_style_changed,
-	null_name_changed,
+	.diff_start = highlight_diff_start,
+	.diff_end = highlight_diff_end,
+	.dtor = highlight_dtor,
+	.sheet_start = highlight_sheet_start,
+	.sheet_end = highlight_sheet_end,
+	.cell_changed = highlight_cell_changed,
+	.style_changed = highlight_style_changed,
 };
 
 /* -------------------------------------------------------------------------- */
 
-static gboolean
-compare_texpr_equal (GnmExprTop const *oe, GnmParsePos const *opp,
-		     GnmExprTop const *ne, GnmParsePos const *npp,
-		     GnmConventions const *convs)
-{
-	char *so, *sn;
-	gboolean eq;
-
-	if (gnm_expr_top_equal (oe, ne))
-		return TRUE;
-
-	// Not equal, but with references to sheets, that is not
-	// necessary.  Compare as strings.
-
-	so = gnm_expr_top_as_string (oe, opp, convs);
-	sn = gnm_expr_top_as_string (ne, npp, convs);
-
-	eq = g_strcmp0 (so, sn) == 0;
-
-	g_free (so);
-	g_free (sn);
-
-	return eq;
-}
-
-static gboolean
-compare_corresponding_cells (GnmCell const *co, GnmCell const *cn)
-{
-	gboolean has_expr = gnm_cell_has_expr (co);
-	gboolean has_value = co->value != NULL;
-
-	if (has_expr != gnm_cell_has_expr (cn))
-		return TRUE;
-	if (has_expr) {
-		GnmParsePos opp, npp;
-		parse_pos_init_cell (&opp, co);
-		parse_pos_init_cell (&npp, cn);
-		return !compare_texpr_equal (co->base.texpr, &opp,
-					     cn->base.texpr, &npp,
-					     sheet_get_conventions (cn->base.sheet));
-	}
-
-	if (has_value != (cn->value != NULL))
-		return TRUE;
-	if (has_value)
-		return !(value_equal (co->value, cn->value) &&
-			 go_format_eq (VALUE_FMT (co->value),
-				       VALUE_FMT (cn->value)));
-
-
-	return FALSE;
-}
-
-static gboolean
-ignore_cell (GnmCell const *cell)
-{
-	if (cell) {
-		if (gnm_cell_has_expr (cell)) {
-			return gnm_expr_top_is_array_elem (cell->base.texpr,
-							   NULL, NULL);
-		} else {
-			return VALUE_IS_EMPTY (cell->value);
-		}
-	}
-	return FALSE;
-}
-
-static void
-diff_sheets_cells (GnmDiffState *state)
-{
-	GPtrArray *old_cells = sheet_cells (state->old_sheet, NULL);
-	GPtrArray *new_cells = sheet_cells (state->new_sheet, NULL);
-	size_t io = 0, in = 0;
-
-	// Make code below simpler.
-	g_ptr_array_add (old_cells, NULL);
-	g_ptr_array_add (new_cells, NULL);
-
-	while (TRUE) {
-		GnmCell const *co, *cn;
-
-		while (ignore_cell ((co = g_ptr_array_index (old_cells, io))))
-			io++;
-
-		while (ignore_cell ((cn = g_ptr_array_index (new_cells, in))))
-			in++;
-
-		if (co && cn) {
-			int order = co->pos.row == cn->pos.row
-				? co->pos.col - cn->pos.col
-				: co->pos.row - cn->pos.row;
-			if (order < 0)
-				cn = NULL;
-			else if (order > 0)
-				co = NULL;
-			else {
-				if (compare_corresponding_cells (co, cn)) {
-					state->diff_found = TRUE;
-					state->actions->cell_changed (state, co, cn);
-				}
-				io++, in++;
-				continue;
-			}
-		}
-
-		if (co) {
-			state->diff_found = TRUE;
-			state->actions->cell_changed (state, co, NULL);
-			io++;
-		} else if (cn) {
-			state->diff_found = TRUE;
-			state->actions->cell_changed (state, NULL, cn);
-			in++;
-		} else
-			break;
-	}
-
-	g_ptr_array_free (old_cells, TRUE);
-	g_ptr_array_free (new_cells, TRUE);
-}
-
-static void
-diff_sheets_colrow (GnmDiffState *state, gboolean is_cols)
-{
-	ColRowInfo const *old_def =
-		sheet_colrow_get_default (state->old_sheet, is_cols);
-	ColRowInfo const *new_def =
-		sheet_colrow_get_default (state->new_sheet, is_cols);
-	int i, U;
-
-	if (!colrow_equal (old_def, new_def)) {
-		state->diff_found = TRUE;
-		state->actions->colrow_changed (state, old_def, new_def, is_cols, -1);
-	}
-
-	U = is_cols
-		? state->common_range.end.col
-		: state->common_range.end.row;
-	for (i = 0; i <= U; i++) {
-		ColRowInfo const *ocr =
-			sheet_colrow_get (state->old_sheet, i, is_cols);
-		ColRowInfo const *ncr =
-			sheet_colrow_get (state->new_sheet, i, is_cols);
-
-		if (ocr == ncr)
-			continue; // Considered equal, even if defaults are different
-		if (!ocr) ocr = old_def;
-		if (!ncr) ncr = new_def;
-		if (!colrow_equal (ocr, ncr)) {
-			state->diff_found = TRUE;
-			state->actions->colrow_changed (state, ocr, ncr, is_cols, i);
-		}
-	}
-}
-
-#define DO_INT(field,attr)						\
-  do {									\
-	  if (state->old_sheet->field != state->new_sheet->field) {	\
-		  state->diff_found = TRUE;				\
-		  state->actions->sheet_attr_int_changed		\
-			  (state, attr, state->old_sheet->field, state->new_sheet->field); \
-	  }								\
-  } while (0)
-
-static void
-diff_sheets_attrs (GnmDiffState *state)
-{
-	GnmSheetSize const *os = gnm_sheet_get_size (state->old_sheet);
-	GnmSheetSize const *ns = gnm_sheet_get_size (state->new_sheet);
-
-	if (os->max_cols != ns->max_cols) {
-		state->diff_found = TRUE;
-		state->actions->sheet_attr_int_changed
-			(state, "Cols", os->max_cols, ns->max_cols);
-	}
-	if (os->max_rows != ns->max_rows) {
-		state->diff_found = TRUE;
-		state->actions->sheet_attr_int_changed
-			(state, "Rows", os->max_rows, ns->max_rows);
-	}
-
-	DO_INT (display_formulas, "DisplayFormulas");
-	DO_INT (hide_zero, "HideZero");
-	DO_INT (hide_grid, "HideGrid");
-	DO_INT (hide_col_header, "HideColHeader");
-	DO_INT (hide_row_header, "HideRowHeader");
-	DO_INT (display_outlines, "DisplayOutlines");
-	DO_INT (outline_symbols_below, "OutlineSymbolsBelow");
-	DO_INT (outline_symbols_right, "OutlineSymbolsRight");
-	DO_INT (text_is_rtl, "RTL_Layout");
-	DO_INT (is_protected, "Protected");
-	DO_INT (visibility, "Visibility");
-}
-#undef DO_INT
-
-struct cb_diff_sheets_styles {
-	GnmDiffState *state;
-	GnmStyle *old_style;
-};
-
-static void
-cb_diff_sheets_styles_2 (G_GNUC_UNUSED gpointer key,
-			 gpointer sr_, gpointer user_data)
-{
-	GnmStyleRegion *sr = sr_;
-	struct cb_diff_sheets_styles *data = user_data;
-	GnmDiffState *state = data->state;
-	GnmRange r = sr->range;
-
-	if (gnm_style_find_differences (data->old_style, sr->style, TRUE) == 0)
-		return;
-
-	state->diff_found = TRUE;
-
-	state->actions->style_changed (state, &r, data->old_style, sr->style);
-}
-
-static void
-cb_diff_sheets_styles_1 (G_GNUC_UNUSED gpointer key,
-			 gpointer sr_, gpointer user_data)
-{
-	GnmStyleRegion *sr = sr_;
-	struct cb_diff_sheets_styles *data = user_data;
-	GnmDiffState *state = data->state;
-
-	data->old_style = sr->style;
-	sheet_style_range_foreach (state->new_sheet, &sr->range,
-				   cb_diff_sheets_styles_2,
-				   data);
-}
-
-static void
-diff_sheets_styles (GnmDiffState *state)
-{
-	struct cb_diff_sheets_styles data;
-
-	data.state = state;
-	sheet_style_range_foreach (state->old_sheet, &state->common_range,
-				   cb_diff_sheets_styles_1,
-				   &data);
-}
-
-static int
-cb_expr_name_by_name (GnmNamedExpr const *a, GnmNamedExpr const *b)
-{
-	return g_strcmp0 (expr_name_name (a), expr_name_name (b));
-}
-
-static void
-diff_names (GnmDiffState *state,
-	    GnmNamedExprCollection const *onames, GnmNamedExprCollection const *nnames)
-{
-	GSList *old_names = gnm_named_expr_collection_list (onames);
-	GSList *new_names = gnm_named_expr_collection_list (nnames);
-	GSList *lo, *ln;
-	GnmConventions const *convs;
-
-	if (state->new_sheet)
-		convs = sheet_get_conventions (state->new_sheet);
-	else
-		// Hmm...  It's not terribly important where we get them
-		convs = sheet_get_conventions (workbook_sheet_by_index (state->new.wb, 0));
-		
-	old_names = g_slist_sort (old_names, (GCompareFunc)cb_expr_name_by_name);
-	new_names = g_slist_sort (new_names, (GCompareFunc)cb_expr_name_by_name);
-
-	lo = old_names;
-	ln = new_names;
-	while (lo || ln) {
-		GnmNamedExpr const *on = lo ? lo->data : NULL;
-		GnmNamedExpr const *nn = ln ? ln->data : NULL;
-
-		if (!nn || (on && cb_expr_name_by_name (on, nn) < 0)) {
-			// Old name got removed
-			state->diff_found = TRUE;
-			state->actions->name_changed (state, on, nn);
-			lo = lo->next;
-			continue;
-		}
-
-		if (!on || (nn && cb_expr_name_by_name (on, nn) > 0)) {
-			// New name got added
-			state->diff_found = TRUE;
-			state->actions->name_changed (state, on, nn);
-			ln = ln->next;
-			continue;
-		}
-
-		if (!compare_texpr_equal (on->texpr, &on->pos,
-					  nn->texpr, &nn->pos,
-					  convs)) {
-			state->diff_found = TRUE;
-			state->actions->name_changed (state, on, nn);
-		}
-
-		lo = lo->next;
-		ln = ln->next;
-	}
-
-	g_slist_free (old_names);
-	g_slist_free (new_names);
-}
-
-
-static void
-diff_sheets (GnmDiffState *state, Sheet *old_sheet, Sheet *new_sheet)
-{
-	GnmRange or, nr;
-
-	state->old_sheet = old_sheet;
-	state->new_sheet = new_sheet;
-
-	range_init_full_sheet (&or, old_sheet);
-	range_init_full_sheet (&nr, new_sheet);
-	range_intersection (&state->common_range, &or, &nr);
-
-	diff_sheets_attrs (state);
-	diff_names (state, state->old_sheet->names, state->new_sheet->names);
-	diff_sheets_colrow (state, TRUE);
-	diff_sheets_colrow (state, FALSE);
-	diff_sheets_cells (state);
-	diff_sheets_styles (state);
-
-	state->old_sheet = state->new_sheet = NULL;
-}
-
 static int
 diff (char const *oldfilename, char const *newfilename,
       GOIOContext *ioc,
       GnmDiffActions const *actions, GsfOutput *output)
 {
-	GnmDiffState state;
+	DiffState state;
 	int res = 0;
-	int i, count;
-	gboolean sheet_order_changed = FALSE;
-	int last_index = -1;
 	GnmLocale *locale;
 
 	locale = gnm_push_C_locale ();
 
 	memset (&state, 0, sizeof (state));
-	state.actions = actions;
 	state.ioc = ioc;
 	state.output = output;
 
@@ -1304,63 +890,16 @@ diff (char const *oldfilename, char const *newfilename,
 
 	/* ---------------------------------------- */
 
-	if (state.actions->diff_start (&state))
-		goto error;
-
-	diff_names (&state, state.old.wb->names, state.new.wb->names);
-
-	// This doesn't handle sheet renames very well, but simply considers
-	// that a sheet deletion and a sheet insert.
-	count = workbook_sheet_count (state.old.wb);
-	for (i = 0; i < count; i++) {
-		Sheet *old_sheet = workbook_sheet_by_index (state.old.wb, i);
-		Sheet *new_sheet = workbook_sheet_by_name (state.new.wb,
-							   old_sheet->name_unquoted);
-		state.actions->sheet_start (&state, old_sheet, new_sheet);
-
-		if (new_sheet) {
-			if (new_sheet->index_in_wb < last_index)
-				sheet_order_changed = TRUE;
-			last_index = new_sheet->index_in_wb;
-
-			diff_sheets (&state, old_sheet, new_sheet);
-		} else
-			state.diff_found = TRUE;
-
-		state.actions->sheet_end (&state);
-	}
-
-	count = workbook_sheet_count (state.new.wb);
-	for (i = 0; i < count; i++) {
-		Sheet *new_sheet = workbook_sheet_by_index (state.new.wb, i);
-		Sheet *old_sheet = workbook_sheet_by_name (state.old.wb,
-							   new_sheet->name_unquoted);
-		if (old_sheet)
-			; // Nothing -- already done above.
-		else {
-			state.diff_found = TRUE;
-			state.actions->sheet_start (&state, old_sheet, new_sheet);
-			state.actions->sheet_end (&state);
-		}
-	}
-
-	if (sheet_order_changed) {
-		state.diff_found = TRUE;
-		state.actions->sheet_order_changed (&state);
-	}
-
-	state.actions->diff_end (&state);
+	res = gnm_diff_workbooks (actions, &state, state.old.wb, state.new.wb);
 
 out:
 	clear_file_state (&state.old);
 	clear_file_state (&state.new);
-	state.actions->dtor (&state);
+	if (actions->dtor)
+		actions->dtor (&state);
 
 	gnm_pop_C_locale (locale);
 
-	if (res == 0)
-		res = state.diff_found ? 1 : 0;
-
 	return res;
 
 error:
