@@ -6,7 +6,7 @@
  * Copyright (C) Almer. S. Tigelaar.
  * EMail: almer1@dds.nl or almer-t@bigfoot.com
  *
- * Based on the csv-io.c plugin by :
+ * Based on the csv-io.c plugin by:
  *   Miguel de Icaza <miguel@gnu.org>
  *   Jody Goldberg   <jody@gnome.org>
  *
@@ -21,8 +21,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
@@ -605,7 +604,7 @@ GSF_CLASS (GnmStfExport, gnm_stf_export,
  * gnm_stf_get_stfe:
  * @obj: #GObject with a #GnmStfExport attached as data.
  *
- * If non is found, a new one is created ans attached to @obj.
+ * If none is found, a new one is created and attached to @obj.
  * Returns: (transfer none): the #GnmStfExport.
  **/
 GnmStfExport *
@@ -665,6 +664,7 @@ gnm_stf_file_saver_save (G_GNUC_UNUSED GOFileSaver const *fs, GOIOContext *conte
 	Workbook *wb = wb_view_get_workbook (wbv);
 	GnmStfExport *stfe = gnm_stf_get_stfe (G_OBJECT (wb));
 	GsfOutput *dummy_sink;
+	gboolean nosheets;
 
 	/* TODO: move this GUI dependent code out of this
 	 * filesaver into gui-file.c. After this, remove includes (see above). */
@@ -677,7 +677,8 @@ gnm_stf_file_saver_save (G_GNUC_UNUSED GOFileSaver const *fs, GOIOContext *conte
 		}
 	}
 
-	if (!stfe->sheet_list)
+	nosheets = (stfe->sheet_list == NULL);
+	if (nosheets)
 		gnm_stf_export_options_sheet_list_add
 			(stfe, wb_view_cur_sheet (wbv));
 
@@ -690,6 +691,9 @@ gnm_stf_file_saver_save (G_GNUC_UNUSED GOFileSaver const *fs, GOIOContext *conte
 	dummy_sink = gsf_output_memory_new ();
 	g_object_set (G_OBJECT (stfe), "sink", dummy_sink, NULL);
 	g_object_unref (dummy_sink);
+
+	if (nosheets)
+		gnm_stf_export_options_sheet_list_clear (stfe);
 }
 
 static gboolean
