@@ -11,7 +11,6 @@
 #include "gnumeric.h"
 #include "style.h"
 #include "style-font.h"
-#include "gnm-style-impl.h"
 
 #include "gnm-format.h"
 #include "style-color.h"
@@ -249,10 +248,10 @@ gnm_font_new (PangoContext *context,
 	abort ();
 }
 
-void
+GnmFont *
 gnm_font_ref (GnmFont *sf)
 {
-	g_return_if_fail (sf != NULL);
+	g_return_val_if_fail (sf != NULL, NULL);
 
 	sf->ref_count++;
 #ifdef DEBUG_REF_COUNT
@@ -262,6 +261,8 @@ gnm_font_ref (GnmFont *sf)
 		 sf->is_italic ? " italic" : "",
 		 sf->ref_count);
 #endif
+
+	return sf;
 }
 
 void
@@ -417,6 +418,9 @@ gnm_pango_context_get (void)
 	return g_object_ref (context);
 }
 
+/**
+ * gnm_font_init: (skip)
+ */
 void
 gnm_font_init (void)
 {
@@ -485,7 +489,7 @@ list_cached_fonts (GnmFont *font, G_GNUC_UNUSED gpointer value, GSList **lp)
 }
 
 /**
- * gnm_font_shutdown:
+ * gnm_font_shutdown: (skip)
  *
  * Release all resources allocated by gnm_font_init.
  **/
