@@ -21,8 +21,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
@@ -690,7 +689,7 @@ dao_autofit_rows (data_analysis_output_t *dao)
  * @row1:
  * @col2:
  * @row2:
- * @style:
+ * @style: (transfer full):
  *
  * Applies a partial style to the given region.
  *
@@ -1094,12 +1093,12 @@ dao_convert_to_values (data_analysis_output_t *dao)
 	if (dao->put_formulas)
 		return;
 
-	sheet_foreach_cell_in_range (dao->sheet, CELL_ITER_IGNORE_BLANK,
-				     dao->start_col, dao->start_row,
-				     dao->start_col + dao->cols - 1,
-				     dao->start_row + dao->rows - 1,
-				     cb_convert_to_value,
-				     NULL);
+	sheet_foreach_cell_in_region (dao->sheet, CELL_ITER_IGNORE_BLANK,
+				      dao->start_col, dao->start_row,
+				      dao->start_col + dao->cols - 1,
+				      dao->start_row + dao->rows - 1,
+				      cb_convert_to_value,
+				      NULL);
 }
 
 void
