@@ -3,11 +3,13 @@
 #include "value.h"
 #include "cell.h"
 #include "expr.h"
+#include "expr-deriv.h"
 #include "sheet.h"
 #include "workbook.h"
 #include "rangefunc.h"
 #include "ranges.h"
 #include "gutils.h"
+#include "mathfunc.h"
 #include "gnm-solver.h"
 #include "workbook-view.h"
 #include "workbook-control.h"
@@ -225,7 +227,7 @@ gnm_solver_constraint_valid (GnmSolverConstraint const *c,
 		GnmSheetRange sr_input, sr_c;
 
 		if (!vinput)
-			break; /* No need to blame contraint.  */
+			break; /* No need to blame constraint.  */
 
 		gnm_sheet_range_from_value (&sr_input, vinput);
 		gnm_sheet_range_from_value (&sr_c, lhs);
@@ -850,6 +852,18 @@ gnm_solver_dispose (GObject *obj)
 		gnm_solver_update_derived (sol);
 	}
 
+	if (sol->gradient) {
+		sol->gradient_status = 0;
+		g_ptr_array_unref (sol->gradient);
+		sol->gradient = NULL;
+	}
+
+	if (sol->hessian) {
+		sol->hessian_status = 0;
+		g_ptr_array_unref (sol->hessian);
+		sol->hessian = NULL;
+	}
+
 	gnm_solver_parent_class->dispose (obj);
 }
 
@@ -1299,7 +1313,7 @@ gnm_solver_saveas (GnmSolver *solver, WorkbookControl *wbc,
 
 	output = gsf_output_stdio_new_FILE (*filename, file, TRUE);
 	io_context = go_io_context_new (GO_CMD_CONTEXT (wbc));
-	wbv_save_to_output (wbv, fs, output, io_context);
+	workbook_view_save_to_output (wbv, fs, output, io_context);
 	ok = !go_io_error_occurred (io_context);
 	g_object_unref (io_context);
 	g_object_unref (output);
@@ -1943,6 +1957,65 @@ gnm_solver_restore_vars (GnmSolver *sol, GPtrArray *vals)
 	g_ptr_array_free (vals, TRUE);
 }
 
+/**
+ * gnm_solver_has_analytic_gradient:
+ * @sol: the solver
+ *
+ * Returns: %TRUE if the gradient can be computed analytically.
+ */
+gboolean
+gnm_solver_has_analytic_gradient (GnmSolver *sol)
+{
+	const int n = sol->input_cells->len;
+
+	if (sol->gradient_status == 0) {
+		int i;
+
+		sol->gradient_status++;
+
+		sol->gradient = g_ptr_array_new_with_free_func ((GDestroyNotify)gnm_expr_top_unref);
+		for (i = 0; i < n; i++) {
+			GnmCell *cell = g_ptr_array_index (sol->input_cells, i);
+			GnmExprTop const *te =
+				gnm_expr_cell_deriv (sol->target, cell);
+			if (te)
+				g_ptr_array_add (sol->gradient, (gpointer)te);
+			else {
+				if (gnm_solver_debug ())
+					g_printerr ("Unable to compute analytic gradient\n");
+				sol->gradient_status++;
+				break;
+			}
+		}
+	}
+
+	return sol->gradient_status == 1;
+}
+
+static gnm_float *
+gnm_solver_compute_gradient_analytically (GnmSolver *sol, gnm_float const *xs)
+{
+	const int n = sol->input_cells->len;
+	int i;
+	gnm_float *g = g_new (gnm_float, n);
+	GnmEvalPos ep;
+
+	eval_pos_init_cell (&ep, sol->target);
+	for (i = 0; i < n; i++) {
+		GnmExprTop const *te = g_ptr_array_index (sol->gradient, i);
+		GnmValue *v = gnm_expr_top_eval
+			(te, &ep, GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
+		g[i] = VALUE_IS_NUMBER (v) ? value_get_as_float (v) : gnm_nan;
+		if (sol->flip_sign)
+			g[i] = 0 - g[i];
+		value_release (v);
+	}
+
+	if (gnm_solver_debug ())
+		print_vector ("Analytic gradient", g, n);
+
+	return g;
+}
 
 /**
  * gnm_solver_compute_gradient:
@@ -1950,8 +2023,8 @@ gnm_solver_restore_vars (GnmSolver *sol, GPtrArray *vals)
  * @xs: Point to compute gradient at
  *
  * Returns: (transfer full): A vector containing the gradient.  This
- * function takes the flip-sign property into account.  Note, that this
- * is a numerical approximation.
+ * function takes the flip-sign property into account.  This will use
+ * analytic gradient, if possible, and a numerical approximation otherwise.
  */
 gnm_float *
 gnm_solver_compute_gradient (GnmSolver *sol, gnm_float const *xs)
@@ -1965,6 +2038,9 @@ gnm_solver_compute_gradient (GnmSolver *sol, gnm_float const *xs)
 	gnm_solver_set_vars (sol, xs);
 	y0 = gnm_solver_get_target_value (sol);
 
+	if (gnm_solver_has_analytic_gradient (sol))
+		return gnm_solver_compute_gradient_analytically (sol, xs);
+
 	g = g_new (gnm_float, n);
 	for (i = 0; i < n; i++) {
 		gnm_float x0 = xs[i];
@@ -1999,9 +2075,112 @@ gnm_solver_compute_gradient (GnmSolver *sol, gnm_float const *xs)
 		gnm_solver_set_var (sol, i, x0);
 	}
 
+	if (gnm_solver_debug ())
+		print_vector ("Numerical gradient", g, n);
+
 	return g;
 }
 
+/**
+ * gnm_solver_has_analytic_hessian:
+ * @sol: the solver
+ *
+ * Returns: %TRUE if the Hessian can be computed analytically.
+ */
+gboolean
+gnm_solver_has_analytic_hessian (GnmSolver *sol)
+{
+	const int n = sol->input_cells->len;
+	int i, j;
+	GnmEvalPos ep;
+	GnmExprDeriv *info;
+
+	if (!gnm_solver_has_analytic_gradient (sol))
+		sol->hessian_status = sol->gradient_status;
+
+	if (sol->hessian_status)
+		return sol->hessian_status == 1;
+
+	sol->hessian_status++;
+	sol->hessian = g_ptr_array_new_with_free_func ((GDestroyNotify)gnm_expr_top_unref);
+
+	eval_pos_init_cell (&ep, sol->target);
+	info = gnm_expr_deriv_info_new ();
+	for (i = 0; i < n && sol->hessian_status == 1; i++) {
+		GnmExprTop const *gi = g_ptr_array_index (sol->gradient, i);
+		for (j = i; j < n; j++) {
+			GnmCell *cell;
+			GnmExprTop const *te;
+			GnmEvalPos var;
+
+			cell = g_ptr_array_index (sol->input_cells, j);
+			eval_pos_init_cell (&var, cell);
+			gnm_expr_deriv_info_set_var (info, &var);
+			te = gnm_expr_top_deriv (gi, &ep, info);
+
+			if (te)
+				g_ptr_array_add (sol->hessian, (gpointer)te);
+			else {
+				if (gnm_solver_debug ())
+					g_printerr ("Unable to compute analytic hessian\n");
+				sol->hessian_status++;
+				break;
+			}
+		}
+	}
+
+	gnm_expr_deriv_info_free (info);
+
+	return sol->hessian_status == 1;
+}
+
+/**
+ * gnm_solver_compute_hessian:
+ * @sol: Solver
+ * @xs: Point to compute Hessian at
+ *
+ * Returns: (transfer full): A vector containing the Hessian.  This
+ * function takes the flip-sign property into account.  The result vector
+ * will be n+(n-1)+...+2+1 elements long containing the triangular
+ * Hessian.  Use symmetry to obtain the full Hessian.
+ */
+GnmMatrix *
+gnm_solver_compute_hessian (GnmSolver *sol, gnm_float const *xs)
+{
+	int i, j, k;
+	GnmMatrix *H;
+	GnmEvalPos ep;
+	int const n = sol->input_cells->len;
+
+	if (!gnm_solver_has_analytic_hessian (sol))
+		return NULL;
+
+	gnm_solver_set_vars (sol, xs);
+
+	H = gnm_matrix_new (n, n);
+	eval_pos_init_cell (&ep, sol->target);
+	for (i = k = 0; i < n; i++) {
+		for (j = i; j < n; j++, k++) {
+			GnmExprTop const *te =
+				g_ptr_array_index (sol->hessian, k);
+			GnmValue *v = gnm_expr_top_eval
+				(te, &ep, GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
+			gnm_float x = VALUE_IS_NUMBER (v)
+				? value_get_as_float (v)
+				: gnm_nan;
+			if (sol->flip_sign)
+				x = 0 - x;
+			value_release (v);
+
+			H->data[i][j] = x;
+			H->data[j][i] = x;
+		}
+	}
+
+	return H;
+}
+
+
 static gnm_float
 try_step (GnmSolver *sol, gnm_float const *x0, gnm_float const *dir, gnm_float step)
 {
@@ -2234,7 +2413,7 @@ gnm_solver_pick_lp_coords (GnmSolver *sol,
  * @x2: second coordinate value
  * @err: error location
  *
- * Returns: (transfer full): coordinates, or NULL in case of error.
+ * Returns: (transfer full) (nullable): coordinates, or %NULL in case of error.
  * Note: this function is not affected by the flip-sign property, even
  * if @ycell happens to coindice with the solver target cell.
  */
