@@ -177,6 +177,13 @@ value_new_error_NA (GnmEvalPos const *pos)
 	return value_new_error_str (pos, standard_errors[GNM_ERROR_NA].locale_name_str);
 }
 
+/**
+ * value_error_name:
+ * @err: #GnmStdError
+ * @translated: If %TRUE, use localized name.
+ *
+ * Returns: (transfer none): the name of @err, possibly localized.
+ */
 char const *
 value_error_name (GnmStdError err, gboolean translated)
 {
@@ -195,6 +202,8 @@ value_error_name (GnmStdError err, gboolean translated)
  * @pos:
  *
  * Change the position of a ValueError.
+ *
+ * Returns: (transfer none): @err as a #GnmValue.
  */
 GnmValue *
 value_error_set_pos (GnmValueErr *err, G_GNUC_UNUSED GnmEvalPos const *pos)
@@ -367,7 +376,7 @@ value_new_cellrange_r (Sheet *sheet, GnmRange const *r)
  *
  * Parse @str using the convention associated with @sheet.
  * Returns a (GnmValue *) of type VALUE_CELLRANGE if the @range was
- * succesfully parsed or NULL on failure.
+ * succesfully parsed or %NULL on failure.
  */
 GnmValue *
 value_new_cellrange_str (Sheet *sheet, char const *str)
@@ -391,7 +400,7 @@ value_new_cellrange_str (Sheet *sheet, char const *str)
  *
  * Parse @str using the convention associated with @sheet.
  * Returns a (GnmValue *) of type VALUE_CELLRANGE if the @range was
- * succesfully parsed or NULL on failure.
+ * succesfully parsed or %NULL on failure.
  */
 GnmValue *
 value_new_cellrange_parsepos_str (GnmParsePos const *pp, char const *str,
@@ -624,9 +633,9 @@ value_release (GnmValue *value)
 
 /**
  * value_dup:
- * @v: #GnmValue
+ * @v: (nullable): #GnmValue
  *
- * Returns a copy of @v.  @v == NULL will return NULL
+ * Returns: (transfer full) (nullable): a copy of @v.
  **/
 GnmValue *
 value_dup (GnmValue const *src)
@@ -708,7 +717,7 @@ value_cmp (void const *ptr_a, void const *ptr_b)
 	case IS_EQUAL :   return  0;
 	case IS_LESS :    return -1;
 	case IS_GREATER : return  1;
-	default :
+	default:
 		break;
 	}
 	return a->v_any.type - b->v_any.type;
@@ -826,6 +835,13 @@ value_hash (GnmValue const *v)
 }
 
 
+GnmValueType
+value_type_of (const GnmValue *v)
+{
+	return v->v_any.type;
+}
+
+
 gboolean
 value_get_as_bool (GnmValue const *v, gboolean *err)
 {
@@ -998,11 +1014,11 @@ value_get_as_gstring (GnmValue const *v, GString *target,
 
 /**
  * value_get_as_string:
- * @v:
+ * @v: #GnmValue
  *
- * simplistic value rendering
+ * Simplistic value rendering
  *
- * Returns a string that must be freed.
+ * Returns: (transfer full): a string rendering of @v.
  **/
 char *
 value_get_as_string (GnmValue const *v)
@@ -1012,10 +1028,15 @@ value_get_as_string (GnmValue const *v)
 	return g_string_free (res, FALSE);
 }
 
-/*
- * Result will stay valid until (a) the value is disposed of, or (b) two
- * further calls to this function are made.
+/**
+ * value_peek_string:
+ * @v: a #GnmValue
+ *
+ * Returns: (transfer none): A string representation of the value.  The
+ * result will stay valid until either (a) the value is disposed of, or
+ * (b) two further calls to this function are made.
  */
+// NOTE: "(transfer none)" papers over an introspection bug
 char const *
 value_peek_string (GnmValue const *v)
 {
@@ -1037,8 +1058,78 @@ value_peek_string (GnmValue const *v)
 	}
 }
 
-/*
- * FIXME FIXME FIXME : Support errors
+/**
+ * value_stringify:
+ * @v: a #GnmValue
+ *
+ * Returns: (transfer full): A string representation of the value suitable
+ * for use in a Python __repr__ function.
+ */
+char *
+value_stringify (GnmValue const *v)
+{
+	GString *res = g_string_sized_new (30);
+
+	g_string_append_c (res, '{');
+
+	switch (v->v_any.type) {
+	case VALUE_EMPTY:
+		g_string_append (res, "EMPTY,");
+		g_string_append (res, "None");
+		break;
+
+	case VALUE_STRING:
+		g_string_append (res, "STRING,");
+		go_strescape (res, value_peek_string (v));
+		break;
+
+	case VALUE_CELLRANGE:
+		g_string_append (res, "CELLRANGE,");
+		g_string_append (res, value_peek_string (v));
+		return 0;
+
+	case VALUE_ARRAY:
+		g_string_append (res, "ARRAY,");
+		g_string_append (res, value_peek_string (v));
+		break;
+
+	case VALUE_FLOAT:
+		g_string_append (res, "FLOAT,");
+		g_string_append (res, value_peek_string (v));
+		break;
+
+	case VALUE_BOOLEAN:
+		g_string_append (res, "BOOLEAN,");
+		g_string_append_c (res, v->v_bool.val ? '1' : '0');
+		break;
+
+	case VALUE_ERROR:
+		g_string_append (res, "ERROR,");
+		go_strescape (res, value_peek_string (v));
+		break;
+
+	default:
+		g_string_append (res, "?,?");
+		break;
+	}
+
+	if (VALUE_FMT (v) != NULL) {
+		g_string_append_c (res, ',');
+		go_strescape (res, go_format_as_XL (VALUE_FMT (v)));
+	}
+
+	g_string_append_c (res, '}');
+
+	return g_string_free (res, FALSE);
+}
+
+
+
+/**
+ * value_get_as_int:
+ * @v: (nullable): a #GnmValue
+ *
+ * Returns: @v interpreted as an integer.
  */
 int
 value_get_as_int (GnmValue const *v)
@@ -1075,8 +1166,11 @@ value_get_as_int (GnmValue const *v)
 	return 0;
 }
 
-/*
- * FIXME FIXME FIXME : Support errors
+/**
+ * value_get_as_float:
+ * @v: (nullable): a #GnmValue
+ *
+ * Returns: @v interpreted as a floating point value.
  */
 gnm_float
 value_get_as_float (GnmValue const *v)
@@ -1243,30 +1337,30 @@ value_diff (GnmValue const *a, GnmValue const *b)
 	if (ta == VALUE_STRING) {
 		switch (tb) {
 		/* Strings are > (empty, or number) */
-		case VALUE_EMPTY :
+		case VALUE_EMPTY:
 			if (*a->v_str.val->str == '\0')
 				return 0.;
 			return DBL_MAX;
 
 		/* If both are strings compare as string */
-		case VALUE_STRING :
+		case VALUE_STRING:
 			if (go_string_equal (a->v_str.val, b->v_str.val))
 				return 0.;
 
 		case VALUE_FLOAT: case VALUE_BOOLEAN:
-		default :
+		default:
 			return DBL_MAX;
 		}
 
 	} else if (tb == VALUE_STRING) {
 		switch (ta) {
 		/* (empty, or number) < String */
-		case VALUE_EMPTY :
+		case VALUE_EMPTY:
 			if (*b->v_str.val->str == '\0')
 				return 0.;
 
-		case VALUE_FLOAT : case VALUE_BOOLEAN :
-		default :
+		case VALUE_FLOAT : case VALUE_BOOLEAN:
+		default:
 			return DBL_MAX;
 		}
 	}
@@ -1469,6 +1563,13 @@ value_compare_no_cache (GnmValue const *a, GnmValue const *b,
 	return value_compare_real (a, b, case_sensitive, FALSE);
 }
 
+/**
+ * value_set_format:
+ * @v: #GnmValue
+ * @fmt: (nullable): #GOFormat
+ *
+ * Sets @v's format.
+ */
 void
 value_set_fmt (GnmValue *v, GOFormat const *fmt)
 {
@@ -1501,6 +1602,9 @@ GnmValueErr const value_terminate_err = { VALUE_ERROR, NULL, NULL };
 static GnmValueFloat const the_value_zero = { VALUE_FLOAT, NULL, 0 };
 GnmValue const *value_zero = (GnmValue const *)&the_value_zero;
 
+/**
+ * value_init: (skip)
+ */
 void
 value_init (void)
 {
@@ -1540,6 +1644,9 @@ value_init (void)
 #endif
 }
 
+/**
+ * value_shutdown: (skip)
+ */
 void
 value_shutdown (void)
 {
