@@ -438,7 +438,7 @@ wbcg_edit_finish (WBCGtk *wbcg, WBCEditResult result,
 			/* Redraw the cell contents in case there was a span */
 			GnmRange tmp; tmp.start = tmp.end = sv->edit_pos;
 			sheet_range_bounding_box (sv->sheet, &tmp);
-			sv_redraw_range (wb_control_cur_sheet_view (wbc), &tmp);
+			gnm_sheet_view_redraw_range (wb_control_cur_sheet_view (wbc), &tmp);
 		}
 
 		/* Reload the entry widget with the original contents */
@@ -936,7 +936,7 @@ wbcg_edit_start (WBCGtk *wbcg,
 	else if (cell != NULL) {
 		gboolean quoted = FALSE;
 
-		text = gnm_cell_get_text_for_editing (cell, sv->sheet, &quoted, &cursor_pos);
+		text = gnm_cell_get_text_for_editing (cell, &quoted, &cursor_pos);
 
 		if (text)
 			gtk_entry_set_text (wbcg_get_entry (wbcg), text);
@@ -1044,7 +1044,7 @@ wbcg_insert_object (WBCGtk *wbcg, SheetObject *so)
 			scg_object_unselect (scg, NULL);
 			scg_cursor_visible (scg, FALSE);
 			scg_set_display_cursor (scg);
-			sc_unant (GNM_SC (scg));
+			sc_unant (GNM_SHEET_CONTROL (scg));
 		}
 	}
 	/* we can't set wbcg->new_object before now because if one sheet has a
@@ -1060,7 +1060,7 @@ wbcg_insert_object (WBCGtk *wbcg, SheetObject *so)
  *
  * If we are preparing to insert a new object, unref the object, and restore
  * a normal state to the scgs that was changed in wbcg_insert_object
- * (e.g.  visiblity of cursors)
+ * (e.g., visibility of cursors)
  **/
 void
 wbcg_insert_object_clear (WBCGtk *wbcg)
