@@ -511,7 +511,7 @@ gee_set_property (GObject      *object,
 		gee->wbcg = WBC_GTK (g_value_get_object (value));
 		break;
 	case PROP_CONSTANT_FORMAT:
-		gee_set_format (gee, g_value_get_pointer (value));
+		gee_set_format (gee, g_value_get_boxed (value));
 		break;
 	case PROP_EDITING_CANCELED:
 		gee->editing_canceled = g_value_get_boolean (value);
@@ -547,7 +547,7 @@ gee_get_property (GObject      *object,
 		g_value_set_object (value, G_OBJECT (gee->wbcg));
 		break;
 	case PROP_CONSTANT_FORMAT:
-		g_value_set_pointer (value, (gpointer)gee->constant_format);
+		g_value_set_boxed (value, (gpointer)gee->constant_format);
 		break;
 	case PROP_EDITING_CANCELED:
 		g_value_set_boolean (value, gee->editing_canceled);
@@ -857,7 +857,7 @@ gee_set_tooltip (GnmExprEntry *gee, GnmFunc *fd, gint args, gboolean had_stuff)
 	const char *fdname;
 
 	gnm_func_load_if_stub (fd);
-	function_def_count_args (fd, &min, &max);
+	gnm_func_count_args (fd, &min, &max);
 
 	if ((gee->tooltip.fd)
 	    && (gee->tooltip.fd == fd && gee->tooltip.args == args
@@ -874,7 +874,7 @@ gee_set_tooltip (GnmExprEntry *gee, GnmFunc *fd, gint args, gboolean had_stuff)
 	g_string_append_c (str, '(');
 
 	for (i = 0; i < max; i++) {
-		char *arg_name = function_def_get_arg_name
+		char *arg_name = gnm_func_get_arg_name
 			(fd, i);
 		if (arg_name != NULL) {
 			if (first)
@@ -969,7 +969,7 @@ gee_set_tooltip_completion (GnmExprEntry *gee, GSList *list, guint start, guint
 		g_string_append (str_marked, _("\n\t<i>F4 to complete</i>"));
 	} else if (i > 1)
 		/*xgettext: short form for: "type shift-F4-keys to select the completion"*/
-		g_string_append (str_marked, _("\n\t<i>\xe2\x87\xa7""F4 to select</i>"));
+		g_string_append (str_marked, _("\n\t<i>\342\207\247F4 to select</i>"));
 	else
 		g_string_truncate (str, str->len - 1);
 	gee->tooltip.completion_start = start;
@@ -1441,7 +1441,7 @@ cb_gee_key_press_event (GtkEntry	*entry,
 				/* invalidate, in case Enter direction changes */
 				if (is_enter)
 					sv->first_tab_col = -1;
-				sv_update (sv);
+				gnm_sheet_view_update (sv);
 			}
 		}
 		return TRUE;
@@ -1742,10 +1742,11 @@ gee_class_init (GObjectClass *gobject_class)
 
 	g_object_class_install_property
 		(gobject_class, PROP_CONSTANT_FORMAT,
-		 g_param_spec_pointer ("constant-format",
-				       P_("Constant Format"),
-				       P_("Format for constants"),
-				       GSF_PARAM_STATIC | G_PARAM_READWRITE));
+		 g_param_spec_boxed ("constant-format",
+				     P_("Constant Format"),
+				     P_("Format for constants"),
+				     go_format_get_type (),
+				     GSF_PARAM_STATIC | G_PARAM_READWRITE));
 
 	gee_debug = gnm_debug_flag ("gee");
 }
@@ -2338,7 +2339,7 @@ gnm_expr_entry_set_scg (GnmExprEntry *gee, SheetControlGUI *scg)
 	if (scg) {
 		g_object_weak_ref (G_OBJECT (gee->scg),
 				   (GWeakNotify) cb_scg_destroy, gee);
-		gee->sheet = sc_sheet (GNM_SC (scg));
+		gee->sheet = sc_sheet (GNM_SHEET_CONTROL (scg));
 		parse_pos_init_editpos (&gee->pp, scg_view (gee->scg));
 		gee->wbcg = scg_wbcg (gee->scg);
 	} else
@@ -2656,7 +2657,7 @@ gnm_expr_entry_parse (GnmExprEntry *gee, GnmParsePos const *pp,
 		SheetControlGUI *scg = wbcg_cur_scg (gee->wbcg);
 		Rangesel const *rs = &gee->rangesel;
 		if (gee == wbcg_get_entry_logical (gee->wbcg) &&
-		    start_sel && sc_sheet (GNM_SC (scg)) == rs->ref.a.sheet) {
+		    start_sel && sc_sheet (GNM_SHEET_CONTROL (scg)) == rs->ref.a.sheet) {
 			scg_rangesel_bound (scg,
 				rs->ref.a.col, rs->ref.a.row,
 				rs->ref.b.col, rs->ref.b.row);
