@@ -56,7 +56,7 @@
 
 enum {
 	PROP_0,
-	RECALC_MODE
+	PROP_RECALC_MODE
 };
 enum {
 	SHEET_ORDER_CHANGED,
@@ -64,7 +64,7 @@ enum {
 	SHEET_DELETED,
 	LAST_SIGNAL
 };
-static guint signals [LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = { 0 };
 static GObjectClass *workbook_parent_class;
 
 static void
@@ -130,6 +130,7 @@ workbook_dispose (GObject *wb_object)
 {
 	Workbook *wb = WORKBOOK (wb_object);
 	GSList *sheets, *ptr;
+	GSList *controls = NULL;
 
 	wb->during_destruction = TRUE;
 
@@ -139,8 +140,11 @@ workbook_dispose (GObject *wb_object)
 		workbook_set_saveinfo (wb, GO_FILE_FL_WRITE_ONLY, NULL);
 	workbook_set_last_export_uri (wb, NULL);
 
-	/* Remove all the sheet controls to avoid displaying while we exit */
+	// Remove all the sheet controls to avoid displaying while we exit
+	// However, hold on to a ref for each -- dialogs like to refer
+	// to ->wbcg during destruction
 	WORKBOOK_FOREACH_CONTROL (wb, view, control,
+		controls = g_slist_prepend (controls, g_object_ref (control));
 		wb_control_sheet_remove_all (control););
 
 	/* Get rid of all the views */
@@ -178,6 +182,9 @@ workbook_dispose (GObject *wb_object)
 	}
 	g_slist_free (sheets);
 
+	// Now get rid of the control refs
+	g_slist_free_full (controls, g_object_unref);
+
 	workbook_parent_class->dispose (wb_object);
 }
 
@@ -249,7 +256,7 @@ workbook_get_property (GObject *object, guint property_id,
 	Workbook *wb = (Workbook *)object;
 
 	switch (property_id) {
-	case RECALC_MODE :
+	case PROP_RECALC_MODE:
 		g_value_set_boolean (value, wb->recalc_auto);
 		break;
 	default:
@@ -265,7 +272,7 @@ workbook_set_property (GObject *object, guint property_id,
 	Workbook *wb = (Workbook *)object;
 
 	switch (property_id) {
-	case RECALC_MODE :
+	case PROP_RECALC_MODE:
 		workbook_set_recalcmode (wb, g_value_get_boolean (value));
 		break;
 	default:
@@ -274,74 +281,27 @@ workbook_set_property (GObject *object, guint property_id,
 	}
 }
 
-static void
-workbook_class_init (GObjectClass *gobject_class)
-{
-	workbook_parent_class = g_type_class_peek_parent (gobject_class);
-
-	gobject_class->set_property = workbook_set_property;
-	gobject_class->get_property = workbook_get_property;
-	gobject_class->finalize	    = workbook_finalize;
-	gobject_class->dispose	    = workbook_dispose;
-
-        g_object_class_install_property (gobject_class, RECALC_MODE,
-		 g_param_spec_boolean ("recalc-mode",
-				       P_("Recalc mode"),
-				       P_("Enable automatic recalculation."),
-				       TRUE,
-				       GSF_PARAM_STATIC |
-				       G_PARAM_READWRITE));
-
-	signals [SHEET_ORDER_CHANGED] = g_signal_new ("sheet_order_changed",
-		GNM_WORKBOOK_TYPE,
-		G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (WorkbookClass, sheet_order_changed),
-		NULL, NULL,
-		g_cclosure_marshal_VOID__VOID,
-		G_TYPE_NONE,
-		0, G_TYPE_NONE);
-
-	signals [SHEET_ADDED] = g_signal_new ("sheet_added",
-		GNM_WORKBOOK_TYPE,
-		G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (WorkbookClass, sheet_added),
-		NULL, NULL,
-		g_cclosure_marshal_VOID__VOID,
-		G_TYPE_NONE,
-		0, G_TYPE_NONE);
-
-	signals [SHEET_DELETED] = g_signal_new ("sheet_deleted",
-		GNM_WORKBOOK_TYPE,
-		G_SIGNAL_RUN_LAST,
-		G_STRUCT_OFFSET (WorkbookClass, sheet_deleted),
-		NULL, NULL,
-		g_cclosure_marshal_VOID__VOID,
-		G_TYPE_NONE,
-		0, G_TYPE_NONE);
-}
-
-/**
- * workbook_new:
- *
- * Creates a new empty Workbook
- * and assigns a unique name.
- **/
-Workbook *
-workbook_new (void)
+static GObject *
+workbook_constructor (GType type,
+		      guint n_construct_properties,
+		      GObjectConstructParam *construct_params)
 {
+	GObject *obj;
+	Workbook *wb;
 	static int count = 0;
 	gboolean is_unique;
-	Workbook  *wb;
 	GOFileSaver *def_save = go_file_saver_get_default ();
 	char const *extension = NULL;
 
+	obj = workbook_parent_class->constructor
+		(type, n_construct_properties, construct_params);
+	wb = WORKBOOK (obj);
+
 	if (def_save != NULL)
 		extension = go_file_saver_get_extension (def_save);
 	if (extension == NULL)
 		extension = "gnumeric";
 
-	wb = g_object_new (GNM_WORKBOOK_TYPE, NULL);
-
 	/* Assign a default name */
 	do {
 		char *name, *nameutf8, *uri;
@@ -360,8 +320,68 @@ workbook_new (void)
 		g_free (name);
 		g_free (nameutf8);
 	} while (!is_unique);
+
 	gnm_insert_meta_date (GO_DOC (wb), GSF_META_NAME_DATE_CREATED);
-	return wb;
+
+	return obj;
+}
+
+static void
+workbook_class_init (GObjectClass *gobject_class)
+{
+	workbook_parent_class = g_type_class_peek_parent (gobject_class);
+
+	gobject_class->constructor  = workbook_constructor;
+	gobject_class->set_property = workbook_set_property;
+	gobject_class->get_property = workbook_get_property;
+	gobject_class->finalize	    = workbook_finalize;
+	gobject_class->dispose	    = workbook_dispose;
+
+        g_object_class_install_property (gobject_class, PROP_RECALC_MODE,
+		 g_param_spec_boolean ("recalc-mode",
+				       P_("Recalc mode"),
+				       P_("Enable automatic recalculation."),
+				       TRUE,
+				       GSF_PARAM_STATIC |
+				       G_PARAM_READWRITE));
+
+	signals[SHEET_ORDER_CHANGED] = g_signal_new ("sheet_order_changed",
+		GNM_WORKBOOK_TYPE,
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (WorkbookClass, sheet_order_changed),
+		NULL, NULL,
+		g_cclosure_marshal_VOID__VOID,
+		G_TYPE_NONE,
+		0, G_TYPE_NONE);
+
+	signals[SHEET_ADDED] = g_signal_new ("sheet_added",
+		GNM_WORKBOOK_TYPE,
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (WorkbookClass, sheet_added),
+		NULL, NULL,
+		g_cclosure_marshal_VOID__VOID,
+		G_TYPE_NONE,
+		0, G_TYPE_NONE);
+
+	signals[SHEET_DELETED] = g_signal_new ("sheet_deleted",
+		GNM_WORKBOOK_TYPE,
+		G_SIGNAL_RUN_LAST,
+		G_STRUCT_OFFSET (WorkbookClass, sheet_deleted),
+		NULL, NULL,
+		g_cclosure_marshal_VOID__VOID,
+		G_TYPE_NONE,
+		0, G_TYPE_NONE);
+}
+
+/**
+ * workbook_new:
+ *
+ * Returns: A new empty #Workbook with a unique name.
+ **/
+Workbook *
+workbook_new (void)
+{
+	return g_object_new (GNM_WORKBOOK_TYPE, NULL);
 }
 
 /**
@@ -406,7 +426,7 @@ workbook_sheet_name_strip_number (char *name, unsigned int *number)
  * workbook_new_with_sheets:
  * @sheet_count: initial number of sheets to create.
  *
- * Returns a Workbook with @sheet_count allocated
+ * Returns: a #Workbook with @sheet_count allocated
  * sheets on it
  */
 Workbook *
@@ -420,7 +440,7 @@ workbook_new_with_sheets (int sheet_count)
 	while (sheet_count-- > 0)
 		workbook_sheet_add (wb, -1, cols, rows);
 	go_doc_set_dirty (GO_DOC (wb), FALSE);
-	GO_DOC (wb)->pristine = TRUE;
+	go_doc_set_pristine (GO_DOC (wb), TRUE);
 	return wb;
 }
 
@@ -428,11 +448,11 @@ workbook_new_with_sheets (int sheet_count)
  * workbook_set_saveinfo:
  * @wb: the workbook to modify
  * @lev: the file format level
- * @saver: the file saver.
+ * @saver: (nullable): the file saver.
  *
- * If level is sufficiently advanced assign the info.
+ * If level is sufficiently advanced, assign the info.
  *
- * Returns: TRUE if save info was set and history may require updating
+ * Returns: %TRUE if save info was set and history may require updating
  *
  * FIXME : Add a check to ensure the name is unique.
  */
@@ -521,10 +541,11 @@ workbook_set_file_exporter (Workbook *wb, GOFileSaver *fs)
 }
 
 void
-workbook_set_last_export_uri (Workbook *wb, gchar *uri)
+workbook_set_last_export_uri (Workbook *wb, const gchar *uri)
 {
+	char *s = g_strdup (uri);
 	g_free (wb->last_export_uri);
-	wb->last_export_uri = uri;
+	wb->last_export_uri = s;
 	WORKBOOK_FOREACH_CONTROL (wb, wbv, wbc,
 				  wb_control_menu_state_update (wbc, MS_FILE_EXPORT_IMPORT););
 }
@@ -579,8 +600,7 @@ workbook_foreach_cell_in_range (GnmEvalPos const *pos,
 
 		for (; i <= stop ; i++) {
 			res = sheet_foreach_cell_in_range (
-				g_ptr_array_index (wb->sheets, i), flags,
-				r.start.col, r.start.row, r.end.col, r.end.row,
+				g_ptr_array_index (wb->sheets, i), flags, &r,
 				handler, closure);
 			if (res != NULL)
 				return res;
@@ -588,8 +608,7 @@ workbook_foreach_cell_in_range (GnmEvalPos const *pos,
 		return NULL;
 	}
 
-	return sheet_foreach_cell_in_range (start_sheet, flags,
-		r.start.col, r.start.row, r.end.col, r.end.row,
+	return sheet_foreach_cell_in_range (start_sheet, flags, &r,
 		handler, closure);
 }
 
@@ -602,7 +621,7 @@ workbook_foreach_cell_in_range (GnmEvalPos const *pos,
  * Collects a GPtrArray of GnmEvalPos pointers for all cells in a workbook.
  * No particular order should be assumed.
  *
- * Returns: (element-type GnmEvalPos) (transfer full): the cells array
+ * Returns: (element-type GnmEvalPos) (transfer container): the cells array
  */
 GPtrArray *
 workbook_cells (Workbook *wb, gboolean comments, GnmSheetVisibility vis)
@@ -612,7 +631,7 @@ workbook_cells (Workbook *wb, gboolean comments, GnmSheetVisibility vis)
 	g_return_val_if_fail (wb != NULL, cells);
 
 	WORKBOOK_FOREACH_SHEET (wb, sheet, {
-		int oldlen = cells->len;
+		size_t oldlen = cells->len;
 		GPtrArray *scells;
 
 		if (sheet->visibility > vis)
@@ -706,7 +725,13 @@ void
 workbook_set_recalcmode (Workbook *wb, gboolean is_auto)
 {
 	g_return_if_fail (GNM_IS_WORKBOOK (wb));
+
+	is_auto = !!is_auto;
+	if (is_auto == wb->recalc_auto)
+		return;
+
 	wb->recalc_auto = is_auto;
+	g_object_notify (G_OBJECT (wb), "recalc-mode");
 }
 
 gboolean
@@ -763,7 +788,7 @@ workbook_detach_view (WorkbookView *wbv)
 
 	WORKBOOK_FOREACH_SHEET (wbv->wb, sheet, {
 		SheetView *sv = sheet_get_view (sheet, wbv);
-		sv_dispose (sv);
+		gnm_sheet_view_dispose (sv);
 	});
 
 	g_ptr_array_remove (wbv->wb->wb_views, wbv);
@@ -780,7 +805,7 @@ workbook_detach_view (WorkbookView *wbv)
  * @wb: #Workbook
  *
  * Get an ordered list of the sheets in the workbook
- * The caller is required to free the list.
+ *
  * Returns: (element-type Sheet) (transfer container): the sheets list.
  */
 GSList *
@@ -836,7 +861,7 @@ post_sheet_index_change (Workbook *wb)
 	if (wb->during_destruction)
 		return;
 
-	g_signal_emit (G_OBJECT (wb), signals [SHEET_ORDER_CHANGED], 0);
+	g_signal_emit (G_OBJECT (wb), signals[SHEET_ORDER_CHANGED], 0);
 }
 
 static void
@@ -855,19 +880,16 @@ workbook_sheet_index_update (Workbook *wb, int start)
  * @wb: workbook to lookup the sheet on
  * @i: the sheet index we are looking for.
  *
- * Return value: (transfer none): a pointer to a Sheet or NULL if the sheet
- * was not found.
+ * Return value: (transfer none) (nullable): A #Sheet
  */
 Sheet *
 workbook_sheet_by_index (Workbook const *wb, int i)
 {
 	g_return_val_if_fail (GNM_IS_WORKBOOK (wb), NULL);
-	g_return_val_if_fail (i < (int)wb->sheets->len, NULL);
 	g_return_val_if_fail (i >= -1, NULL);
 
-	/* i = -1 is special, return NULL */
-
-	if (i == -1)
+	// i = -1 is special, return NULL
+	if (i == -1 || i >= (int)wb->sheets->len)
 		return NULL;
 
 	return g_ptr_array_index (wb->sheets, i);
@@ -876,10 +898,9 @@ workbook_sheet_by_index (Workbook const *wb, int i)
 /**
  * workbook_sheet_by_name:
  * @wb: workbook to lookup the sheet on
- * @sheet_name: the sheet name we are looking for.
+ * @sheet_name: the sheet name we are looking for.  This is case insensitive.
  *
- * Return value: (transfer none): a pointer to a Sheet or NULL if the sheet
- * was not found.
+ * Return value: (transfer none) (nullable): A #Sheet
  */
 Sheet *
 workbook_sheet_by_name (Workbook const *wb, char const *name)
@@ -932,9 +953,9 @@ workbook_focus_other_sheet (Workbook *wb, Sheet *sheet)
  * @wb: #Workbook
  * @sheet: #Sheet
  *
- * Remove the visible SheetControls of a sheet and shut them down politely.
+ * Remove the visible #SheetControls of a sheet and shut them down politely.
  *
- * Returns TRUE if there are any remaining sheets visible
+ * Returns %TRUE if there are any remaining sheets visible
  **/
 static gboolean
 workbook_sheet_remove_controls (Workbook *wb, Sheet *sheet)
@@ -963,12 +984,11 @@ workbook_sheet_remove_controls (Workbook *wb, Sheet *sheet)
 
 /**
  * workbook_sheet_attach_at_pos:
- * @wb:
- * @new_sheet:
- * @pos;
+ * @wb: A #Workbook
+ * @new_sheet: A #Sheet
+ * @pos: position to attach @new_sheet at, -1 meaning at the end
  *
- * Add @new_sheet to @wb, placing it at @pos.  This will add a ref to
- * the sheet.
+ * Add @new_sheet to @wb, placing it at @pos.
  */
 void
 workbook_sheet_attach_at_pos (Workbook *wb, Sheet *new_sheet, int pos)
@@ -976,7 +996,10 @@ workbook_sheet_attach_at_pos (Workbook *wb, Sheet *new_sheet, int pos)
 	g_return_if_fail (GNM_IS_WORKBOOK (wb));
 	g_return_if_fail (IS_SHEET (new_sheet));
 	g_return_if_fail (new_sheet->workbook == wb);
-	g_return_if_fail (pos >= 0 && pos <= (int)wb->sheets->len);
+	g_return_if_fail (pos >= -1 && pos <= (int)wb->sheets->len);
+
+	if (pos == -1)
+		pos = wb->sheets->len;
 
 	pre_sheet_index_change (wb);
 
@@ -998,8 +1021,8 @@ workbook_sheet_attach_at_pos (Workbook *wb, Sheet *new_sheet, int pos)
 
 /**
  * workbook_sheet_attach:
- * @wb:
- * @new_sheet:
+ * @wb: A #Workbook
+ * @new_sheet: (transfer full): A #Sheet to attach
  *
  * Add @new_sheet to @wb, placing it at the end.  SURPRISE: This assumes
  * a ref to the sheet.
@@ -1007,15 +1030,15 @@ workbook_sheet_attach_at_pos (Workbook *wb, Sheet *new_sheet, int pos)
 void
 workbook_sheet_attach (Workbook *wb, Sheet *new_sheet)
 {
-	workbook_sheet_attach_at_pos (wb, new_sheet, wb->sheets->len);
+	workbook_sheet_attach_at_pos (wb, new_sheet, -1);
 	/* Balance the ref added by the above call.  */
 	g_object_unref (new_sheet);
 }
 
 /**
  * workbook_sheet_add:
- * @wb: a workbook.
- * @pos: position to add, -1 meaning append.
+ * @wb: a #Workbook.
+ * @pos: position to add, -1 meaning at end.
  * @columns: the sheet columns number.
  * @rows: the sheet rows number.
  *
@@ -1031,12 +1054,10 @@ workbook_sheet_add (Workbook *wb, int pos, int columns, int rows)
 	Sheet *new_sheet = sheet_new (wb, name, columns, rows);
 	g_free (name);
 
-	if (pos == -1)
-		pos = wb->sheets->len;
 	workbook_sheet_attach_at_pos (wb, new_sheet, pos);
 
 	/* FIXME: Why here?  */
-	g_signal_emit (G_OBJECT (wb), signals [SHEET_ADDED], 0);
+	g_signal_emit (G_OBJECT (wb), signals[SHEET_ADDED], 0);
 
 	g_object_unref (new_sheet);
 
@@ -1063,12 +1084,10 @@ workbook_sheet_add_with_type (Workbook *wb, GnmSheetType sheet_type, int pos, in
 	Sheet *new_sheet = sheet_new_with_type (wb, name, sheet_type, columns, rows);
 	g_free (name);
 
-	if (pos == -1)
-		pos = wb->sheets->len;
 	workbook_sheet_attach_at_pos (wb, new_sheet, pos);
 
 	/* FIXME: Why here?  */
-	g_signal_emit (G_OBJECT (wb), signals [SHEET_ADDED], 0);
+	g_signal_emit (G_OBJECT (wb), signals[SHEET_ADDED], 0);
 
 	g_object_unref (new_sheet);
 
@@ -1077,7 +1096,7 @@ workbook_sheet_add_with_type (Workbook *wb, GnmSheetType sheet_type, int pos, in
 
 /**
  * workbook_sheet_delete:
- * @sheet: the sheet that we want to delete from its workbook
+ * @sheet: the #Sheet that we want to delete from its workbook
  *
  * This function detaches the given sheet from its parent workbook and
  * invalidates all references to the deleted sheet from other sheets and
@@ -1118,7 +1137,7 @@ workbook_sheet_delete (Sheet *sheet)
 	post_sheet_index_change (wb);
 
 	/* Clear the controls first, before we potentially update */
-	SHEET_FOREACH_VIEW (sheet, view, sv_dispose (view););
+	SHEET_FOREACH_VIEW (sheet, view, gnm_sheet_view_dispose (view););
 
 	g_signal_emit_by_name (G_OBJECT (sheet), "detached_from_workbook", wb);
 	g_object_unref (sheet);
@@ -1133,6 +1152,9 @@ workbook_sheet_delete (Sheet *sheet)
 
 /**
  * workbook_sheet_move:
+ * @sheet: #Sheet to move
+ * @direction: number of spots to move, positive for right and negative
+ * for left.
  *
  * Moves the sheet up or down @direction spots in the sheet list
  * If @direction is negative, move left. If positive, move right.
@@ -1171,7 +1193,7 @@ workbook_sheet_move (Sheet *sheet, int direction)
 
 /**
  * workbook_sheet_get_free_name:
- * @wb:   workbook to look for
+ * @wb: #Workbook for which the new name can be used
  * @base: base for the name, e. g. "Sheet"
  * @always_suffix: if true, add suffix even if the name "base" is not in use.
  * @handle_counter: strip counter if necessary
@@ -1179,7 +1201,7 @@ workbook_sheet_move (Sheet *sheet, int direction)
  * Gets a new unquoted name for a sheets such that it does not exist on the
  * workbook.
  *
- * Returns the name assigned to the sheet.
+ * Returns: (transfer full): a unique sheet name
  **/
 char *
 workbook_sheet_get_free_name (Workbook *wb,
@@ -1226,14 +1248,14 @@ workbook_sheet_get_free_name (Workbook *wb,
 
 /**
  * workbook_sheet_rename:
- * @wb:          workbook to look for
- * @sheet_indices: (element-type void):  list of sheet indices (ignore -1)
- * @new_names: (element-type char):  list of new names
+ * @wb: #Workbook in which to rename sheets
+ * @sheet_indices: (element-type void): list of sheet indices (ignore -1)
+ * @new_names: (element-type utf8): list of new names
  *
  * Adjusts the names of the sheets. We assume that everything is
  * valid. If in doubt call workbook_sheet_reorder_check first.
  *
- * Returns: FALSE when it was successful
+ * Returns: %FALSE when it was successful
  **/
 gboolean
 workbook_sheet_rename (Workbook *wb,
@@ -1245,10 +1267,10 @@ workbook_sheet_rename (Workbook *wb,
 	GSList *new_name = new_names;
 
 	while (new_name && sheet_index) {
-		if (-1 != GPOINTER_TO_INT (sheet_index->data)) {
-			g_hash_table_remove (wb->sheet_hash_private,
-					     new_name->data);
-		}
+		int ix = GPOINTER_TO_INT (sheet_index->data);
+		const char *name = new_name->data;
+		if (ix != -1)
+			g_hash_table_remove (wb->sheet_hash_private, name);
 		sheet_index = sheet_index->next;
 		new_name = new_name->next;
 	}
@@ -1256,10 +1278,11 @@ workbook_sheet_rename (Workbook *wb,
 	sheet_index = sheet_indices;
 	new_name = new_names;
 	while (new_name && sheet_index) {
-		if (-1 != GPOINTER_TO_INT (sheet_index->data)) {
-			Sheet *sheet = workbook_sheet_by_index
-				(wb, GPOINTER_TO_INT (sheet_index->data));
-			g_object_set (sheet, "name", new_name->data, NULL);
+		int ix = GPOINTER_TO_INT (sheet_index->data);
+		const char *name = new_name->data;
+		if (ix != -1) {
+			Sheet *sheet = workbook_sheet_by_index (wb, ix);
+			g_object_set (sheet, "name", name, NULL);
 		}
 		sheet_index = sheet_index->next;
 		new_name = new_name->next;
@@ -1275,6 +1298,7 @@ workbook_sheet_rename (Workbook *wb,
  * @cmd: command
  *
  * Returns: the 1 based index of the @key command, or 0 if it is not found
+ * (which would be a programmer error).
  **/
 unsigned
 workbook_find_command (Workbook *wb, gboolean is_undo, gpointer cmd)
@@ -1294,12 +1318,12 @@ workbook_find_command (Workbook *wb, gboolean is_undo, gpointer cmd)
 
 /**
  * workbook_sheet_reorder:
- * @wb:          workbook to look for
- * @new_order: (element-type Sheet):  list of sheets
+ * @wb: workbook to reorder
+ * @new_order: (element-type Sheet): list of #Sheet
  *
  * Adjusts the order of the sheets.
  *
- * Returns FALSE when it was successful
+ * Returns %FALSE when it was successful
  **/
 gboolean
 workbook_sheet_reorder (Workbook *wb, GSList *new_order)
