@@ -72,6 +72,9 @@ typedef struct {
 	GHashTable	   *expr_map;
 	GString		   *cell_str;   /* Scratch pad.  */
 
+	// Do we write result values?  For now this is clipboard only
+	gboolean            write_value_result;
+
 	GsfXMLOut *output;
 } GnmOutputXML;
 
@@ -578,15 +581,15 @@ xml_write_style (GnmOutputXML *state, GnmStyle const *style)
 				      GNM_VALIDATION_TYPE_TYPE, v->type);
 
 		switch (v->type) {
-		case GNM_VALIDATION_TYPE_AS_INT :
-		case GNM_VALIDATION_TYPE_AS_NUMBER :
-		case GNM_VALIDATION_TYPE_AS_DATE :
-		case GNM_VALIDATION_TYPE_AS_TIME :
-		case GNM_VALIDATION_TYPE_TEXT_LENGTH :
+		case GNM_VALIDATION_TYPE_AS_INT:
+		case GNM_VALIDATION_TYPE_AS_NUMBER:
+		case GNM_VALIDATION_TYPE_AS_DATE:
+		case GNM_VALIDATION_TYPE_AS_TIME:
+		case GNM_VALIDATION_TYPE_TEXT_LENGTH:
 			gsf_xml_out_add_enum (state->output, "Operator",
 					      GNM_VALIDATION_OP_TYPE, v->op);
 			break;
-		default :
+		default:
 			break;
 		}
 
@@ -726,25 +729,26 @@ xml_write_styles (GnmOutputXML *state)
 
 typedef struct {
 	GnmOutputXML *state;
-	gboolean	is_column;
-	ColRowInfo const *prev;
+	gboolean is_column;
+	ColRowInfo prev;
 	int prev_pos, rle_count;
+	GnmCellRegion const *cr;
 } closure_write_colrow;
 
 static gboolean
 xml_write_colrow_info (GnmColRowIter const *iter, closure_write_colrow *closure)
 {
-	ColRowInfo const *prev = closure->prev;
+	ColRowInfo const *prev = &closure->prev;
 	GsfXMLOut *output = closure->state->output;
 	ColRowInfo const *def =
 		sheet_colrow_get_default (closure->state->sheet,
 					  closure->is_column);
 
 	closure->rle_count++;
-	if (NULL != iter && colrow_equal (prev, iter->cri))
+	if (NULL != iter && col_row_info_equal (prev, iter->cri))
 		return FALSE;
 
-	if (prev != NULL && !colrow_equal (prev, def)) {
+	if (closure->prev_pos != -1 && !col_row_info_equal (prev, def)) {
 		if (closure->is_column)
 			gsf_xml_out_start_element (output, GNM "ColInfo");
 		else
@@ -768,7 +772,7 @@ xml_write_colrow_info (GnmColRowIter const *iter, closure_write_colrow *closure)
 
 	closure->rle_count = 0;
 	if (NULL != iter) {
-		closure->prev = iter->cri;
+		closure->prev = *iter->cri;
 		closure->prev_pos = iter->pos;
 	}
 
@@ -776,34 +780,44 @@ xml_write_colrow_info (GnmColRowIter const *iter, closure_write_colrow *closure)
 }
 
 static void
-xml_write_cols_rows (GnmOutputXML *state)
+xml_write_cols_rows (GnmOutputXML *state, GnmCellRegion const *cr)
 {
-	closure_write_colrow closure;
-	gsf_xml_out_start_element (state->output, GNM "Cols");
-	xml_out_add_points (state->output, "DefaultSizePts",
-		sheet_col_get_default_size_pts (state->sheet));
-	closure.state = state;
-	closure.is_column = TRUE;
-	closure.prev = NULL;
-	closure.prev_pos = -1;
-	closure.rle_count = 0;
-	colrow_foreach (&state->sheet->cols, 0, gnm_sheet_get_last_col (state->sheet),
-		(ColRowHandler)&xml_write_colrow_info, &closure);
-	xml_write_colrow_info (NULL, &closure); /* flush */
-	gsf_xml_out_end_element (state->output); /* </gnm:Cols> */
+	const Sheet *sheet = state->sheet;
+	int i;
 
-	gsf_xml_out_start_element (state->output, GNM "Rows");
-	xml_out_add_points (state->output, "DefaultSizePts",
-		sheet_row_get_default_size_pts (state->sheet));
-	closure.state = state;
-	closure.is_column = FALSE;
-	closure.prev = NULL;
-	closure.prev_pos = -1;
-	closure.rle_count = 0;
-	colrow_foreach (&state->sheet->rows, 0, gnm_sheet_get_last_row (state->sheet),
-		(ColRowHandler)&xml_write_colrow_info, &closure);
-	xml_write_colrow_info (NULL, &closure); /* flush */
-	gsf_xml_out_end_element (state->output); /* </gnm:Rows> */
+	for (i = 0; i < 2; i++) {
+		closure_write_colrow closure;
+		gboolean is_cols = (i == 0);
+
+		gsf_xml_out_start_element (state->output,
+					   is_cols ? GNM "Cols" : GNM "Rows");
+
+		if (sheet)
+			xml_out_add_points
+				(state->output, "DefaultSizePts",
+				 sheet_colrow_get_default (sheet, is_cols)->size_pts);
+
+		closure.state = state;
+		closure.cr = cr;
+		closure.is_column = is_cols;
+		memset (&closure.prev, 0, sizeof (closure.prev));
+		closure.prev_pos = -1;
+		closure.rle_count = 0;
+		if (cr)
+			colrow_state_list_foreach
+				(is_cols ? cr->col_state : cr->row_state,
+				 sheet, is_cols,
+				 is_cols ? cr->base.col : cr->base.row,
+				 (ColRowHandler)&xml_write_colrow_info,
+				 &closure);
+		else
+			sheet_colrow_foreach
+				(sheet, is_cols, 0, -1,
+				 (ColRowHandler)&xml_write_colrow_info,
+				 &closure);
+		xml_write_colrow_info (NULL, &closure); /* flush */
+		gsf_xml_out_end_element (state->output); /* </gnm:Cols> */
+	}
 }
 
 static void
@@ -870,11 +884,12 @@ xml_write_cell_and_position (GnmOutputXML *state,
 	}
 
 	if (write_contents) {
+		gboolean write_value = !texpr || state->write_value_result;
 		GString *str = state->cell_str;
 
 		g_string_truncate (str, 0);
 
-		if (!texpr) {
+		if (write_value) {
 			if (val != NULL) {
 				gsf_xml_out_add_int (state->output, "ValueType", val->v_any.type);
 				if (VALUE_FMT (val) != NULL) {
@@ -882,10 +897,16 @@ xml_write_cell_and_position (GnmOutputXML *state,
 					gsf_xml_out_add_cstr (state->output, "ValueFormat", fmt);
 				}
 				value_get_as_gstring (val, str, state->convs);
+				if (texpr) {
+					gsf_xml_out_add_cstr (state->output, "Value", str->str);
+					g_string_truncate (str, 0);
+				}
 			} else {
 				g_warning ("%s has no value ?", cellpos_as_string (&pp->eval));
 			}
-		} else {
+		}
+
+		if (texpr) {
 			GnmConventionsOut out;
 			out.accum = str;
 			out.pp    = pp;
@@ -917,9 +938,10 @@ static void
 xml_write_cells (GnmOutputXML *state)
 {
 	gsf_xml_out_start_element (state->output, GNM "Cells");
-	sheet_foreach_cell_in_range ((Sheet *)state->sheet, CELL_ITER_IGNORE_NONEXISTENT,
-		0, 0, gnm_sheet_get_last_col (state->sheet), gnm_sheet_get_last_row (state->sheet),
-		(CellIterFunc) cb_write_cell, state);
+	sheet_foreach_cell_in_region ((Sheet *)state->sheet,
+				      CELL_ITER_IGNORE_NONEXISTENT,
+				      0, 0, -1, -1,
+				      (CellIterFunc) cb_write_cell, state);
 	gsf_xml_out_end_element (state->output); /* </gnm:Cells> */
 }
 
@@ -945,7 +967,7 @@ xml_write_sheet_layout (GnmOutputXML *state)
 	gsf_xml_out_start_element (state->output, GNM "SheetLayout");
 	gnm_xml_out_add_cellpos (state->output, "TopLeft", &sv->initial_top_left);
 
-	if (sv_is_frozen (sv)) {
+	if (gnm_sheet_view_is_frozen (sv)) {
 		gsf_xml_out_start_element (state->output, GNM "FreezePanes");
 		gnm_xml_out_add_cellpos (state->output, "FrozenTopLeft", &sv->frozen_top_left);
 		gnm_xml_out_add_cellpos (state->output, "UnfrozenTopLeft", &sv->unfrozen_top_left);
@@ -1369,7 +1391,7 @@ xml_write_sheet (GnmOutputXML *state, Sheet const *sheet)
 	xml_write_named_expressions (state, sheet->names);
 	xml_write_print_info (state, sheet->print_info);
 	xml_write_styles (state);
-	xml_write_cols_rows (state);
+	xml_write_cols_rows (state, NULL);
 	xml_write_selection_info (state);
 	xml_write_objects (state, sheet->sheet_objects);
 	xml_write_cells (state);
@@ -1489,6 +1511,7 @@ gnm_xml_file_save_full (G_GNUC_UNUSED GOFileSaver const *fs,
 	state.convs	= gnm_xml_io_conventions ();
 	state.expr_map  = g_hash_table_new (g_direct_hash, g_direct_equal);
 	state.cell_str  = g_string_new (NULL);
+	state.write_value_result = FALSE;
 	go_doc_init_write (GO_DOC (state.wb), state.output);
 
 	locale = gnm_push_C_locale ();
@@ -1588,8 +1611,7 @@ cb_xml_write_cell_region_cells (GnmCellCopy *cc,
  * gnm_cellregion_to_xml:
  * @cr: the content to store.
  *
- * Caller is responsible for free-ing the result.
- * Returns: (transfer full): NULL on error
+ * Returns: (transfer full): %NULL on error
  **/
 GsfOutputMemory *
 gnm_cellregion_to_xml (GnmCellRegion const *cr)
@@ -1611,6 +1633,7 @@ gnm_cellregion_to_xml (GnmCellRegion const *cr)
 	state.state.convs = gnm_xml_io_conventions ();
 	state.state.expr_map = g_hash_table_new (g_direct_hash, g_direct_equal);
 	state.state.cell_str = g_string_new (NULL);
+	state.state.write_value_result = TRUE;
 
 	locale = gnm_push_C_locale ();
 	if (cr->origin_sheet) {
@@ -1640,6 +1663,8 @@ gnm_cellregion_to_xml (GnmCellRegion const *cr)
 	if (cr->not_as_contents)
 		gsf_xml_out_add_bool (state.state.output, "NotAsContent", TRUE);
 
+	xml_write_cols_rows (&state.state, cr);
+
 	if (cr->styles != NULL) {
 		gsf_xml_out_start_element (state.state.output, GNM "Styles");
 		for (s_ptr = cr->styles ; s_ptr != NULL ; s_ptr = s_ptr->next)
