@@ -13,21 +13,29 @@ $| = 1;
                            test_csv_format_guessing
 			   test_ssindex sstest test_command message subtest
                            test_tool
+                           setup_python_environment
 			   $ssconvert $sstest $ssdiff $ssgrep $gnumeric
                            $topsrc $top_builddir
-			   $subtests $samples corpus $PERL);
+			   $subtests $samples corpus $PERL $PYTHON);
 @GnumericTest::EXPORT_OK = qw(junkfile);
 
-use vars qw($topsrc $top_builddir $samples $default_subtests $default_corpus $PERL $verbose);
+use vars qw($topsrc $top_builddir $samples $default_subtests $default_corpus $PERL $PYTHON $verbose);
 use vars qw($ssconvert $ssindex $sstest $ssdiff $ssgrep $gnumeric);
 use vars qw($normalize_gnumeric);
 
+$PYTHON = undef;
+
 $PERL = $Config{'perlpath'};
 $PERL .= $Config{'_exe'} if $^O ne 'VMS' && $PERL !~ m/$Config{'_exe'}$/i;
 
-$topsrc = $0;
-$topsrc =~ s|/[^/]+$|/..|;
-$topsrc =~ s|/test/\.\.$||;
+if ($0 eq '-e') {
+    # Running as "perl -e '...'", so no idea about where we are
+    $topsrc = '.';
+} else {
+    $topsrc = $0;
+    $topsrc =~ s|/[^/]+$|/..|;
+    $topsrc =~ s|/test/\.\.$||;
+}
 
 $top_builddir = "..";
 $samples = "$topsrc/samples"; $samples =~ s{^\./+}{};
@@ -174,10 +182,10 @@ sub subtest {
 
 # -----------------------------------------------------------------------------
 
-my @full_corpus =
-    ("$samples/excel/address.xls",
+my @dist_corpus =
+    ("$samples/regress.gnumeric",
+     "$samples/excel/address.xls",
      "$samples/excel/bitwise.xls",
-     "$samples/excel/chart-tests-excel.xls",
      "$samples/excel/datefuns.xls",
      "$samples/excel/dbfuns.xls",
      "$samples/excel/engfuns.xls",
@@ -241,12 +249,19 @@ my @full_corpus =
      "$samples/validation-tests.gnumeric",
     );
 
+my @full_corpus =
+    ("$samples/excel/chart-tests-excel.xls",   # Too big
+     @dist_corpus);
+
+
 sub corpus {
     my ($c) = @_;
 
     my $corpus = ($c || $user_corpus || $default_corpus);
     if ($corpus eq 'full') {
 	return @full_corpus;
+    } elsif ($corpus eq 'dist') {
+	return @dist_corpus;
     } elsif ($corpus =~ /^random:(\d+)$/) {
 	my $n = $1;
 	my @corpus = grep { -r $_; } @full_corpus;
@@ -269,11 +284,12 @@ sub corpus {
 sub test_command {
     my ($cmd,$test) = @_;
 
+    print STDERR "# $cmd\n" if $verbose;
     my $output = `$cmd 2>&1`;
     my $err = $?;
+    &dump_indented ($output);
     die "Failed command: $cmd\n" if $err;
 
-    &dump_indented ($output);
     local $_ = $output;
     if (&$test ($output)) {
 	print STDERR "Pass\n";
@@ -881,6 +897,30 @@ sub has_linear_solver {
 
 # -----------------------------------------------------------------------------
 
+sub setup_python_environment {
+    $PYTHON = `grep '^#define PYTHON_INTERPRETER ' $top_builddir/gnumeric-config.h 2>&1`;
+    chomp $PYTHON;
+    $PYTHON =~ s/^[^"]*"(.*)"\s*$/$1/;
+    &report_skip ("Missing python interpreter") unless -x $PYTHON;
+
+    # Make sure we load introspection preferentially from build directory
+    my $v = 'GI_TYPELIB_PATH';
+    my $dir = "$top_builddir/src";
+    $ENV{$v} = ($ENV{$v} || '') eq '' ? $dir : $dir . ':' . $ENV{$v};
+
+    # Ditto for shared libraries
+    $v = 'LD_LIBRARY_PATH';
+    $dir = "$top_builddir/src/.libs";
+    $ENV{$v} = ($ENV{$v} || '') eq '' ? $dir : $dir . ':' . $ENV{$v};
+
+    $ENV{'PYTHONPATH'} = "$topsrc/introspection";
+    
+    # Don't litter
+    $ENV{'PYTHONDONTWRITEBYTECODE'} = 1;
+}
+
+# -----------------------------------------------------------------------------
+
 sub quotearg {
     return join (' ', map { &quotearg1 ($_) } @_);
 }
